@@ -4,17 +4,17 @@
 #include <seqan3/alphabet/aminoacid/aa27.hpp>       // for seqan3::operator""_aa27
 #include <seqan3/core/debug_stream.hpp>
 
-using seqan3::operator""_aa27;
-
 int main()
 {
+    using namespace seqan3::literals;
+
     auto seq1 = "QFSEEILSDIYCWMLQCGQERAV"_aa27;
     auto seq2 = "AFLPGWQEENKLSKIWMKDCGCLW"_aa27;
 
     // Configure the alignment kernel.
     auto config = seqan3::align_cfg::method_global{} |
                   seqan3::align_cfg::scoring_scheme{
-                      seqan3::aminoacid_scoring_scheme{seqan3::aminoacid_similarity_matrix::BLOSUM62}} |
+                      seqan3::aminoacid_scoring_scheme{seqan3::aminoacid_similarity_matrix::blosum62}} |
                   seqan3::align_cfg::gap_cost_affine{seqan3::align_cfg::open_score{-9},
                                                      seqan3::align_cfg::extension_score{-2}};
 
