@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2020, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2020, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -18,8 +18,8 @@
 
 #include <seqan3/alignment/exception.hpp>
 #include <seqan3/alphabet/gap/gapped.hpp>
-#include <seqan3/range/concept.hpp>
-#include <seqan3/range/container/concept.hpp>
+#include <seqan3/alphabet/range/sequence.hpp>
+#include <seqan3/utility/container/concept.hpp>
 
 // ---------------------------------------------------------------------------------------------------------------------
 // unaligned_seq transformation trait
@@ -54,7 +54,7 @@ struct unaligned_seq
 //!\brief Exposes the unaligned sequence type given an aligned sequence container type.
 template <typename t>
 //!\cond
-    requires (!requires { typename std::remove_reference_t<t>::unaligned_seq_type; }) &&
+    requires (!requires { typename std::remove_reference_t<t>::unaligned_sequence_type; }) &&
               requires { remove_gap_from_value_type(std::declval<t>()); }
 //!\endcond
 struct unaligned_seq<t>
@@ -64,14 +64,14 @@ struct unaligned_seq<t>
 };
 
 // customisation point for our gap decorators.
-//!\brief Exposes the unaligned sequence type if *t* exposes the type member `unaligned_seq_type`.
+//!\brief Exposes the unaligned sequence type if *t* exposes the type member `unaligned_sequence_type`.
 template <typename t>
 //!\cond
-    requires requires { typename std::remove_reference_t<t>::unaligned_seq_type; }
+    requires requires { typename std::remove_reference_t<t>::unaligned_sequence_type; }
 //!\endcond
 struct unaligned_seq<t>
 {
-    using type = typename std::remove_reference_t<t>::unaligned_seq_type; //!< The unaligned sequence type of t
+    using type = typename std::remove_reference_t<t>::unaligned_sequence_type; //!< The unaligned sequence type of t
 };
 
 //!\brief Helper type that delegates to seqan3::detail::unaligned_seq::type.
@@ -248,7 +248,7 @@ SEQAN3_CONCEPT writable_aligned_sequence =
  * \{
  */
 /*!\brief An implementation of seqan3::writable_aligned_sequence::insert_gap for sequence containers.
- * \ingroup aligned_sequence
+ * \ingroup alignment_aligned_sequence
  * \tparam        aligned_seq_t   Type of the container to modify; must model seqan3::sequence_container;
  *                                The value type must be a seqan3::gapped alphabet.
  * \param[in,out] aligned_seq     The aligned container to modify.
@@ -273,7 +273,7 @@ inline typename aligned_seq_t::iterator insert_gap(aligned_seq_t & aligned_seq,
 }
 
 /*!\brief An implementation of seqan3::writable_aligned_sequence::insert_gap for sequence containers.
- * \ingroup aligned_sequence
+ * \ingroup alignment_aligned_sequence
  * \tparam        aligned_seq_t   Type of the container to modify; must model seqan3::sequence_container;
  *                                The value type must be a seqan3::gapped alphabet.
  * \param[in,out] aligned_seq     The aligned container to modify.
@@ -300,7 +300,7 @@ inline typename aligned_seq_t::iterator insert_gap(aligned_seq_t & aligned_seq,
 }
 
 /*!\brief An implementation of seqan3::writable_aligned_sequence::erase_gap for sequence containers.
- * \ingroup aligned_sequence
+ * \ingroup alignment_aligned_sequence
  * \tparam        aligned_seq_t   Type of the container to modify; must model seqan3::sequence_container;
  *                                The value type must be a seqan3::gapped alphabet.
  * \param[in,out] aligned_seq     The aligned container to modify.
@@ -332,7 +332,7 @@ inline typename aligned_seq_t::iterator erase_gap(aligned_seq_t & aligned_seq,
 }
 
 /*!\brief An implementation of seqan3::writable_aligned_sequence::erase_gap for sequence containers.
- * \ingroup aligned_sequence
+ * \ingroup alignment_aligned_sequence
  * \tparam        aligned_seq_t   Type of the container to modify; must model seqan3::sequence_container;
  *                                The value type must be a seqan3::gapped alphabet.
  * \param[in,out] aligned_seq     The aligned container to modify.
@@ -367,7 +367,7 @@ inline typename aligned_seq_t::iterator erase_gap(aligned_seq_t & aligned_seq,
 }
 
 /*!\brief An implementation of seqan3::writable_aligned_sequence::assign_unaligned_sequence for sequence containers.
- * \ingroup aligned_sequence
+ * \ingroup alignment_aligned_sequence
  * \tparam        aligned_seq_t     Type of the container to reassign; must model seqan3::sequence_container;
  *                                  the value type must be a seqan3::gapped alphabet.
  * \tparam        unaligned_seq_t   Type of the container to assign from; must model std::ranges::forward_range.
@@ -411,7 +411,7 @@ inline void assign_unaligned(aligned_seq_t & aligned_seq, unaligned_sequence_typ
  */
 /*!\brief An implementation of seqan3::writable_aligned_sequence::insert_gap for ranges with the corresponding
  *        member function insert_gap(it, size).
- * \ingroup aligned_sequence
+ * \ingroup alignment_aligned_sequence
  * \tparam range_type    Type of the range to modify; must have an insert_gap(it, size) member function.
  * \param[in,out] rng    The range to modify.
  * \param[in]     pos_it The iterator pointing to the position where to start inserting gaps.
@@ -441,7 +441,7 @@ std::ranges::iterator_t<range_type> insert_gap(range_type & rng,
 
 /*!\brief An implementation of seqan3::writable_aligned_sequence::erase_gap for ranges with the corresponding
  *        member function erase_gap(it).
- * \ingroup aligned_sequence
+ * \ingroup alignment_aligned_sequence
  * \tparam range_type   Type of the range to modify; must have an erase_gap(it) member function.
  * \param[in,out] rng   The range to modify.
  * \param[in] pos_it    The iterator pointing to the position where to erase one gap.
@@ -467,7 +467,7 @@ std::ranges::iterator_t<range_type> erase_gap(range_type & rng,
 
 /*!\brief An implementation of seqan3::writable_aligned_sequence::erase_gap for ranges with the corresponding
  *        member function erase_gap(first, last).
- * \ingroup aligned_sequence
+ * \ingroup alignment_aligned_sequence
  * \tparam range_type   Type of the range to modify; must have an erase_gap(first, last) member function.
  * \param[in,out] rng   The range to modify.
  * \param[in] first     The iterator pointing to the position where to start erasing gaps.
@@ -510,16 +510,4 @@ inline bool constexpr all_model_aligned_seq = (aligned_sequence<elems> && ...);
  */
 template <typename ...elems>
 inline bool constexpr all_model_aligned_seq<type_list<elems...>> = all_model_aligned_seq<elems...>;
-
-/*!\brief True, if each type models seqan3::writable_aligned_sequence; false otherwise.
- * \tparam elems The pack of types to be tested.
- */
-template <typename ...elems>
-inline bool constexpr all_model_writable_aligned_seq = (writable_aligned_sequence<elems> && ...);
-
-/*!\brief True, if each type in the seqan3::type_list models seqan3::writable_aligned_sequence; false otherwise.
- * \tparam elems The pack of types to be tested.
- */
-template <typename ...elems>
-inline bool constexpr all_model_writable_aligned_seq<type_list<elems...>> = all_model_writable_aligned_seq<elems...>;
 } // namespace seqan3::detail
