@@ -1,25 +1,24 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2020, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2020, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
 
 /*!\file
- * \brief Meta-header for the \link alignment_matrix matrix sub-module \endlink.
+ * \brief Meta-header for the \cond DEV \link alignment_matrix Alignment / Matrix submodule \endlink \endcond.
  * \author Marcel Ehrhardt <marcel.ehrhardt AT fu-berlin.de>
  */
 
-#pragma once
+//!\cond DEV
 
 /*!\defgroup alignment_matrix Matrix
  * \brief Provides data structures for representing alignment coordinates and alignments as a matrix.
  * \ingroup alignment
  * \see alignment
  */
+//!\endcond
 
-#include <seqan3/alignment/matrix/alignment_coordinate.hpp>
-#include <seqan3/alignment/matrix/alignment_optimum.hpp>
-#include <seqan3/alignment/matrix/debug_matrix.hpp>
-#include <seqan3/alignment/matrix/matrix_concept.hpp>
-#include <seqan3/alignment/matrix/row_wise_matrix.hpp>
+#pragma once
+
+#include <seqan3/core/platform.hpp>
