@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2020, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2020, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -12,12 +12,13 @@
 
 #pragma once
 
-#include <seqan3/core/type_traits/basic.hpp>
-#include <seqan3/core/type_traits/range.hpp>
 #include <seqan3/std/iterator>
 #include <seqan3/std/ranges>
 #include <seqan3/std/span>
 
+#include <seqan3/core/range/type_traits.hpp>
+#include <seqan3/utility/type_traits/basic.hpp>
+
 namespace seqan3::detail
 {
 
@@ -289,7 +290,7 @@ private:
      * When dereferenced the iterator returns a seqan3::detail::alignment_matrix_column_major_range_base::column_type.
      * The initialisation of the alignment-column depends on the derived type.
      * This iterator models the std::input_iterator since in some cases the underlying semantics would only guarantee
-     * an std::input_iterator, e.g. in the one column score matrix implementation. Both the previous and the current
+     * a std::input_iterator, e.g. in the one column score matrix implementation. Both the previous and the current
      * column refer to the same data storage.
      */
     class iterator_type
@@ -367,9 +368,8 @@ private:
             return column_index == me_ptr->num_cols;
         }
 
-        //!\copydoc operator==
-        friend constexpr bool operator==(std::default_sentinel_t const & lhs, iterator_type const & rhs)
-            noexcept
+        //!\copydoc seqan3::detail::alignment_matrix_column_major_range_base::alignment_column_type::iterator_type::operator==
+        friend constexpr bool operator==(std::default_sentinel_t const & lhs, iterator_type const & rhs) noexcept
         {
             return rhs == lhs;
         }
@@ -380,9 +380,8 @@ private:
             return !(*this == rhs);
         }
 
-        //!\copydoc operator!=
-        friend constexpr bool operator!=(std::default_sentinel_t const & lhs, iterator_type const & rhs)
-            noexcept
+        //!\copydoc seqan3::detail::alignment_matrix_column_major_range_base::alignment_column_type::iterator_type::operator!=
+        friend constexpr bool operator!=(std::default_sentinel_t const & lhs, iterator_type const & rhs) noexcept
         {
             return rhs != lhs;
         }
