@@ -14,7 +14,7 @@
 
 #include <seqan3/std/concepts>
 
-#include <seqan3/alignment/matrix/trace_directions.hpp>
+#include <seqan3/alignment/matrix/detail/trace_directions.hpp>
 #include <seqan3/utility/simd/concept.hpp>
 #include <seqan3/utility/type_traits/basic.hpp>
 
