@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2020, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2020, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -15,9 +15,9 @@
 
 #include <optional>
 
-#include <seqan3/core/algorithm/configuration.hpp>
-#include <seqan3/core/detail/debug_stream_type.hpp>
-#include <seqan3/core/type_traits/template_inspection.hpp>
+#include <seqan3/core/configuration/configuration.hpp>
+#include <seqan3/core/debug_stream/debug_stream_type.hpp>
+#include <seqan3/core/detail/template_inspection.hpp>
 
 namespace seqan3::detail
 {
@@ -32,7 +32,7 @@ template <typename configuration_t>
 class policy_alignment_result_builder;
 
 /*!\brief A struct that contains the actual alignment result data.
- * \ingroup pairwise_alignment
+ * \ingroup alignment_pairwise
  *
  * \tparam sequence1_id_t        The type of the alignment identifier for the first sequence.
  * \tparam sequence2_id_t        The type of the alignment identifier for the second sequence.
@@ -125,7 +125,7 @@ namespace seqan3
 {
 
 /*!\brief Stores the alignment results and gives access to score, alignment and the front and end positionss.
- * \ingroup pairwise_alignment
+ * \ingroup alignment_pairwise
  * \tparam alignment_result_value_t The underlying value type containing the information from the alignment computation.
  *
  * \details
@@ -203,6 +203,7 @@ public:
     alignment_result & operator=(alignment_result const &) = default; //!< Defaulted.
     alignment_result & operator=(alignment_result &&) = default;      //!< Defaulted.
     ~alignment_result() = default;                                    //!< Defaulted.
+
     //!\}
 
     /*!\name Access functions
@@ -364,7 +365,7 @@ namespace seqan3::detail
 {
 /*!\brief Transformation trait to access the hidden result value type of the seqan3::alignment_result class.
  * \implements transformation_trait
- * \ingroup pairwise_alignment
+ * \ingroup alignment_pairwise
  *
  * \tparam result_t The type of the alignment result.
  *
