@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2020, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2020, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -16,16 +16,14 @@
 #include <seqan3/std/ranges>
 
 #include <seqan3/alignment/pairwise/detail/pairwise_alignment_algorithm.hpp>
-#include <seqan3/range/views/drop.hpp>
-#include <seqan3/range/views/take.hpp>
-#include <seqan3/range/views/slice.hpp>
+#include <seqan3/utility/views/slice.hpp>
 
 namespace seqan3::detail
 {
 
 /*!\brief The alignment algorithm type to compute the banded standard pairwise alignment using dynamic programming.
  * \implements std::invocable
- * \ingroup pairwise_alignment
+ * \ingroup alignment_pairwise
  * \copydetails seqan3::detail::pairwise_alignment_algorithm
  */
 template <typename alignment_configuration_t, typename ...policies_t>
@@ -39,7 +37,7 @@ protected:
     //!\brief The alignment configuration traits type with auxiliary information extracted from the configuration type.
     using base_algorithm_t = pairwise_alignment_algorithm<alignment_configuration_t, policies_t...>;
 
-    // import types from base class.
+    // Import types from base class.
     using typename base_algorithm_t::traits_type;
     using typename base_algorithm_t::alignment_result_type;
     using typename base_algorithm_t::score_type;
@@ -85,21 +83,87 @@ public:
 
         for (auto && [sequence_pair, idx] : indexed_sequence_pairs)
         {
-            size_t const sequence1_size = std::ranges::distance(get<0>(sequence_pair));
+            size_t sequence1_size = std::ranges::distance(get<0>(sequence_pair));
             size_t const sequence2_size = std::ranges::distance(get<1>(sequence_pair));
 
             auto && [alignment_matrix, index_matrix] = this->acquire_matrices(sequence1_size,
                                                                               sequence2_size,
                                                                               this->lowest_viable_score());
 
-            compute_matrix(get<0>(sequence_pair), get<1>(sequence_pair), alignment_matrix, index_matrix);
+            // Initialise the cell updater with the dimensions of the regular matrix.
+            this->compare_and_set_optimum.set_target_indices(row_index_type{sequence2_size},
+                                                             column_index_type{sequence1_size});
+
+            // Shrink the first sequence if the band ends before its actual end.
+            sequence1_size = std::min(sequence1_size, this->upper_diagonal + sequence2_size);
+
+            using sequence1_difference_t = std::ranges::range_difference_t<decltype(get<0>(sequence_pair))>;
+
+            compute_matrix(std::views::take(get<0>(sequence_pair), static_cast<sequence1_difference_t>(sequence1_size)),
+                           get<1>(sequence_pair),
+                           alignment_matrix,
+                           index_matrix);
             this->make_result_and_invoke(std::forward<decltype(sequence_pair)>(sequence_pair),
                                          std::move(idx),
                                          this->optimal_score,
                                          this->optimal_coordinate,
+                                         alignment_matrix,
                                          callback);
         }
     }
+
+    //!\overload
+    template <indexed_sequence_pair_range indexed_sequence_pairs_t, typename callback_t>
+    //!\cond
+        requires traits_type::is_vectorised && std::invocable<callback_t, alignment_result_type>
+    //!\endcond
+    auto operator()(indexed_sequence_pairs_t && indexed_sequence_pairs, callback_t && callback)
+    {
+        using simd_collection_t = std::vector<score_type, aligned_allocator<score_type, alignof(score_type)>>;
+        using original_score_t = typename traits_type::original_score_type;
+
+        // Extract the batch of sequences for the first and the second sequence.
+        auto seq1_collection = indexed_sequence_pairs | views::elements<0> | views::elements<0>;
+        auto seq2_collection = indexed_sequence_pairs | views::elements<0> | views::elements<1>;
+
+        this->initialise_tracker(seq1_collection, seq2_collection);
+
+        // Convert batch of sequences to sequence of simd vectors.
+        thread_local simd_collection_t simd_seq1_collection{};
+        thread_local simd_collection_t simd_seq2_collection{};
+
+        this->convert_batch_of_sequences_to_simd_vector(simd_seq1_collection,
+                                                        seq1_collection,
+                                                        this->scoring_scheme.padding_symbol);
+        this->convert_batch_of_sequences_to_simd_vector(simd_seq2_collection,
+                                                        seq2_collection,
+                                                        this->scoring_scheme.padding_symbol);
+
+        size_t const sequence1_size = std::ranges::distance(simd_seq1_collection);
+        size_t const sequence2_size = std::ranges::distance(simd_seq2_collection);
+
+        auto && [alignment_matrix, index_matrix] = this->acquire_matrices(sequence1_size,
+                                                                          sequence2_size,
+                                                                          this->lowest_viable_score());
+
+        compute_matrix(simd_seq1_collection, simd_seq2_collection, alignment_matrix, index_matrix);
+
+        size_t index = 0;
+        for (auto && [sequence_pair, idx] : indexed_sequence_pairs)
+        {
+            original_score_t score = this->optimal_score[index] -
+                                     (this->padding_offsets[index] * this->scoring_scheme.padding_match_score());
+            matrix_coordinate coordinate{row_index_type{size_t{this->optimal_coordinate.row[index]}},
+                                         column_index_type{size_t{this->optimal_coordinate.col[index]}}};
+            this->make_result_and_invoke(std::forward<decltype(sequence_pair)>(sequence_pair),
+                                         std::move(idx),
+                                         std::move(score),
+                                         std::move(coordinate),
+                                         alignment_matrix,
+                                         callback);
+            ++index;
+        }
+    }
     //!\}
 
 protected:
@@ -177,33 +241,36 @@ protected:
         auto alignment_matrix_it = alignment_matrix.begin();
         auto indexed_matrix_it = index_matrix.begin();
 
-        size_t row_size = std::max<int32_t>(0, -this->lower_diagonal);
-        size_t const column_size = std::max<int32_t>(0, this->upper_diagonal);
-        this->initialise_column(*alignment_matrix_it, *indexed_matrix_it, sequence2 | views::take(row_size));
+        using row_index_t = std::ranges::range_difference_t<sequence2_t>; // row_size = |sequence2| + 1
+        using column_index_t = std::ranges::range_difference_t<sequence1_t>; // column_size = |sequence1| + 1
+
+        row_index_t row_size = std::max<int32_t>(0, -this->lower_diagonal);
+        column_index_t const column_size = std::max<int32_t>(0, this->upper_diagonal);
+        this->initialise_column(*alignment_matrix_it, *indexed_matrix_it, std::views::take(sequence2, row_size));
 
         // ---------------------------------------------------------------------
         // 1st recursion phase: band intersects with the first row.
         // ---------------------------------------------------------------------
 
-        for (auto sequence1_value : sequence1 | views::take(column_size))
+        for (auto alphabet1 : std::views::take(sequence1, column_size))
         {
             this->compute_column(*++alignment_matrix_it,
                                  *++indexed_matrix_it,
-                                 sequence1_value,
-                                 sequence2 | views::take(++row_size));
+                                 alphabet1,
+                                 std::views::take(sequence2, ++row_size));
         }
 
         // ---------------------------------------------------------------------
         // 2nd recursion phase: iterate until the end of the matrix.
         // ---------------------------------------------------------------------
 
-        size_t first_row_index = 0u;
-        for (auto sequence1_value : sequence1 | views::drop(column_size))
+        row_index_t first_row_index = 0u;
+        for (auto alphabet1 : std::views::drop(sequence1, column_size))
         {
             compute_band_column(*++alignment_matrix_it,
-                                *++indexed_matrix_it | views::drop(first_row_index + 1),
-                                sequence1_value,
-                                sequence2 | views::slice(first_row_index, ++row_size));
+                                std::views::drop(*++indexed_matrix_it, first_row_index + 1),
+                                alphabet1,
+                                views::slice(sequence2, first_row_index, ++row_size));
             ++first_row_index;
         }
 
@@ -212,14 +279,14 @@ protected:
         // ---------------------------------------------------------------------
 
         auto alignment_column = *alignment_matrix_it;
-        auto cell_index_column = *indexed_matrix_it | views::drop(first_row_index);
+        auto cell_index_column = std::views::drop(*indexed_matrix_it, first_row_index);
 
         auto alignment_column_it = alignment_column.begin();
         auto cell_index_column_it = cell_index_column.begin();
 
         this->track_last_column_cell(*alignment_column_it, *cell_index_column_it);
 
-        for (size_t last_row = std::min<size_t>(std::ranges::distance(sequence2), row_size);
+        for (row_index_t last_row = std::min<row_index_t>(std::ranges::distance(sequence2), row_size);
              first_row_index < last_row;
              ++first_row_index)
             this->track_last_column_cell(*++alignment_column_it, *++cell_index_column_it);
@@ -228,15 +295,15 @@ protected:
     }
 
     /*!\brief Computes a column of the band that does not start in the first row of the alignment matrix.
-     * \tparam alignment_column_t The type of the alignment column; must model std::ranges::input_range.
+     * \tparam alignment_column_t The type of the alignment column; must model std::ranges::forward_range.
      * \tparam cell_index_column_t The type of the indexed column; must model std::ranges::input_range.
-     * \tparam sequence1_value_t The value type of sequence1; must model seqan3::semialphabet.
+     * \tparam alphabet1_t The type of the current symbol of sequence1.
      * \tparam sequence2_t The type of the second sequence; must model std::ranges::input_range.
      *
      * \param[in] alignment_column The current alignment matrix column to compute.
      * \param[in] cell_index_column The current index matrix column to get the respective cell indices.
-     * \param[in] sequence1_value The current symbol of sequence1.
-     * \param[in] sequence2 The second sequence to align against `sequence1_value`.
+     * \param[in] alphabet1 The current symbol of sequence1.
+     * \param[in] sequence2 The second sequence to align against `alphabet1`.
      *
      * \details
      *
@@ -245,42 +312,76 @@ protected:
      * phase the first cell of the column is computed and in the iteration phase all remaining cells are computed.
      * In the final phase the last cell is possibly evaluated for a new alignment optimum.
      * Note that the length of `sequence2` determines the size of the column.
+     *
+     * ### Implementation with a score matrix using linear memory
+     *
+     * When the score matrix uses only linear memory, i.e. only one column is stored, the algorithm reuses the cells of
+     * the same column to compute the current one. This means, before the current cell is updated its value is
+     * cached and used as the previous diagonal value when computing the next cell below.
+     * In the banded case, however, the position of the referenced cell is shifted by one and needs a different
+     * handling.
+     *
+     * ```
+     *    0 1 2 3 4 5 6
+     *    _____________
+     * 0 |0|0|0|\      |
+     * 1 |1|1|1|0|\    |
+     * 2 |\|2|2|1|0|\  |
+     * 3 |  \|3|2|1|0|\|
+     * 4 |    \|3|2|1|0|
+     * 5 |      \|3|2|1|
+     *    –––––––––––––
+     *
+     * ```
+     * The picture above depicts the banded matrix with the indices of the column. As long as the band touches
+     * the first row (column 0 - 2), the indices of the actual stored column refer to the same position as the
+     * previous column. Hence, to compute these columns the regular algorithm
+     * seqan3::detail::pairwise_alignment_algorithm::compute_column can be used.
+     * Starting at column 3 the first cell of the band moves downwards, causing a shift in the position of the previous
+     * cell. In this state, the value of the current cell represents the previous diagonal value before it is updated.
+     * To read the previous horizontal value the next cell below has to be dereferenced.
+     * Accordingly, two iterators are used to point to the respective cells in the matrix. The first one points to the
+     * current cell (the one that is written to) and the second points to the next cell (the one where the
+     * horizontal and vertical scores are read from). After computing the last cell of the column the value of the
+     * current iterator can be used to track the score of the cell.
      */
-    template <std::ranges::input_range alignment_column_t,
+    template <std::ranges::forward_range alignment_column_t,
               std::ranges::input_range cell_index_column_t,
-              semialphabet sequence1_value_t,
+              typename alphabet1_t,
               std::ranges::input_range sequence2_t>
     void compute_band_column(alignment_column_t && alignment_column,
                              cell_index_column_t && cell_index_column,
-                             sequence1_value_t const & sequence1_value,
+                             alphabet1_t const & alphabet1,
                              sequence2_t && sequence2)
     {
         // ---------------------------------------------------------------------
         // Initial phase: prepare column and initialise first cell
         // ---------------------------------------------------------------------
 
-        auto alignment_column_it = alignment_column.begin();
+        auto current_alignment_column_it = alignment_column.begin();
         auto cell_index_column_it = cell_index_column.begin();
 
-        auto cell = *alignment_column_it;
+        // Points to the last valid cell in the column.
+        decltype(current_alignment_column_it) next_alignment_column_it{current_alignment_column_it};
+        auto cell = *current_alignment_column_it;
         cell = this->track_cell(
                 this->initialise_band_first_cell(cell.best_score(),
-                                                 *++alignment_column_it,
-                                                 this->scoring_scheme.score(sequence1_value,
-                                                                            *std::ranges::begin(sequence2))),
+                                                 *++next_alignment_column_it,
+                                                 this->scoring_scheme.score(alphabet1, *std::ranges::begin(sequence2))),
                 *cell_index_column_it);
 
         // ---------------------------------------------------------------------
         // Iteration phase: iterate over column and compute each cell
         // ---------------------------------------------------------------------
 
-        for (auto && sequence2_value : sequence2 | views::drop(1))
+        for (auto && alphabet2 : sequence2 | std::views::drop(1))
         {
-            auto cell = *alignment_column_it;
+            current_alignment_column_it = next_alignment_column_it;
+            auto cell = *current_alignment_column_it;
             cell = this->track_cell(
                 this->compute_inner_cell(cell.best_score(),
-                                         *++alignment_column_it,
-                                         this->scoring_scheme.score(sequence1_value, sequence2_value)),
+                                         *++next_alignment_column_it,
+                                         this->scoring_scheme.score(alphabet1, alphabet2)),
                 *++cell_index_column_it);
         }
 
@@ -288,7 +389,7 @@ protected:
         // Final phase: track last cell
         // ---------------------------------------------------------------------
 
-        this->track_last_row_cell(*alignment_column_it, *cell_index_column_it);
+        this->track_last_row_cell(*current_alignment_column_it, *cell_index_column_it);
     }
 };
 
