@@ -21,7 +21,7 @@ namespace seqan3
 {
 
 /*!\brief A CRTP-base that refines seqan3::alphabet_base and is used by the amino acids.
- * \ingroup aminoacid
+ * \ingroup alphabet_aminoacid
  * \tparam derived_type The CRTP parameter type.
  * \tparam size         The size of the alphabet.
  *
@@ -131,15 +131,7 @@ private:
             // the original valid chars and their lower cases
             for (size_t rank = 0u; rank < derived_type::alphabet_size; ++rank)
             {
-                uint8_t c{};
-#ifdef SEQAN3_DEPRECATED_310
-                if constexpr (detail::has_rank_to_char_table<derived_type>)
-                    c = derived_type::rank_to_char[rank];
-                else
-                    c = derived_type::rank_to_char(rank);
-#else // ^^^ before 3.1.0 release / after 3.1.0 release vvv
-                c = derived_type::rank_to_char(rank);
-#endif // SEQAN3_DEPRECATED_310
+                uint8_t c = derived_type::rank_to_char(rank);
                 ret[c] = true;
                 ret[to_lower(c)] = true;
             }
