@@ -13,7 +13,7 @@
 #pragma once
 
 #include <seqan3/alphabet/concept.hpp>
-#include <seqan3/utility/detail/exposition_only_concept.hpp>
+#include <seqan3/utility/concept/exposition_only/core_language.hpp>
 #include <seqan3/utility/type_list/type_list.hpp>
 #include <seqan3/utility/type_traits/lazy_conditional.hpp>
 
@@ -26,7 +26,7 @@ namespace seqan3::detail
 
 /*!\interface seqan3::detail::alphabet_tuple_like <>
  * \brief seqan3::alphabet_tuple_base and its derivates model this concept.
- * \ingroup composite
+ * \ingroup alphabet_composite
  *
  * \details
  *
@@ -47,7 +47,7 @@ SEQAN3_CONCEPT alphabet_tuple_like = requires
 
 /*!\brief A seqan3::type_list with types that the given type depends on.
  * \implements seqan3::transformation_trait
- * \ingroup composite
+ * \ingroup alphabet_composite
  *
  * \details
  *
@@ -64,7 +64,7 @@ struct required_types
 /*!\brief A seqan3::type_list with types that the given type depends on.
  *        [specialisation for seqan3::alphabet_variant and derivates of seqan3::alphabet_tuple_base].
  * \implements seqan3::transformation_trait
- * \ingroup composite
+ * \ingroup alphabet_composite
  *
  * \details
  *
@@ -94,7 +94,7 @@ using required_types_t = typename required_types<t>::type;
 
 /*!\brief Like seqan3::detail::required_types, but recursive.
  * \implements seqan3::transformation_trait
- * \ingroup composite
+ * \ingroup alphabet_composite
  */
 template <typename t>
 struct recursive_required_types
@@ -105,7 +105,7 @@ struct recursive_required_types
 
 /*!\brief Like seqan3::detail::required_types, but recursive.
  * \implements seqan3::transformation_trait
- * \ingroup composite
+ * \ingroup alphabet_composite
  */
 template <typename t>
 //!\cond
@@ -131,7 +131,7 @@ using recursive_required_types_t = typename recursive_required_types<t>::type;
 // ------------------------------------------------------------------
 
 /*!\brief 'Callable' helper class that is invokable by meta::invoke.
- * Returns an std::true_type if the `type` is constructable from `T`.
+ * Returns a std::true_type if the `type` is constructable from `T`.
  */
 template <typename T>
 struct constructible_from
@@ -142,7 +142,7 @@ struct constructible_from
 };
 
 /*!\brief 'Callable' helper class that is invokable by meta::invoke.
- * Returns an std::true_type if the `T` is implicitly convertible to `type`.
+ * Returns a std::true_type if the `T` is implicitly convertible to `type`.
  */
 template <typename T>
 struct implicitly_convertible_from
@@ -153,7 +153,7 @@ struct implicitly_convertible_from
 };
 
 /*!\brief 'Callable' helper class that is invokable by meta::invoke.
- * Returns an std::true_type if the `type` is assignable from `T`.
+ * Returns a std::true_type if the `type` is assignable from `T`.
  */
 template <typename T>
 struct assignable_from
@@ -164,7 +164,7 @@ struct assignable_from
 };
 
 /*!\brief 'Callable' helper class that is invokable by meta::invoke.
- * Returns an std::true_type if the `type` is weakly equality comparable to `T`.
+ * Returns a std::true_type if the `type` is weakly equality comparable to `T`.
  */
 template <typename T>
 struct weakly_equality_comparable_with_
@@ -175,7 +175,7 @@ struct weakly_equality_comparable_with_
 };
 
 /*!\brief 'Callable' helper class that is invokable by meta::invoke.
- * Returns an std::true_type if the `type` is comparable via <,<=,>,>= to `T`.
+ * Returns a std::true_type if the `type` is comparable via <,<=,>,>= to `T`.
  */
 template <typename T>
 struct weakly_ordered_with_
@@ -200,7 +200,6 @@ template <typename ...alternative_types>
     requires (detail::writable_constexpr_alphabet<alternative_types> && ...) &&
              (std::regular<alternative_types> && ...) &&
              (sizeof...(alternative_types) >= 2)
-             //TODO same char_type
 //!\endcond
 class alphabet_variant;
 
