@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2020, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2020, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -28,10 +28,10 @@
 #include <seqan3/argument_parser/detail/format_parse.hpp>
 #include <seqan3/argument_parser/detail/terminal.hpp>
 #include <seqan3/argument_parser/detail/version_check.hpp>
-#include <seqan3/core/char_operations/predicate.hpp>
+#include <seqan3/core/debug_stream/detail/to_string.hpp>
 #include <seqan3/core/detail/test_accessor.hpp>
-#include <seqan3/core/detail/to_string.hpp>
 #include <seqan3/io/stream/concept.hpp>
+#include <seqan3/utility/char_operations/predicate.hpp>
 
 namespace seqan3
 {
@@ -143,7 +143,7 @@ namespace seqan3
  *
  * Users of applications that have this feature activated can opt-out, by either:
  *
- *  * disabling it for a specific application simply by setting the option `--version-check 0` or
+ *  * disabling it for a specific application simply by setting the option `--version-check false/0` or
  *  * disabling it for all applications by setting the `SEQAN3_NO_VERSION_CHECK` environment variable.
  *
  * Note that in case there is no `--version-check` option (display available options with `-h/--help)`,
@@ -164,11 +164,11 @@ public:
 
     /*!\brief Initializes an seqan3::argument_parser object from the command line arguments.
      *
-     * \param[in] app_name       The name of the app that is displayed on the help page.
-     * \param[in] argc           The number of command line arguments.
-     * \param[in] argv           The command line arguments to parse.
-     * \param[in] version_check  Notify users about app version updates (default true).
-     * \param[in] subcommands    A list of subcommands (see \link subcommand_arg_parse subcommand parsing \endlink).
+     * \param[in] app_name The name of the app that is displayed on the help page.
+     * \param[in] argc The number of command line arguments.
+     * \param[in] argv The command line arguments to parse.
+     * \param[in] version_updates Notify users about version updates (default seqan3::update_notifications::on).
+     * \param[in] subcommands A list of subcommands (see \link subcommand_arg_parse subcommand parsing \endlink).
      *
      * \throws seqan3::design_error if the application name contains illegal characters.
      *
@@ -180,20 +180,30 @@ public:
      */
     argument_parser(std::string const app_name,
                     int const argc,
-                    char const * const * const  argv,
-                    bool version_check = true,
+                    char const * const * const argv,
+                    update_notifications version_updates = update_notifications::on,
                     std::vector<std::string> subcommands = {}) :
-        version_check_dev_decision{version_check}
+        version_check_dev_decision{version_updates},
+        subcommands{std::move(subcommands)}
     {
         if (!std::regex_match(app_name, app_name_regex))
-            throw design_error{"The application name must only contain alpha-numeric characters "
-                                               "or '_' and '-' (regex: \"^[a-zA-Z0-9_-]+$\")."};
-        for (auto & sub : subcommands)
-            if (!std::regex_match(sub, std::regex{"^[a-zA-Z0-9_]+$"}))
-                throw design_error{"The subcommand name must only contain alpha-numeric characters or '_'."};
+        {
+            throw design_error{("The application name must only contain alpha-numeric characters or '_' and '-' "
+                               "(regex: \"^[a-zA-Z0-9_-]+$\").")};
+        }
+
+        for (auto & sub : this->subcommands)
+        {
+            if (!std::regex_match(sub, app_name_regex))
+            {
+                throw design_error{"The subcommand name must only contain alpha-numeric characters or '_' and '-' "
+                                   "(regex: \"^[a-zA-Z0-9_-]+$\")."};
+            }
+        }
 
         info.app_name = std::move(app_name);
-        init(argc, argv, std::move(subcommands));
+
+        init(argc, argv);
     }
 
     //!\brief The destructor.
@@ -238,7 +248,7 @@ public:
                     char const short_id,
                     std::string const & long_id,
                     std::string const & desc,
-                    option_spec const spec = option_spec::DEFAULT,
+                    option_spec const spec = option_spec::standard,
                     validator_type option_validator = validator_type{}) // copy to bind rvalues
     {
         if (sub_parser != nullptr)
@@ -263,7 +273,7 @@ public:
                   char const short_id,
                   std::string const & long_id,
                   std::string const & desc,
-                  option_spec const spec = option_spec::DEFAULT)
+                  option_spec const spec = option_spec::standard)
     {
         verify_identifiers(short_id, long_id);
         // copy variables into the lambda because the calls are pushed to a stack
@@ -320,7 +330,7 @@ public:
     /*!\brief Initiates the actual command line parsing.
      *
      * \attention The function must be called at the very end of all parser
-     * related code and should be enclosed in a try catch block.
+     * related code and should be enclosed in a try catch block as the argument parser may throw.
      *
      * \throws seqan3::design_error if this function was already called before.
      *
@@ -344,12 +354,10 @@ public:
      * - **-hh/\--advanced-help** Prints the help page including advanced options.
      * - <b>\--version</b> Prints the version information.
      * - <b>\--export-help [format]</b> Prints the application description in the given format (html/man/ctd).
-     * - <b>\--version-check 0/1</b> Disable/enable update notifications.
+     * - <b>\--version-check false/0/true/1</b> Disable/enable update notifications.
      *
      * Example:
      *
-     * \note Since the argument parser may throw, you should always wrap `parse()` into a try-catch block.
-     *
      * \include test/snippet/argument_parser/argument_parser_2.cpp
      *
      * The code above gives the following output when calling `--help`:
@@ -391,6 +399,13 @@ public:
 
         detail::version_checker app_version{info.app_name, info.version, info.url};
 
+        if (std::holds_alternative<detail::format_parse>(format) && !subcommands.empty() && sub_parser == nullptr)
+        {
+            throw too_few_arguments{detail::to_string("You either forgot or misspelled the subcommand! Please specify"
+                                                      " which sub-program you want to use: one of ", subcommands,
+                                                      ". Use -h/--help for more information.")};
+        }
+
         if (app_version.decide_if_check_is_performed(version_check_dev_decision, version_check_user_decision))
         {
             // must be done before calling parse on the format because this might std::exit
@@ -409,34 +424,91 @@ public:
     {
         if (sub_parser == nullptr)
         {
-            throw design_error("You did not enable subcommand parsing on construction "
-                                      "so you cannot access the sub-parser!");
+            throw design_error("No subcommand was provided at the construction of the argument parser!");
         }
 
         return *sub_parser;
     }
 
+    /*!\brief Checks whether the option identifier (`id`) was set on the command line by the user.
+     * \tparam id_type Either type `char` or a type that a `std::string` is constructible from.
+     * \param[in] id The short (`char`) or long (`std::string`) option identifier to search for.
+     * \returns `true` if option identifier `id` was set on the command line by the user.
+     * \throws seqan3::design_error if the function is used incorrectly (see details below).
+     *
+     * \details
+     *
+     * You can only ask for option identifiers that were added to the parser beforehand via
+     * `seqan3::argument_parser::add_option`.
+     * As in the `seqan3::argument_parser::add_option` call, pass short identifiers as a `char` and long identifiers
+     * as a `std::string` or a type that a `std::string` is constructible from (e.g. a `const char *`).
+     *
+     * ### Example
+     *
+     * \include test/snippet/argument_parser/is_option_set.cpp
+     *
+     * ### Exceptions
+     *
+     * This function throws a seqan3::design_error if
+     * * `seqan3::argument_parser::parse()` was not called before.
+     * * a long identifier was passed (e.g. a `std::string`) that only consists of a single character. If you mean to
+     *   pass a short identifier, please pass it as a `char` not a `std::string`.
+     * * the option identifier cannot be found in the list of valid option identifiers that were added to the parser
+     *   via `seqan3::argument_parser::add_option()` calls beforehand.
+     */
+    template <typename id_type>
+    //!\cond
+        requires std::same_as<id_type, char> || std::constructible_from<std::string, id_type>
+    //!\endcond
+    bool is_option_set(id_type const & id) const
+    {
+        if (!parse_was_called)
+            throw design_error{"You can only ask which options have been set after calling the function `parse()`."};
+
+        // the detail::format_parse::find_option_id call in the end expects either a char or std::string
+        using char_or_string_t = std::conditional_t<std::same_as<id_type, char>, char, std::string>;
+        char_or_string_t short_or_long_id = {id}; // e.g. convert char * to string here if necessary
+
+        if constexpr (!std::same_as<id_type, char>) // long id was given
+        {
+            if (short_or_long_id.size() == 1)
+            {
+                throw design_error{"Long option identifiers must be longer than one character! If " + short_or_long_id +
+                                   "' was meant to be a short identifier, please pass it as a char ('') not a string"
+                                   " (\"\")!"};
+            }
+        }
+
+        if (std::find(used_option_ids.begin(), used_option_ids.end(), std::string{id}) == used_option_ids.end())
+            throw design_error{"You can only ask for option identifiers that you added with add_option() before."};
+
+        // we only need to search for an option before the `end_of_options_indentifier` (`--`)
+        auto end_of_options = std::find(cmd_arguments.begin(), cmd_arguments.end(), end_of_options_indentifier);
+        auto option_it = detail::format_parse::find_option_id(cmd_arguments.begin(), end_of_options, short_or_long_id);
+        return option_it != end_of_options;
+    }
+
     //!\name Structuring the Help Page
     //!\{
 
     /*!\brief Adds an help page section to the seqan3::argument_parser.
      * \param[in] title The title of the section.
-     * \param[in] spec Whether to always display this section title (seqan3::option_spec::DEFAULT), only when showing
-     *                 the advanced help page (seqan3::option_spec::ADVANCED) or never (seqan3::option_spec::HIDDEN).
+     * \param[in] spec Whether to always display this section title (seqan3::option_spec::standard), only when showing
+     *                 the advanced help page (seqan3::option_spec::advanced) or never (seqan3::option_spec::hidden).
      * \details This only affects the help page and other output formats.
      */
-    void add_section(std::string const & title, option_spec const spec = option_spec::DEFAULT)
+    void add_section(std::string const & title, option_spec const spec = option_spec::standard)
     {
         std::visit([&] (auto & f) { f.add_section(title, spec); }, format);
     }
 
     /*!\brief Adds an help page subsection to the seqan3::argument_parser.
      * \param[in] title The title of the subsection.
-     * \param[in] spec Whether to always display this subsection title (seqan3::option_spec::DEFAULT), only when showing
-     *                 the advanced help page (seqan3::option_spec::ADVANCED) or never (seqan3::option_spec::HIDDEN).
+     * \param[in] spec Whether to always display this subsection title (seqan3::option_spec::standard), only when showing
+     *                 the advanced help page (seqan3::option_spec::advanced) or never (seqan3::option_spec::hidden).
      * \details This only affects the help page and other output formats.
      */
-    void add_subsection(std::string const & title, option_spec const spec = option_spec::DEFAULT)
+    void add_subsection(std::string const & title, option_spec const spec = option_spec::standard)
     {
         std::visit([&] (auto & f) { f.add_subsection(title, spec); }, format);
     }
@@ -444,13 +516,13 @@ public:
     /*!\brief Adds an help page text line to the seqan3::argument_parser.
      * \param[in] text The text to print.
      * \param[in] is_paragraph Whether to insert as paragraph or just a line (Default: false).
-     * \param[in] spec Whether to always display this line (seqan3::option_spec::DEFAULT), only when showing
-     *                 the advanced help page (seqan3::option_spec::ADVANCED) or never (seqan3::option_spec::HIDDEN).
+     * \param[in] spec Whether to always display this line (seqan3::option_spec::standard), only when showing
+     *                 the advanced help page (seqan3::option_spec::advanced) or never (seqan3::option_spec::hidden).
      * \details
      * If the line is not a paragraph (false), only one line break is appended, otherwise two line breaks are appended.
      * This only affects the help page and other output formats.
      */
-    void add_line(std::string const & text, bool is_paragraph = false, option_spec const spec = option_spec::DEFAULT)
+    void add_line(std::string const & text, bool is_paragraph = false, option_spec const spec = option_spec::standard)
     {
         std::visit([&] (auto & f) { f.add_line(text, is_paragraph, spec); }, format);
     }
@@ -458,8 +530,8 @@ public:
     /*!\brief Adds an help page list item (key-value) to the seqan3::argument_parser.
      * \param[in] key  The key of the key-value pair of the list item.
      * \param[in] desc The value of the key-value pair of the list item.
-     * \param[in] spec Whether to always display this list item (seqan3::option_spec::DEFAULT), only when showing
-     *                 the advanced help page (seqan3::option_spec::ADVANCED) or never (seqan3::option_spec::HIDDEN).
+     * \param[in] spec Whether to always display this list item (seqan3::option_spec::standard), only when showing
+     *                 the advanced help page (seqan3::option_spec::advanced) or never (seqan3::option_spec::hidden).
      *
      * \details
      *
@@ -473,7 +545,9 @@ public:
      *            Super important integer for age.
      *```
      */
-    void add_list_item(std::string const & key, std::string const & desc, option_spec const spec = option_spec::DEFAULT)
+    void add_list_item(std::string const & key,
+                       std::string const & desc,
+                       option_spec const spec = option_spec::standard)
     {
         std::visit([&] (auto & f) { f.add_list_item(key, desc, spec); }, format);
     }
@@ -537,7 +611,7 @@ private:
     bool has_positional_list_option{false};
 
     //!\brief Set on construction and indicates whether the developer deactivates the version check calls completely.
-    bool version_check_dev_decision{};
+    update_notifications version_check_dev_decision{};
 
     //!\brief Whether the **user** specified to perform the version check (true) or not (false), default unset.
     std::optional<bool> version_check_user_decision;
@@ -551,14 +625,41 @@ private:
     //!\brief Validates the application name to ensure an escaped server call.
     std::regex app_name_regex{"^[a-zA-Z0-9_-]+$"};
 
+    //!\brief Signals the argument parser that no options follow this string but only positional arguments.
+    static constexpr std::string_view const end_of_options_indentifier{"--"};
+
     //!\brief Stores the sub-parser in case \link subcommand_arg_parse subcommand parsing \endlink is enabled.
     std::unique_ptr<argument_parser> sub_parser{nullptr};
 
+    //!\brief Stores the sub-parser names in case \link subcommand_arg_parse subcommand parsing \endlink is enabled.
+    std::vector<std::string> subcommands{};
+
+    /*!\brief The format of the argument parser that decides the behavior when
+     *        calling the seqan3::argument_parser::parse function.
+     *
+     * \details
+     *
+     * The format is set in the function argument_parser::init.
+     */
+    std::variant<detail::format_parse,
+                 detail::format_help,
+                 detail::format_short_help,
+                 detail::format_version,
+                 detail::format_html,
+                 detail::format_man,
+                 detail::format_copyright/*,
+                 detail::format_ctd*/> format{detail::format_help{{}, false}}; // Will be overwritten in any case.
+
+    //!\brief List of option/flag identifiers that are already used.
+    std::set<std::string> used_option_ids{"h", "hh", "help", "advanced-help", "export-help", "version", "copyright"};
+
+    //!\brief The command line arguments.
+    std::vector<std::string> cmd_arguments{};
+
     /*!\brief Initializes the seqan3::argument_parser class on construction.
      *
      * \param[in] argc        The number of command line arguments.
      * \param[in] argv        The command line arguments.
-     * \param[in] subcommands The subcommand key words to split command line arguments into top-level and sub-parser.
      *
      * \throws seqan3::too_few_arguments if option --export-help was specified without a value
      * \throws seqan3::too_few_arguments if option --version-check was specified without a value
@@ -568,7 +669,7 @@ private:
      *
      * \details
      *
-     * This function adds all command line parameters to a std::vector<std::string>
+     * This function adds all command line parameters to the cmd_arguments member variable
      * to take advantage of the vector functionality later on. Additionally,
      * the format member variable is set, depending on which parameters are given
      * by the user:
@@ -587,11 +688,8 @@ private:
      * If `--export-help` is specified with a value other than html/man or ctd
      * an seqan3::argument_parser_error is thrown.
      */
-    void init(int argc, char const * const * const argv, std::vector<std::string> const & subcommands)
+    void init(int argc, char const * const * const argv)
     {
-        // cash command line input, in case --version-check is specified but shall not be passed to format_parse()
-        std::vector<std::string> argv_new{};
-
         if (argc <= 1) // no arguments provided
         {
             format = detail::format_short_help{};
@@ -600,15 +698,20 @@ private:
 
         bool special_format_was_set{false};
 
-        for(int i = 1, argv_len = argc; i < argv_len; ++i) // start at 1 to skip binary name
+
+        for (int i = 1, argv_len = argc; i < argv_len; ++i) // start at 1 to skip binary name
         {
             std::string arg{argv[i]};
 
             if (std::ranges::find(subcommands, arg) != subcommands.end())
             {
-                sub_parser = std::make_unique<argument_parser>(info.app_name + "-" + arg, argc - i, argv + i, false);
+                sub_parser = std::make_unique<argument_parser>(info.app_name + "-" + arg,
+                                                               argc - i,
+                                                               argv + i,
+                                                               update_notifications::off);
                 break;
             }
+
             if (arg == "-h" || arg == "--help")
             {
                 format = detail::format_help{subcommands, false};
@@ -666,31 +769,24 @@ private:
 
                 arg = argv[i];
 
-                if (arg == "1")
+                if (arg == "1" || arg == "true")
                     version_check_user_decision = true;
-                else if (arg == "0")
+                else if (arg == "0" || arg == "false")
                     version_check_user_decision = false;
                 else
-                    throw validation_error{"Value for option --version-check must be 1 or 0."};
+                    throw validation_error{"Value for option --version-check must be true (1) or false (0)."};
 
+                // in case --version-check is specified it shall not be passed to format_parse()
                 argc -= 2;
             }
             else
             {
-                argv_new.push_back(std::move(arg));
+                cmd_arguments.push_back(std::move(arg));
             }
         }
 
         if (!special_format_was_set)
-        {
-            if (!subcommands.empty() && sub_parser == nullptr)
-            {
-                throw too_few_arguments{detail::to_string("Please specify which sub program you want to use ",
-                                        "(one of ", subcommands, "). Use -h/--help for more information.")};
-            }
-
-            format = detail::format_parse(argc, std::move(argv_new));
-        }
+            format = detail::format_parse(argc, cmd_arguments);
     }
 
     //!\brief Adds standard options to the help page.
@@ -704,9 +800,8 @@ private:
         add_list_item("\\fB--copyright\\fP", "Prints the copyright/license information.");
         add_list_item("\\fB--export-help\\fP (std::string)",
                                     "Export the help page information. Value must be one of [html, man].");
-        if (version_check_dev_decision)
-            add_list_item("\\fB--version-check\\fP (bool)", "Whether to to check for the newest app version. Default: 1.");
-        add_subsection(""); // add a new line (todo smehringer) add a add_newline() function
+        if (version_check_dev_decision == update_notifications::on)
+            add_list_item("\\fB--version-check\\fP (bool)", "Whether to check for the newest app version. Default: true.");
     }
 
     /*!\brief Checks whether the long identifier has already been used before.
@@ -754,22 +849,6 @@ private:
         if (detail::format_parse::is_empty_id(short_id) && detail::format_parse::is_empty_id(long_id))
             throw design_error("Option Identifiers cannot both be empty.");
     }
-
-    /*!\brief The format of the argument parser that decides the behavior when
-     * calling the seqan3::argument_parser::parse function.
-     * \details The format is set in the function argument_parser::init.
-     */
-    std::variant<detail::format_parse,
-                 detail::format_help,
-                 detail::format_short_help,
-                 detail::format_version,
-                 detail::format_html,
-                 detail::format_man,
-                 detail::format_copyright/*,
-                 detail::format_ctd*/> format{detail::format_help{{}, false}}; // Will be overwritten in any case.
-
-    //!\brief List of option/flag identifiers that are already used.
-    std::set<std::string> used_option_ids{"h", "hh", "help", "advanced-help", "export-help", "version", "copyright"};
 };
 
 } // namespace seqan3
