@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2020, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2020, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -20,7 +20,6 @@
 #include <seqan3/argument_parser/detail/format_base.hpp>
 #include <seqan3/argument_parser/detail/terminal.hpp>
 #include <seqan3/core/detail/test_accessor.hpp>
-#include <seqan3/version.hpp>
 
 namespace seqan3::detail
 {
@@ -34,6 +33,8 @@ namespace seqan3::detail
  * In addition the needed order would be different from the parse format.
  * Thus the calls are stored (parser_set_up_calls and positional_option_calls)
  * and only evaluated when calling format_help::parse().
+ *
+ * \remark For a complete overview, take a look at \ref argument_parser
  */
 class format_help : public format_help_base<format_help>
 {
@@ -138,9 +139,9 @@ protected:
     void print_subsection(std::string const & title)
     {
         std::ostream_iterator<char> out(std::cout);
-        std::cout << '\n' << to_text("\\fB");
+        std::cout << '\n';
         std::fill_n(out, layout.leftPadding / 2, ' ');
-        std::cout << title << to_text("\\fP") << '\n';
+        std::cout << in_bold(title) << '\n';
         prev_was_paragraph = false;
     }
 
@@ -196,64 +197,10 @@ protected:
         prev_was_paragraph = false;
     }
 
-    //!\brief Prints the version information to std::cout.
-    void print_version()
-    {
-        std::ostream_iterator<char> out(std::cout);
-
-        // Print version, date and url.
-        std::cout << "\n" << to_text("\\fB") << "VERSION" << to_text("\\fP") << "\n";
-        std::fill_n(out, layout.leftPadding, ' ');
-        std::cout << to_text("\\fB") << "Last update: " << to_text("\\fP") << meta.date << "\n";
-        std::fill_n(out, layout.leftPadding, ' ');
-        std::cout << to_text("\\fB") << meta.app_name << " version: " << to_text("\\fP") << meta.version << "\n";
-        std::fill_n(out, layout.leftPadding, ' ');
-        std::cout << to_text("\\fB") << "SeqAn version: " << to_text("\\fP") << SEQAN3_VERSION_MAJOR << '.'
-                  <<  SEQAN3_VERSION_MINOR << '.' << SEQAN3_VERSION_PATCH;
-
-        if (!empty(meta.url))
-        {
-            std::cout <<  "\n" << to_text("\\fB") << "URL" << to_text("\\fP") << "\n";
-            std::fill_n(out, layout.leftPadding, ' ');
-            std::cout << meta.url << "\n";
-        }
-        std::cout << "\n";
-    }
-
     //!\brief Prints a help page footer to std::cout.
     void print_footer()
     {
-        print_version();
-
-        std::ostream_iterator<char> out(std::cout);
-
-        // Print legal stuff
-        if ((!empty(meta.short_copyright)) || (!empty(meta.long_copyright)) || (!empty(meta.citation)))
-        {
-            std::cout << "\n" << to_text("\\fB") << "LEGAL" << to_text("\\fP") << "\n";
-
-            if (!empty(meta.short_copyright))
-            {
-                std::fill_n(out, layout.leftPadding, ' ');
-                std::cout << to_text("\\fB") << meta.app_name << " Copyright: "
-                          << to_text("\\fP") << meta.short_copyright << "\n";
-            }
-            std::fill_n(out, layout.leftPadding, ' ');
-            std::cout << to_text("\\fB") << "SeqAn Copyright: " << to_text("\\fP")
-                      << "2006-2015 Knut Reinert, FU-Berlin; released under the 3-clause BSDL.\n";
-            if (!empty(meta.citation))
-            {
-                std::fill_n(out, layout.leftPadding, ' ');
-                std::cout << to_text("\\fB") << "In your academic works please cite: " << to_text("\\fP")
-                          << meta.citation << "\n";
-            }
-            if (!empty(meta.long_copyright))
-            {
-                std::fill_n(out, layout.leftPadding, ' ');
-                std::cout << "For full copyright and/or warranty information see " << to_text("\\fB")
-                          << "--copyright" << to_text("\\fP") << ".\n";
-            }
-        }
+        // no footer
     }
 
     /*!\brief Formats text for pretty command line printing.
@@ -418,6 +365,15 @@ protected:
             std::cout << '\n';
     }
 
+    /*!\brief Format string in bold.
+     * \param[in] str The input string to format in bold.
+     * \returns The string `str` wrapped in bold formatting.
+     */
+    std::string in_bold(std::string const & str)
+    {
+        return to_text("\\fB") + str + to_text("\\fP");
+    }
+
     //!\brief Needed for correct formatting while calling different print functions.
     bool prev_was_paragraph{false};
 
@@ -436,6 +392,8 @@ protected:
  * The short help message printing is not done immediately, because the user cannot provide
  * meta information (e.g. app_name) on construction of the parser. Thus the meta information is collected
  * and only evaluated when calling seqan3::detail::format_version::parse.
+ *
+ * \remark For a complete overview, take a look at \ref argument_parser
  */
 class format_short_help : public format_help
 {
@@ -466,6 +424,8 @@ public:
  * The version printing is not done immediately, because the user cannot provide
  * meta information on construction of the parser. Thus the meta information is collected
  * and only evaluated when calling format_version::parse().
+ *
+ * \remark For a complete overview, take a look at \ref argument_parser
  */
 class format_version : public format_help
 {
@@ -492,6 +452,8 @@ public:
  * The copyright message printing is not done immediately, because the user cannot provide
  * meta information (e.g. long_copyright) on construction of the parser. Thus the meta information is collected
  * and only evaluated when calling seqan3::detail::format_version::parse.
+ *
+ * \remark For a complete overview, take a look at \ref argument_parser 
  */
 class format_copyright : public format_help
 {
@@ -504,8 +466,8 @@ public:
         meta = parser_meta;
         debug_stream_type stream{std::cout};
         std::string seqan_license{
-R"(Copyright (c) 2006-2020, Knut Reinert & Freie Universität Berlin
-Copyright (c) 2016-2020, Knut Reinert & MPI für molekulare Genetik
+R"(Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
+Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without
@@ -532,8 +494,9 @@ LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
 DAMAGE.)"};
 
-        stream << std::string(80, '=') << to_text("\n\\fB") << "Copyright information for "
-               << meta.app_name << ":\n" << to_text("\\fP") << std::string(80, '-') << '\n';
+        stream << std::string(80, '=') << "\n"
+               << in_bold("Copyright information for " + meta.app_name + ":\n")
+               << std::string(80, '-') << '\n';
 
         if (!empty(meta.long_copyright))
         {
@@ -541,17 +504,18 @@ DAMAGE.)"};
         }
         else if (!empty(meta.short_copyright))
         {
-            stream << to_text("\\fP") << meta.app_name << " full copyright information not available. Displaying"
-                  << " short copyright information instead:\n" << to_text("\\fP") << meta.short_copyright << "\n";
+            stream << in_bold(meta.app_name + " full copyright information not available. " +
+                              "Displaying short copyright information instead:\n" )
+                   << meta.short_copyright << "\n";
         }
         else
         {
             stream << to_text("\\fP") << meta.app_name << " copyright information not available.\n";
         }
 
-        stream << std::string(80, '=') << to_text("\n\\fB")
-              << "This program contains SeqAn code licensed under the following terms:\n" << to_text("\\fP")
-              << std::string(80, '-') << '\n' << seqan_license << '\n';
+        stream << std::string(80, '=') << '\n'
+               << in_bold("This program contains SeqAn code licensed under the following terms:\n")
+               << std::string(80, '-') << '\n' << seqan_license << '\n';
 
         std::exit(EXIT_SUCCESS);
     }
