@@ -48,6 +48,8 @@ namespace seqan3::detail
  * When parsing flags and options, the identifiers (and values) are removed from
  * the vector format_parse::argv. That way, options that are specified multiple times,
  * but are no container type, can be identified and an error is reported.
+ *
+ * \remark For a complete overview, take a look at \ref argument_parser 
  */
 class format_parse : public format_base
 {
@@ -451,7 +453,7 @@ private:
         if (res == option_parse_result::error)
         {
             throw user_input_error{msg + "Argument " + input_value + " could not be parsed as type " +
-                                   get_type_name_as_string(input_value) + "."};
+                                   get_type_name_as_string(option_type{}) + "."};
         }
 
         if constexpr (arithmetic<option_type>)
@@ -467,7 +469,7 @@ private:
         assert(res == option_parse_result::success); // if nothing was thrown, the result must have been a success
     }
 
-    /*!\brief Handles value retrieval for options based on different kev value pairs.
+    /*!\brief Handles value retrieval for options based on different key-value pairs.
      *
      * \param[out] value     Stores the value found in argv, parsed by parse_option_value.
      * \param[in]  option_it The iterator where the option identifier was found.
