@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2020, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2020, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -12,23 +12,22 @@
 
 #pragma once
 
+#include <seqan3/std/algorithm>
 #include <atomic>
+#include <seqan3/std/bit>
 #include <cmath>
+#include <seqan3/std/concepts>
 #include <mutex>
-#include <new>
+#include <seqan3/std/new>
+#include <seqan3/std/ranges>
 #include <shared_mutex>
+#include <seqan3/std/span>
 #include <type_traits>
 #include <vector>
 
-#include <seqan3/core/bit_manipulation.hpp>
-#include <seqan3/core/parallel/detail/spin_delay.hpp>
-#include <seqan3/core/type_traits/range.hpp>
-#include <seqan3/range/container/concept.hpp>
-#include <seqan3/std/algorithm>
-#include <seqan3/std/concepts>
-#include <seqan3/std/new>
-#include <seqan3/std/ranges>
-#include <seqan3/std/span>
+#include <seqan3/core/range/type_traits.hpp>
+#include <seqan3/utility/container/concept.hpp>
+#include <seqan3/utility/parallel/detail/spin_delay.hpp>
 
 namespace seqan3::contrib
 {
@@ -110,7 +109,7 @@ public:
     explicit buffer_queue(size_type const init_capacity)
     {
         buffer.resize(init_capacity + 1);
-        ring_buffer_capacity = seqan3::detail::next_power_of_two(buffer.size());
+        ring_buffer_capacity = std::bit_ceil(buffer.size());
     }
 
     template <std::ranges::input_range range_type>
@@ -169,15 +168,18 @@ public:
         value_type value{};
         for (;;)
         {
-            auto status = try_pop(value);
+            if (!writer_waiting.load())
+            {
+                auto status = try_pop(value);
 
-            if (status == queue_op_status::closed)
-                throw queue_op_status::closed;
-            else if (status == queue_op_status::success)
-                return value;
+                if (status == queue_op_status::closed)
+                    throw queue_op_status::closed;
+                else if (status == queue_op_status::success)
+                    return value;
 
-            assert(status != queue_op_status::full);
-            assert(status == queue_op_status::empty);
+                assert(status != queue_op_status::full);
+                assert(status == queue_op_status::empty);
+            }
             delay.wait(); // pause and then try again.
         }
     }
@@ -189,13 +191,16 @@ public:
         queue_op_status status;
         for (;;)
         {
-            status = try_pop(value);
+            if (!writer_waiting.load())
+            {
+                status = try_pop(value);
 
-            if (status == queue_op_status::closed || status == queue_op_status::success)
-                break;
+                if (status == queue_op_status::closed || status == queue_op_status::success)
+                    break;
 
-            assert(status != queue_op_status::full);
-            assert(status == queue_op_status::empty);
+                assert(status != queue_op_status::full);
+                assert(status == queue_op_status::empty);
+            }
             delay.wait(); // pause and then try again.
         }
         return status;
@@ -215,14 +220,27 @@ public:
     /*!\name State operations
      * \{
      */
-    void close() noexcept
+    void close()
     {
-        closed_flag.store(true, std::memory_order_release);
+        if (writer_waiting.exchange(true)) // First writer that closes the queue will continue, the rest returns.
+            return;
+
+        try
+        {
+            std::unique_lock write_lock{mutex};
+            closed_flag = true;
+            writer_waiting.store(false); // reset the lock.
+        }
+        catch (...)
+        {
+            writer_waiting.store(false); // reset the lock.
+            std::rethrow_exception(std::current_exception());
+        }
     }
 
     bool is_closed() const noexcept
     {
-        return closed_flag.load(std::memory_order_acquire);
+        return closed_flag;
     }
 
     bool is_empty() const noexcept
@@ -339,7 +357,8 @@ private:
     alignas(std::hardware_destructive_interference_size) std::atomic<size_type>    push_back_position{0};
     alignas(std::hardware_destructive_interference_size) std::atomic<size_type>    pending_push_back_position{0};
     alignas(std::hardware_destructive_interference_size) std::atomic<size_type>    ring_buffer_capacity{0};
-    alignas(std::hardware_destructive_interference_size) std::atomic<bool>         closed_flag{false};
+    alignas(std::hardware_destructive_interference_size) std::atomic_bool          writer_waiting{false};
+    alignas(std::hardware_destructive_interference_size) bool                      closed_flag{false};
 };
 
 // Specifies a fixed size buffer queue.
@@ -401,7 +420,7 @@ inline bool buffer_queue<value_t, buffer_t, buffer_policy>::overflow(value2_t &&
 
         // increase capacity by one and move all elements from current pop_front_position one to the right.
         buffer.resize(old_size + 1);
-        ring_buffer_capacity = seqan3::detail::next_power_of_two(buffer.size());
+        ring_buffer_capacity = std::bit_ceil(buffer.size());
         std::ranges::move_backward(std::span{buffer.data() + front_buffer_position, buffer.data() + old_size},
                                    buffer.data() + buffer.size());
 
@@ -440,7 +459,7 @@ template <typename value_t, typename buffer_t, buffer_queue_policy buffer_policy
 inline queue_op_status buffer_queue<value_t, buffer_t, buffer_policy>::try_pop(value_t & result)
 {
     // try to extract a value
-    std::shared_lock  read_lock{mutex};
+    std::shared_lock read_lock{mutex};
 
     size_type local_pending_pop_front_position{};
     size_type next_local_pop_front_position{};
