@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2020, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2020, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -14,13 +14,8 @@
 
 #include <iostream>
 
-#include <seqan3/alignment/aligned_sequence/aligned_sequence_concept.hpp>
-#include <seqan3/core/detail/debug_stream_alphabet.hpp>
-#include <seqan3/core/detail/debug_stream_optional.hpp>
-#include <seqan3/core/detail/debug_stream_range.hpp>
-#include <seqan3/core/detail/debug_stream_tuple.hpp>
-#include <seqan3/core/detail/debug_stream_type.hpp>
-#include <seqan3/core/detail/debug_stream_variant.hpp>
+#include <seqan3/alphabet/detail/debug_stream_alphabet.hpp>
+#include <seqan3/core/debug_stream/all.hpp>
 
 // forward declare
 //!\cond
@@ -38,7 +33,7 @@ namespace seqan3
 // ------------------------------------------------------------------
 
 //!\brief A global instance of seqan3::debug_stream_type.
-//!\ingroup stream
+//!\ingroup core_debug_stream
 inline debug_stream_type debug_stream{std::cerr};
 
 } // namespace seqan3
