@@ -19,7 +19,7 @@
 #include <vector>
 
 #include <seqan3/core/detail/template_inspection.hpp>
-#include <seqan3/utility/detail/exposition_only_concept.hpp>
+#include <seqan3/utility/concept/exposition_only/core_language.hpp>
 #include <seqan3/utility/detail/to_little_endian.hpp>
 #include <seqan3/utility/type_pack/traits.hpp>
 
@@ -114,13 +114,13 @@ struct bgzf_compression
  * \ingroup io
  */
 using compression_formats = pack_traits::drop_front<void
-                                                    #if SEQAN3_HAS_ZLIB
+                                                    #if defined(SEQAN3_HAS_ZLIB)
                                                     , gz_compression
                                                     , bgzf_compression
-                                                    #endif // SEQAN3_HAS_ZLIB
-                                                    #if SEQAN3_HAS_BZIP2
+                                                    #endif // defined(SEQAN3_HAS_ZLIB)
+                                                    #if defined(SEQAN3_HAS_BZIP2)
                                                     , bz2_compression
-                                                    #endif // SEQAN3_HAS_BZIP2
+                                                    #endif // defined(SEQAN3_HAS_BZIP2)
                                                     #if SEQAN3_HAS_ZSTD
                                                     , zstd_compression
                                                     #endif // SEQAN3_HAS_ZSTD
