@@ -19,8 +19,6 @@
 
 #include <seqan3/alphabet/concept.hpp>
 #include <seqan3/alphabet/views/to_char.hpp>
-#include <seqan3/io/detail/istreambuf_view.hpp>
-#include <seqan3/io/detail/take_until_view.hpp>
 #include <seqan3/io/sam_file/detail/cigar.hpp>
 #include <seqan3/io/sam_file/detail/format_sam_base.hpp>
 #include <seqan3/io/sam_file/header.hpp>
@@ -31,6 +29,8 @@
 #include <seqan3/io/sequence_file/input_format_concept.hpp>
 #include <seqan3/io/sequence_file/output_options.hpp>
 #include <seqan3/io/stream/detail/fast_ostreambuf_iterator.hpp>
+#include <seqan3/io/views/detail/istreambuf_view.hpp>
+#include <seqan3/io/views/detail/take_until_view.hpp>
 #include <seqan3/utility/detail/type_name_as_string.hpp>
 #include <seqan3/utility/tuple/concept.hpp>
 #include <seqan3/utility/views/slice.hpp>
@@ -110,6 +110,8 @@ namespace seqan3
  *
  * The SAM header (if present) is read/written once in the beginning before the
  * first record is read/written.
+ *
+ * \remark For a complete overview, take a look at \ref io_sam_file
  */
 class format_sam : private detail::format_sam_base
 {
@@ -134,18 +136,6 @@ public:
     };
 
 protected:
-#ifdef SEQAN3_DEPRECATED_310
-    template <typename stream_type,     // constraints checked by file
-              typename seq_legal_alph_type, bool seq_qual_combined,
-              typename seq_type,        // other constraints checked inside function
-              typename id_type,
-              typename qual_type>
-    void read_sequence_record(stream_type & stream,
-                              sequence_file_input_options<seq_legal_alph_type, seq_qual_combined> const & options,
-                              seq_type & sequence,
-                              id_type & id,
-                              qual_type & qualities);
-#else // ^^^ before seqan 3.1 / after seqan 3.1 vvv
     template <typename stream_type,     // constraints checked by file
               typename seq_legal_alph_type,
               typename seq_type,        // other constraints checked inside function
@@ -156,7 +146,6 @@ protected:
                               seq_type & sequence,
                               id_type & id,
                               qual_type & qualities);
-#endif // SEQAN3_DEPRECATED_310
 
     template <typename stream_type,     // constraints checked by file
               typename seq_type,        // other constraints checked inside function
@@ -289,18 +278,6 @@ private:
 };
 
 //!\copydoc sequence_file_input_format::read_sequence_record
-#ifdef SEQAN3_DEPRECATED_310
-template <typename stream_type,     // constraints checked by file
-          typename seq_legal_alph_type, bool seq_qual_combined,
-          typename seq_type,        // other constraints checked inside function
-          typename id_type,
-          typename qual_type>
-inline void format_sam::read_sequence_record(stream_type & stream,
-                                             sequence_file_input_options<seq_legal_alph_type, seq_qual_combined> const & options,
-                                             seq_type & sequence,
-                                             id_type & id,
-                                             qual_type & qualities)
-#else // ^^^ before seqan 3.1 / after seqan 3.1 vvv
 template <typename stream_type,     // constraints checked by file
           typename seq_legal_alph_type,
           typename seq_type,        // other constraints checked inside function
@@ -311,23 +288,9 @@ inline void format_sam::read_sequence_record(stream_type & stream,
                                              seq_type & sequence,
                                              id_type & id,
                                              qual_type & qualities)
-#endif // SEQAN3_DEPRECATED_310
 {
     sam_file_input_options<seq_legal_alph_type> align_options;
 
-#ifdef SEQAN3_DEPRECATED_310
-    if constexpr (seq_qual_combined)
-    {
-        tmp_qual.clear();
-        read_alignment_record(stream, align_options, std::ignore, default_header, sequence, tmp_qual, id,
-                              std::ignore, std::ignore, std::ignore, std::ignore, std::ignore, std::ignore,
-                              std::ignore, std::ignore, std::ignore, std::ignore, std::ignore, std::ignore);
-
-        for (auto sit = tmp_qual.begin(), dit = std::ranges::begin(sequence); sit != tmp_qual.end(); ++sit, ++dit)
-            get<1>(*dit).assign_char(*sit);
-    }
-    else
-#endif // SEQAN3_DEPRECATED_310
     {
         read_alignment_record(stream, align_options, std::ignore, default_header, sequence, qualities, id,
                               std::ignore, std::ignore, std::ignore, std::ignore, std::ignore, std::ignore,
@@ -796,7 +759,7 @@ inline void format_sam::write_alignment_record(stream_type & stream,
     }
 
     if (ref_offset.has_value() && (ref_offset.value() + 1) < 0)
-        throw format_error{"The ref_offset object must be an std::integral >= 0."};
+        throw format_error{"The ref_offset object must be a std::integral >= 0."};
 
     // ---------------------------------------------------------------------
     // Writing the Header on first call
@@ -1154,7 +1117,7 @@ inline void format_sam::write_range_or_asterisk(stream_it_t & stream_it, char co
 template <typename stream_it_t>
 inline void format_sam::write_tag_fields(stream_it_t & stream_it, sam_tag_dictionary const & tag_dict, char const separator)
 {
-    auto const stream_variant_fn = [&stream_it] (auto && arg) // helper to print an std::variant
+    auto const stream_variant_fn = [&stream_it] (auto && arg) // helper to print a std::variant
     {
         using T = std::remove_cvref_t<decltype(arg)>;
 
