@@ -25,15 +25,15 @@
 #include <seqan3/alphabet/views/to_char.hpp>
 #include <seqan3/core/range/detail/misc.hpp>
 #include <seqan3/core/range/type_traits.hpp>
-#include <seqan3/io/detail/istreambuf_view.hpp>
 #include <seqan3/io/detail/misc.hpp>
-#include <seqan3/io/detail/take_line_view.hpp>
-#include <seqan3/io/detail/take_until_view.hpp>
 #include <seqan3/io/sequence_file/input_format_concept.hpp>
 #include <seqan3/io/sequence_file/input_options.hpp>
 #include <seqan3/io/sequence_file/output_format_concept.hpp>
 #include <seqan3/io/sequence_file/output_options.hpp>
 #include <seqan3/io/stream/detail/fast_ostreambuf_iterator.hpp>
+#include <seqan3/io/views/detail/istreambuf_view.hpp>
+#include <seqan3/io/views/detail/take_line_view.hpp>
+#include <seqan3/io/views/detail/take_until_view.hpp>
 #include <seqan3/utility/char_operations/predicate.hpp>
 #include <seqan3/utility/detail/type_name_as_string.hpp>
 #include <seqan3/utility/views/repeat_n.hpp>
@@ -43,7 +43,7 @@ namespace seqan3
 /*!\brief The EMBL format.
  * \implements seqan3::sequence_file_input_format
  * \implements seqan3::sequence_file_output_format
- * \ingroup sequence_file
+ * \ingroup io_sequence_file
  *
  * \details
  *
@@ -68,6 +68,7 @@ namespace seqan3
  *
  * Passed qualities to either the read or write function are ignored.
  *
+ * \remark For a complete overview, take a look at \ref io_sequence_file
  */
 class format_embl
 {
@@ -92,18 +93,6 @@ public:
 
 protected:
     //!\copydoc sequence_file_input_format::read_sequence_record
-#ifdef SEQAN3_DEPRECATED_310
-    template <typename stream_type,     // constraints checked by file
-              typename seq_legal_alph_type, bool seq_qual_combined,
-              typename seq_type,        // other constraints checked inside function
-              typename id_type,
-              typename qual_type>
-    void read_sequence_record(stream_type & stream,
-                              sequence_file_input_options<seq_legal_alph_type, seq_qual_combined> const & options,
-                              seq_type    & sequence,
-                              id_type     & id,
-                              qual_type   & SEQAN3_DOXYGEN_ONLY(qualities))
-#else // ^^^ before seqan 3.1 / after seqan 3.1 vvv
     template <typename stream_type,     // constraints checked by file
               typename seq_legal_alph_type,
               typename seq_type,        // other constraints checked inside function
@@ -114,7 +103,6 @@ protected:
                               seq_type    & sequence,
                               id_type     & id,
                               qual_type   & SEQAN3_DOXYGEN_ONLY(qualities))
-#endif // SEQAN3_DEPRECATED_310
     {
         auto stream_view = detail::istreambuf(stream);
         auto stream_it = std::ranges::begin(stream_view);
