@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2020, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2020, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -13,31 +13,31 @@
 #pragma once
 
 #include <cassert>
+#include <seqan3/std/filesystem>
 #include <fstream>
 #include <string>
 #include <variant>
 #include <vector>
+
 #include <seqan3/alphabet/adaptation/char.hpp>
 #include <seqan3/alphabet/aminoacid/aa27.hpp>
-#include <seqan3/alphabet/nucleotide/dna5.hpp>
 #include <seqan3/alphabet/nucleotide/dna15.hpp>
+#include <seqan3/alphabet/nucleotide/dna5.hpp>
 #include <seqan3/alphabet/quality/phred42.hpp>
 #include <seqan3/alphabet/quality/qualified.hpp>
-#include <seqan3/core/detail/pack_algorithm.hpp>
-#include <seqan3/core/type_list/traits.hpp>
-#include <seqan3/io/stream/concept.hpp>
-#include <seqan3/io/exception.hpp>
-#include <seqan3/std/filesystem>
-#include <seqan3/io/record.hpp>
 #include <seqan3/io/detail/in_file_iterator.hpp>
 #include <seqan3/io/detail/misc_input.hpp>
 #include <seqan3/io/detail/record.hpp>
-#include <seqan3/io/sequence_file/input_format_concept.hpp>
+#include <seqan3/io/exception.hpp>
+#include <seqan3/io/sam_file/format_sam.hpp>
 #include <seqan3/io/sequence_file/format_embl.hpp>
 #include <seqan3/io/sequence_file/format_fasta.hpp>
 #include <seqan3/io/sequence_file/format_fastq.hpp>
 #include <seqan3/io/sequence_file/format_genbank.hpp>
-#include <seqan3/io/alignment_file/format_sam.hpp>
+#include <seqan3/io/sequence_file/input_format_concept.hpp>
+#include <seqan3/io/sequence_file/record.hpp>
+#include <seqan3/io/stream/concept.hpp>
+#include <seqan3/utility/type_list/traits.hpp>
 
 namespace seqan3
 {
@@ -48,17 +48,15 @@ namespace seqan3
 
 /*!\interface seqan3::sequence_file_input_traits <>
  * \brief The requirements a traits_type for seqan3::sequence_file_input must meet.
- * \ingroup sequence
+ * \ingroup io_sequence_file
  */
 /*!\name Requirements for seqan3::sequence_file_input_traits
  * \brief You can expect these **member types** of all types that satisfy seqan3::sequence_file_input_traits.
  * \memberof seqan3::sequence_file_input_traits
  *
- * \details
+ * \remark For a complete overview, take a look at \ref io_sequence_file
  *
- * Note that the alphabet type of the seqan3::field::seq_qual cannot be specified directly, it is always
- * seqan3::qualified<sequence_alphabet, quality_alphabet> and the container type templates for
- * the field are those of seqan3::field::seq.
+ * \details
  *
  * \{
  */
@@ -118,7 +116,7 @@ SEQAN3_CONCEPT sequence_file_input_traits = requires (t v)
 
 /*!\brief The default traits for seqan3::sequence_file_input
  * \implements sequence_file_input_traits
- * \ingroup sequence
+ * \ingroup io_sequence_file
  *
  * \details
  *
@@ -128,6 +126,8 @@ SEQAN3_CONCEPT sequence_file_input_traits = requires (t v)
  * This example will make the file read into a smaller alphabet and a compressed container:
  *
  * \include test/snippet/io/sequence_file/sequence_file_input_trait_overwrite.cpp
+ *
+ * \remark For a complete overview, take a look at \ref io_sequence_file
  */
 struct sequence_file_input_default_traits_dna
 {
@@ -164,7 +164,7 @@ struct sequence_file_input_default_traits_dna
 };
 
 //!\brief A traits type that specifies input as amino acids.
-//!\ingroup sequence
+//!\ingroup io_sequence_file
 struct sequence_file_input_default_traits_aa : sequence_file_input_default_traits_dna
 {
     /*!\name Member types
@@ -185,9 +185,10 @@ struct sequence_file_input_default_traits_aa : sequence_file_input_default_trait
 // ----------------------------------------------------------------------------
 
 /*!\brief A class for reading sequence files, e.g. FASTA, FASTQ ...
- * \ingroup sequence
+ * \ingroup io_sequence_file
  * \tparam traits_type          An auxiliary type that defines certain member types and constants, must satisfy
  *                              seqan3::sequence_file_input_traits.
+ *                              (Default: seqan3::sequence_file_input_default_traits_dna)
  * \tparam selected_field_ids   A seqan3::fields type with the list and order of desired record entries; all fields
  *                              must be in seqan3::sequence_file_input::field_ids.
  * \tparam valid_formats        A seqan3::type_list of the selectable formats (each must meet
@@ -195,113 +196,9 @@ struct sequence_file_input_default_traits_aa : sequence_file_input_default_trait
  *
  * \details
  *
- * ### Introduction
+ * \include{doc} doc/fragments/sequence_file_input.md
  *
- * Sequence files are the most generic and common biological files. Well-known formats include
- * FastA and FastQ, but some may also be interested in treating SAM or BAM files as sequence
- * files, discarding the alignment.
- *
- * The Sequence file abstraction supports reading four different fields:
- *
- *   1. seqan3::field::seq
- *   2. seqan3::field::id
- *   3. seqan3::field::qual
- *   4. seqan3::field::seq_qual (sequence and qualities in one range)
- *
- * The first three fields are retrieved by default (and in that order). The last field may be selected to have
- * sequence and qualities directly stored in a more memory-efficient combined container. If you select the last
- * field you may not select seqan3::field::seq or seqan3::field::qual.
- *
- * ### Construction and specialisation
- *
- * This class comes with two constructors, one for construction from a file name and one for construction from
- * an existing stream and a known format. The first one automatically picks the format based on the extension
- * of the file name. The second can be used if you have a non-file stream, like std::cin or std::istringstream,
- * that you want to read from and/or if you cannot use file-extension based detection, but know that your input
- * file has a certain format.
- *
- * In most cases the template parameters are deduced completely automatically:
- *
- * \include test/snippet/io/sequence_file/sequence_file_input_template_deduction.cpp
- * Reading from an std::istringstream:
- * \include test/snippet/io/sequence_file/sequence_file_input_istringstream.cpp
- *
- * Note that this is not the same as writing `sequence_file_input<>` (with angle brackets). In the latter case they are
- * explicitly set to their default values, in the former case
- * [automatic deduction](https://en.cppreference.com/w/cpp/language/class_template_argument_deduction) happens which
- * chooses different parameters depending on the constructor arguments. For opening from file, `sequence_file_input<>`
- * would have also worked, but for opening from stream it would not have.
- *
- * In some cases, you do need to specify the arguments, e.g. if you want to read amino acids:
- *
- * \include test/snippet/io/sequence_file/sequence_file_input_aminoacid.cpp
- *
- * You can define your own traits type to further customise the types used by and returned by this class, see
- * seqan3::sequence_file_default_traits_dna for more details. As mentioned above, specifying at least one
- * template parameter yourself means that you loose automatic deduction so if you want to read amino acids **and**
- * want to read from a string stream you need to give all types yourself:
- *
- * \include test/snippet/io/sequence_file/sequence_file_input_template_specification.cpp
- *
- * ### Reading record-wise
- *
- * You can iterate over this file record-wise:
- *
- * \include test/snippet/io/sequence_file/sequence_file_input_record_iter.cpp
- *
- * In the above example, rec has the type \ref record_type which is a specialisation of seqan3::record and behaves
- * like an std::tuple (that's why we can access it via get). Instead of using the seqan3::field based interface on
- * the record, you could also use `std::get<0>` or even `std::get<dna4_vector>` to retrieve the sequence, but it is
- * not recommended, because it is more error-prone.
- *
- * *Note:* It is important to write `auto &` and not just `auto`, otherwise you will copy the record on every iteration.
- * Since the buffer gets "refilled" on every iteration, you can also move the data out of the record if you want
- * to store it somewhere without copying:
- *
- * \include test/snippet/io/sequence_file/sequence_file_input_auto_ref.cpp
- *
- * ### Reading record-wise (decomposed records)
- *
- * Instead of using `get` on the record, you can also use
- * [structured bindings](https://en.cppreference.com/w/cpp/language/structured_binding)
- * to decompose the record into its elements:
- *
- * \include test/snippet/io/sequence_file/sequence_file_input_decomposed.cpp
- *
- * In this case you immediately get the two elements of the tuple: `seq` of \ref sequence_type and `id` of
- * \ref id_type. **But beware: with structured bindings you do need to get the order of elements correctly!**
- *
- * ### Reading record-wise (custom fields)
- *
- * If you want to skip specific fields from the record you can pass a non-empty fields trait object to the
- * sequence_file_input constructor to select the fields that should be read from the input. For example to choose a
- * combined field for SEQ and QUAL (see above). Or to never actually read the QUAL, if you don't need it.
- * The following snippets demonstrate the usage of such a fields trait object.
- *
- * \include test/snippet/io/sequence_file/sequence_file_input_custom_fields.cpp
- *
- * When reading a file, all fields not present in the file (but requested implicitly or via the `selected_field_ids`
- * parameter) are ignored.
- *
- * ### Views on files
- *
- * Since SeqAn files are ranges, you can also create views over files. A useful example is to filter the records
- * based on certain criteria, e.g. minimum length of the sequence field:
- *
- * \include test/snippet/io/sequence_file/sequence_file_input_file_view.cpp
- *
- * ### End of file
- *
- * You can check whether a file is at end by comparing begin() and end() (if they are the same, the file is at end).
- *
- * ### Formats
- *
- * We currently support reading the following formats:
- *   * seqan3::format_fasta
- *   * seqan3::format_fastq
- *   * seqan3::format_embl
- *   * seqan3::format_genbank
- *   * seqan3::format_sam
+ * \remark For a complete overview, take a look at \ref io_sequence_file
  */
 
 template <
@@ -332,7 +229,7 @@ public:
     /*!\brief The subset of seqan3::field IDs that are valid for this file; order corresponds to the types in
      * \ref field_types.
      */
-    using field_ids            = fields<field::seq, field::id, field::qual, field::seq_qual>;
+    using field_ids            = fields<field::seq, field::id, field::qual>;
 
     static_assert([] () constexpr
                   {
@@ -344,14 +241,6 @@ public:
                   "You selected a field that is not valid for sequence files, please refer to the documentation "
                   "of sequence_file_input::field_ids for the accepted values.");
 
-    static_assert([] () constexpr
-                  {
-                      return !(selected_field_ids::contains(field::seq_qual) &&
-                               (selected_field_ids::contains(field::seq) ||
-                               (selected_field_ids::contains(field::qual))));
-                  }(),
-                  "You may not select field::seq_qual and either of field::seq and field::qual at the same time.");
-
     /*!\name Field types and record type
      * \brief These types are relevant for record/row-based reading; they may be manipulated via the \ref traits_type
      * to achieve different storage behaviour.
@@ -366,17 +255,14 @@ public:
     //!\brief The type of field::qual (std::vector <seqan3::phred42> by default).
     using quality_type          = typename traits_type::template quality_container<
                                     typename traits_type::quality_alphabet>;
-    //!\brief The type of field::seq_qual (std::vector <seqan3::dna5q> by default).
-    using sequence_quality_type = typename traits_type::
-                                    template sequence_container<qualified<typename traits_type::sequence_alphabet,
-                                                                          typename traits_type::quality_alphabet>>;
-
     //!\brief The previously defined types aggregated in a seqan3::type_list.
-    using field_types           = type_list<sequence_type, id_type, quality_type, sequence_quality_type>;
+    using field_types           = type_list<sequence_type, id_type, quality_type>;
 
     //!\brief The type of the record, a specialisation of seqan3::record; acts as a tuple of the selected field types.
-    using record_type           = record<detail::select_types_with_ids_t<field_types, field_ids, selected_field_ids>,
-                                         selected_field_ids>;
+    using record_type           = sequence_record<detail::select_types_with_ids_t<field_types,
+                                                                                  field_ids,
+                                                                                  selected_field_ids>,
+                                                  selected_field_ids>;
     //!\}
 
     /*!\name Range associated types
@@ -448,7 +334,16 @@ public:
         secondary_stream = detail::make_secondary_istream(*primary_stream, filename);
 
         // initialise format handler or throw if format is not found
-        detail::set_format(format, filename);
+        using format_variant_t = typename detail::variant_from_tags<valid_formats,
+                                                                    detail::sequence_file_input_format_exposer>::type;
+        format_variant_t format_variant{};
+        detail::set_format(format_variant, filename);
+
+        std::visit([&] (auto && selected_format)
+        {
+            using format_t = std::remove_cvref_t<decltype(selected_format)>;
+            format = std::make_unique<selected_sequence_format<format_t>>();
+        }, format_variant);
     }
     /* NOTE(h-2): Curiously we do not need a user-defined deduction guide for the above constructor.
      * A combination of default template parameters and auto-deduction guides works as expected,
@@ -480,7 +375,7 @@ public:
                         file_format        const & SEQAN3_DOXYGEN_ONLY(format_tag),
                         selected_field_ids const & SEQAN3_DOXYGEN_ONLY(fields_tag) = selected_field_ids{}) :
         primary_stream{&stream, stream_deleter_noop},
-        format{detail::sequence_file_input_format_exposer<file_format>{}}
+        format{std::make_unique<selected_sequence_format<file_format>>()}
     {
         static_assert(list_traits::contains<file_format, valid_formats>,
                       "You selected a format that is not in the valid_formats of this file.");
@@ -499,7 +394,7 @@ public:
                         file_format        const & SEQAN3_DOXYGEN_ONLY(format_tag),
                         selected_field_ids const & SEQAN3_DOXYGEN_ONLY(fields_tag) = selected_field_ids{}) :
         primary_stream{new stream_t{std::move(stream)}, stream_deleter_default},
-        format{detail::sequence_file_input_format_exposer<file_format>{}}
+        format{std::make_unique<selected_sequence_format<file_format>>()}
     {
         static_assert(list_traits::contains<file_format, valid_formats>,
                       "You selected a format that is not in the valid_formats of this file.");
@@ -586,9 +481,10 @@ public:
     }
     //!\}
 
+    //!\brief The input file options type.
+    using sequence_file_input_options_type = sequence_file_input_options<typename traits_type::sequence_legal_alphabet>;
     //!\brief The options are public and its members can be set directly.
-    sequence_file_input_options<typename traits_type::sequence_legal_alphabet,
-                             selected_field_ids::contains(field::seq_qual)> options;
+    sequence_file_input_options_type options;
 
 protected:
     //!\privatesection
@@ -621,14 +517,9 @@ protected:
     bool first_record_was_read{false};
     //!\brief File is at position 1 behind the last record.
     bool at_end{false};
-
-    //!\brief Type of the format, an std::variant over the `valid_formats`.
-    using format_type = typename detail::variant_from_tags<valid_formats,
-                                                           detail::sequence_file_input_format_exposer>::type;
-    //!\brief The actual std::variant holding a pointer to the detected/selected format.
-    format_type format;
     //!\}
 
+private:
     //!\brief Tell the format to move to the next record and update the buffer.
     void read_next_record()
     {
@@ -643,28 +534,93 @@ protected:
             return;
         }
 
-        assert(!format.valueless_by_exception());
-        std::visit([&] (auto & f)
+        format->read_sequence_record(*secondary_stream, record_buffer, options);
+    }
+
+    /*!\brief An abstract base class to store the selected input format.
+     *
+     * \details
+     *
+     * This abstract base class is used to store the user given input format as a type-erased base class in a
+     * std::unique_ptr. There is exactly one derived type that implements this abstract base class called
+     * seqan3::sequence_file_input::selected_sequence_format which is a private subclass of
+     * seqan3::sequence_file_input. It is not exposed to the user and allows to hide the implementation detail of
+     * storing a specfic format instance which is first known at runtime.
+     */
+    struct sequence_format_base
+    {
+        /*!\name Constructors, destructor and assignment
+         * \{
+         */
+        sequence_format_base() = default; //!< Default.
+        sequence_format_base(sequence_format_base const &) = default; //!< Default.
+        sequence_format_base(sequence_format_base &&) = default; //!< Default.
+        sequence_format_base & operator=(sequence_format_base const &) = default; //!< Default.
+        sequence_format_base & operator=(sequence_format_base &&) = default; //!< Default.
+        virtual ~sequence_format_base() = default; //!< Virtual default.
+        //!\}
+
+        /*!\brief Reads the next format specific record from the given istream.
+         *
+         * \param[in, out] instream The input stream to extract the next record from.
+         * \param[in, out] record_buffer The record buffer to fill.
+         * \param[in] options User specific format options set from outside.
+         *
+         * \details
+         *
+         * Invokes the actual read sequence record function for the selected format and fills the record accordingly.
+         */
+        virtual void read_sequence_record(std::istream & instream,
+                                          record_type & record_buffer,
+                                          sequence_file_input_options_type const & options) = 0;
+    };
+
+    /*!\brief The specific selected format to read the records from.
+     *
+     * \tparam format_t The user specific format type to store.
+     *
+     * \details
+     *
+     * This class implements the format specific read operation based on the instantiated format type.
+     * The specfic format type is selected at runtime and stored through a pointer to the abstract
+     * seqan3::sequence_file_input::sequence_format_base class. A virtual function call then ensures that the
+     * specific read record function of the selected format is invoked.
+     */
+    template <typename format_t>
+    struct selected_sequence_format final : public sequence_format_base
+    {
+        /*!\name Constructors, destructor and assignment
+         * \{
+         */
+        selected_sequence_format() = default; //!< Default.
+        selected_sequence_format(selected_sequence_format const &) = default; //!< Default.
+        selected_sequence_format(selected_sequence_format &&) = default; //!< Default.
+        selected_sequence_format & operator=(selected_sequence_format const &) = default; //!< Default.
+        selected_sequence_format & operator=(selected_sequence_format &&) = default; //!< Default.
+        ~selected_sequence_format() = default; //!< Default.
+        //!\}
+
+        //!\copydoc sequence_format_base::read_sequence_record
+        void read_sequence_record(std::istream & instream,
+                                  record_type & record_buffer,
+                                  sequence_file_input_options_type const & options) override
         {
             // read new record
-            if constexpr (selected_field_ids::contains(field::seq_qual))
             {
-                f.read_sequence_record(*secondary_stream,
-                                       options,
-                                       detail::get_or_ignore<field::seq_qual>(record_buffer),
-                                       detail::get_or_ignore<field::id>(record_buffer),
-                                       detail::get_or_ignore<field::seq_qual>(record_buffer));
+                _format.read_sequence_record(instream,
+                                             options,
+                                             detail::get_or_ignore<field::seq>(record_buffer),
+                                             detail::get_or_ignore<field::id>(record_buffer),
+                                             detail::get_or_ignore<field::qual>(record_buffer));
             }
-            else
-            {
-                f.read_sequence_record(*secondary_stream,
-                                       options,
-                                       detail::get_or_ignore<field::seq>(record_buffer),
-                                       detail::get_or_ignore<field::id>(record_buffer),
-                                       detail::get_or_ignore<field::qual>(record_buffer));
-            }
-        }, format);
-    }
+        };
+
+        //!\brief The selected format stored as a format exposer object.
+        detail::sequence_file_input_format_exposer<format_t> _format{};
+    };
+
+    //!\brief An instance of the detected/selected format.
+    std::unique_ptr<sequence_format_base> format{};
 
     //!\brief Befriend iterator so it can access the buffers.
     friend iterator;
@@ -689,9 +645,9 @@ template <input_stream stream_type,
           sequence_file_input_format file_format>
 sequence_file_input(stream_type && stream,
                     file_format const &)
-   -> sequence_file_input<typename sequence_file_input<>::traits_type,         // actually use the default
-                          typename sequence_file_input<>::selected_field_ids,  // default field ids.
-                          type_list<file_format>>;
+    -> sequence_file_input<typename sequence_file_input<>::traits_type,         // actually use the default
+                           typename sequence_file_input<>::selected_field_ids,  // default field ids.
+                           type_list<file_format>>;
 
 //!\brief Deduces the sequence input file type from the stream, the format and the field ids.
 template <input_stream stream_type,
