@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2020, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2020, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -17,11 +17,12 @@
 namespace seqan3
 {
 /*!\brief The options type defines various option members that influence the behaviour of all or some formats.
+ * \ingroup io_sequence_file
  * \tparam sequence_legal_alphabet_ The sequence legal alphabet exposed as type trait to the format.
- * \tparam seq_qual_combined Trait that exposes to the format whether seq and qual arguments are actually the
- * same/combined.
+ *
+ * \remark For a complete overview, take a look at \ref io_sequence_file
  */
-template <typename sequence_legal_alphabet, bool seq_qual_combined>
+template <typename sequence_legal_alphabet>
 struct sequence_file_input_options
 {
     //!\brief Read the ID string only up until the first whitespace character.
