@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2020, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2020, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -13,32 +13,33 @@
 #pragma once
 
 #include <cassert>
+#include <seqan3/std/filesystem>
 #include <fstream>
+#include <seqan3/std/ranges>
 #include <string>
 #include <variant>
 #include <vector>
-#include <seqan3/core/detail/pack_algorithm.hpp>
-#include <seqan3/core/type_list/traits.hpp>
-#include <seqan3/core/concept/tuple.hpp>
-#include <seqan3/io/stream/concept.hpp>
-#include <seqan3/io/exception.hpp>
-#include <seqan3/std/filesystem>
-#include <seqan3/io/record.hpp>
+
 #include <seqan3/io/detail/misc.hpp>
 #include <seqan3/io/detail/misc_output.hpp>
 #include <seqan3/io/detail/out_file_iterator.hpp>
 #include <seqan3/io/detail/record.hpp>
+#include <seqan3/io/detail/record_like.hpp>
+#include <seqan3/io/exception.hpp>
+#include <seqan3/io/record.hpp>
+#include <seqan3/io/sam_file/format_sam.hpp>
 #include <seqan3/io/sequence_file/format_embl.hpp>
 #include <seqan3/io/sequence_file/format_fasta.hpp>
 #include <seqan3/io/sequence_file/format_fastq.hpp>
 #include <seqan3/io/sequence_file/format_genbank.hpp>
-#include <seqan3/io/alignment_file/format_sam.hpp>
 #include <seqan3/io/sequence_file/output_format_concept.hpp>
 #include <seqan3/io/sequence_file/output_options.hpp>
-#include <seqan3/range/views/convert.hpp>
-#include <seqan3/range/views/get.hpp>
-#include <seqan3/range/views/zip.hpp>
-#include <seqan3/std/ranges>
+#include <seqan3/io/stream/concept.hpp>
+#include <seqan3/utility/tuple/concept.hpp>
+#include <seqan3/utility/type_list/traits.hpp>
+#include <seqan3/utility/views/convert.hpp>
+#include <seqan3/utility/views/elements.hpp>
+#include <seqan3/utility/views/zip.hpp>
 
 namespace seqan3
 {
@@ -48,7 +49,7 @@ namespace seqan3
 // ----------------------------------------------------------------------------
 
 /*!\brief A class for writing sequence files, e.g. FASTA, FASTQ ...
- * \ingroup sequence
+ * \ingroup io_sequence_file
  * \tparam selected_field_ids   A seqan3::fields type with the list and order of fields IDs; only relevant if these
  *                              can't be deduced.
  * \tparam valid_formats        A seqan3::type_list of the selectable formats (each must meet
@@ -56,109 +57,9 @@ namespace seqan3
  *
  * \details
  *
- * ### Introduction
+ * \include{doc} doc/fragments/sequence_file_output.md
  *
- * Sequence files are the most generic and common biological files. Well-known formats include
- * FastA and FastQ, but some may also be interested in treating SAM or BAM files as sequence
- * files, discarding the alignment.
- *
- * The Sequence file abstraction supports writing four different fields:
- *
- *   1. seqan3::field::seq
- *   2. seqan3::field::id
- *   3. seqan3::field::qual
- *   4. seqan3::field::seq_qual (sequence and qualities in one range)
- *
- * The member functions take any and either of these fields. If the field ID of an argument cannot be deduced, it
- * is assumed to correspond to the field ID of the respective template parameter.
- *
- * ### Construction and specialisation
- *
- * This class comes with two constructors, one for construction from a file name and one for construction from
- * an existing stream and a known format. The first one automatically picks the format based on the extension
- * of the file name. The second can be used if you have a non-file stream, like std::cout or std::ostringstream,
- * that you want to read from and/or if you cannot use file-extension based detection, but know that your output
- * file has a certain format.
- *
- * In most cases the template parameters are deduced completely automatically:
- *
- * \include test/snippet/io/sequence_file/sequence_file_output_template_deduction.cpp
- *
- * Writing to std::cout:
- * \include test/snippet/io/sequence_file/sequence_file_output_cout_write.cpp
- *
- * Note that this is not the same as writing `sequence_file_output<>` (with angle brackets). In the latter case they are
- * explicitly set to their default values, in the former case
- * [automatic deduction](https://en.cppreference.com/w/cpp/language/class_template_argument_deduction) happens which
- * chooses different parameters depending on the constructor arguments. Prefer deduction over explicit defaults.
- *
- * ### Writing record-wise
- *
- * You can iterate over this file record-wise:
- *
- * \include test/snippet/io/sequence_file/sequence_file_output_record_wise_iteration.cpp
- *
- * The easiest way to write to a sequence file is to use the push_back() or emplace_back() member functions. These
- * work similarly to how they work on an std::vector. If you pass a tuple to push_back() or give arguments to
- * emplace_back() the seqan3::field ID of the i-th tuple-element/argument is assumed to be the i-th value of
- * selected_field_ids, i.e. by default the first is assumed to be seqan3::field::seq, the second seqan3::field::id
- * and the third one seqan3::field::qual. You may give less fields than are selected if the actual format you are
- * writing to can cope with less
- * (e.g. for FastA it is sufficient to write seqan3::field::seq and seqan3::field::id, even if selected_field_ids
- * also contains seqan3::field::qual at the third position).
- *
- * You may also use the output file's iterator for writing, however, this rarely provides an advantage.
- *
-* ### Writing record-wise (custom fields)
- *
- * If you want to pass a combined object for SEQ and QUAL fields to push_back() / emplace_back(), or if you want
- * to change the order of the parameters, you can pass a non-empty fields trait object to the
- * sequence_file_output constructor to select the fields that are used for interpreting the arguments.
- *
- * The following snippets demonstrates the usage of such a fields trait object.
- *
- * \include test/snippet/io/sequence_file/sequence_file_output_fields_trait_1.cpp
- *
- * A different way of passing custom fields to the file is to pass a seqan3::record – instead of a tuple – to
- * push_back(). The seqan3::record clearly indicates which of its elements has which seqan3::field ID so the file will
- * use that information instead of the template argument. This is especially handy when reading from one file and
- * writing to another, because you don't have to configure the output file to match the input file, it will just work:
- *
- * \include test/snippet/io/sequence_file/sequence_file_output_fields_trait_2.cpp
- *
- * ### Writing record-wise in batches
- *
- * You can write multiple records at once, by assigning to the file:
- *
- * \include test/snippet/io/sequence_file/sequence_file_output_batch_write.cpp
- * ### File I/O pipelines
- *
- * Record-wise writing in batches also works for writing from input files directly to output files, because input
- * files are also input ranges in SeqAn:
- *
- * \include test/snippet/io/sequence_file/sequence_file_output_direct_writing.cpp
- *
- * This can be combined with file-based views to create I/O pipelines:
- *
- * \include test/snippet/io/sequence_file/sequence_file_output_view_pipeline.cpp
- *
- * ### Column-based writing
- *
- * The record-based interface treats the file as a range of tuples (the records), but in certain situations
- * you might have the data as columns, i.e. a tuple-of-ranges, instead of range-of-tuples.
- *
- * You can use column-based writing in that case, it uses operator=() and seqan3::views::zip():
- *
- * \include test/snippet/io/sequence_file/sequence_file_output_col_based_writing.cpp
- *
- * ### Formats
- *
- * We currently support writing the following formats:
- *   * seqan3::format_fasta
- *   * seqan3::format_fastq
- *   * seqan3::format_embl
- *   * seqan3::format_genbank
- *   * seqan3::format_sam
+ * \remark For a complete overview, take a look at \ref io_sequence_file
  */
 
 template <detail::fields_specialisation selected_field_ids_ = fields<field::seq, field::id, field::qual>,
@@ -180,7 +81,7 @@ public:
     //!\}
 
     //!\brief The subset of seqan3::field IDs that are valid for this file.
-    using field_ids            = fields<field::seq, field::id, field::qual, field::seq_qual>;
+    using field_ids            = fields<field::seq, field::id, field::qual>;
 
     static_assert([] () constexpr
                   {
@@ -192,14 +93,6 @@ public:
                   "You selected a field that is not valid for sequence files, please refer to the documentation "
                   "of sequence_file_output::field_ids for the accepted values.");
 
-    static_assert([] () constexpr
-                  {
-                      return !(selected_field_ids::contains(field::seq_qual) &&
-                               (selected_field_ids::contains(field::seq) ||
-                               (selected_field_ids::contains(field::qual))));
-                  }(),
-                  "You may not select field::seq_qual and either of field::seq and field::qual at the same time.");
-
     /*!\name Range associated types
      * \brief Most of the range associated types are `void` for output ranges.
      * \{
@@ -387,15 +280,12 @@ public:
     template <typename record_t>
     void push_back(record_t && r)
     //!\cond
-        requires tuple_like<record_t> &&
-                 requires { requires detail::is_type_specialisation_of_v<std::remove_cvref_t<record_t>, record>; }
+        requires detail::record_like<record_t>
     //!\endcond
     {
         write_record(detail::get_or_ignore<field::seq>(r),
                      detail::get_or_ignore<field::id>(r),
-                     detail::get_or_ignore<field::qual>(r),
-                     detail::get_or_ignore<field::seq_qual>(r));
-
+                     detail::get_or_ignore<field::qual>(r));
     }
 
     /*!\brief           Write a record in form of a std::tuple to the file.
@@ -422,14 +312,13 @@ public:
     template <typename tuple_t>
     void push_back(tuple_t && t)
     //!\cond
-        requires tuple_like<tuple_t>
+        requires tuple_like<tuple_t> && (!detail::record_like<tuple_t>)
     //!\endcond
     {
         // index_of might return npos, but this will be handled well by get_or_ignore (and just return ignore)
         write_record(detail::get_or_ignore<selected_field_ids::index_of(field::seq)>(t),
                      detail::get_or_ignore<selected_field_ids::index_of(field::id)>(t),
-                     detail::get_or_ignore<selected_field_ids::index_of(field::qual)>(t),
-                     detail::get_or_ignore<selected_field_ids::index_of(field::seq_qual)>(t));
+                     detail::get_or_ignore<selected_field_ids::index_of(field::qual)>(t));
     }
 
     /*!\brief            Write a record to the file by passing individual fields.
@@ -518,7 +407,7 @@ public:
      *
      * This is especially useful in combination with file-based filters:
      *
-     * \include test/snippet/io/sequence_file/sequence_file_output_view_pipeline.cpp
+     * \snippet test/snippet/io/sequence_file/sequence_file_output_view_pipeline.cpp snippet
      */
     template <std::ranges::input_range rng_t>
     friend sequence_file_output & operator|(rng_t && range, sequence_file_output & f)
@@ -579,7 +468,7 @@ protected:
     //!\brief The secondary stream is a compression layer on the primary or just points to the primary (no compression).
     stream_ptr_t secondary_stream{nullptr, stream_deleter_noop};
 
-    //!\brief Type of the format, an std::variant over the `valid_formats`.
+    //!\brief Type of the format, a std::variant over the `valid_formats`.
     using format_type = typename detail::variant_from_tags<valid_formats,
                                                            detail::sequence_file_output_format_exposer>::type;
     //!\brief The actual std::variant holding a pointer to the detected/selected format.
@@ -587,29 +476,12 @@ protected:
     //!\}
 
     //!\brief Write record to format.
-    template <typename seq_t, typename id_t, typename qual_t, typename seq_qual_t>
-    void write_record(seq_t && seq, id_t && id, qual_t && qual, seq_qual_t && seq_qual)
+    template <typename seq_t, typename id_t, typename qual_t>
+    void write_record(seq_t && seq, id_t && id, qual_t && qual)
     {
-        static_assert(detail::decays_to_ignore_v<seq_qual_t> ||
-                      (detail::decays_to_ignore_v<seq_t> && detail::decays_to_ignore_v<qual_t>),
-                      "You may not select field::seq_qual and either of field::seq and field::qual at the same time.");
-
-        if constexpr (!detail::decays_to_ignore_v<seq_qual_t>)
-            static_assert(detail::is_type_specialisation_of_v<std::ranges::range_value_t<seq_qual_t>, qualified>,
-                          "The SEQ_QUAL field must contain a range over the seqan3::qualified alphabet.");
-
         assert(!format.valueless_by_exception());
         std::visit([&] (auto & f)
         {
-            if constexpr (!detail::decays_to_ignore_v<seq_qual_t>)
-            {
-                f.write_sequence_record(*secondary_stream,
-                                        options,
-                                        seq_qual | views::get<0>,
-                                        id,
-                                        seq_qual | views::get<1>);
-            }
-            else
             {
                 f.write_sequence_record(*secondary_stream,
                                         options,
