@@ -10,13 +10,17 @@
  * \author Jörg Winkler <j.winkler AT fu-berlin.de>
  */
 
-#pragma once
-
-/*!\defgroup structure_file Structure File
+/*!\defgroup io_structure_file Structure File
  * \ingroup io
  * \brief Provides files and formats for handling structure data.
+ *
+ * \include{doc} doc/fragments/io_structure_input.md
+ *
+ * \include{doc} doc/fragments/io_structure_output.md
  */
 
+#pragma once
+
 #include <seqan3/io/structure_file/format_vienna.hpp>
 #include <seqan3/io/structure_file/input.hpp>
 #include <seqan3/io/structure_file/input_format_concept.hpp>
@@ -24,3 +28,4 @@
 #include <seqan3/io/structure_file/output.hpp>
 #include <seqan3/io/structure_file/output_format_concept.hpp>
 #include <seqan3/io/structure_file/output_options.hpp>
+#include <seqan3/io/structure_file/record.hpp>
