@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2020, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2020, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -14,25 +14,27 @@
 
 #include <type_traits>
 
-#include <seqan3/core/type_traits/transformation_trait_or.hpp>
-#include <seqan3/range/views/slice.hpp>
 #include <seqan3/search/detail/search_common.hpp>
 #include <seqan3/search/detail/search_scheme_precomputed.hpp>
 #include <seqan3/search/detail/search_traits.hpp>
+#include <seqan3/search/fm_index/bi_fm_index.hpp>
 #include <seqan3/search/fm_index/concept.hpp>
+#include <seqan3/utility/type_traits/detail/transformation_trait_or.hpp>
+#include <seqan3/utility/views/slice.hpp>
 
 namespace seqan3::detail
 {
 
-/*!\addtogroup search
- * \{
- */
-
-/*!\brief The algorithm that performs a unidirectional search on an FM index using trivial backtracking.
+/*!\brief The algorithm that performs a bidirectional search on a bidirectional FM index using (optimal) search schemes.
+ * \ingroup search
  * \tparam configuration_t The search configuration type.
- * \tparam index_t The type of index; must model seqan3::bi_fm_index_specialisation.
+ * \tparam index_t The type of index; index_t::cursor_type must model seqan3::detail::template_specialisation_of
+ *                 a seqan3::bi_fm_index_cursor.
  */
-template <typename configuration_t, bi_fm_index_specialisation index_t, typename ...policies_t>
+template <typename configuration_t, typename index_t, typename ...policies_t>
+//!\cond
+    requires (template_specialisation_of<typename index_t::cursor_type, bi_fm_index_cursor>)
+//!\endcond
 class search_scheme_algorithm : protected policies_t...
 {
 private:
@@ -56,7 +58,8 @@ public:
 
     /*!\brief Constructs from a configuration object and an index.
      * \tparam configuration_t The search configuration type.
-     * \tparam index_t The type of index; must model seqan3::bi_fm_index_specialisation.
+     * \tparam index_t The type of index; index_t::cursor_type must model seqan3::detail::template_specialisation_of
+     *                 a seqan3::bi_fm_index_cursor.
      * \param[in] cfg The configuration object that guides the search algorithm.
      * \param[in] index The index used in the algorithm.
      *
@@ -116,7 +119,7 @@ public:
     }
 
 private:
-    //!\brief A pointer to the fm index which is used to perform the unidirectional search.
+    //!\brief A pointer to the bidirectional fm index which is used to perform the bidirectional search.
     index_t const * index_ptr{nullptr};
 
     //!\brief The stratum value if set.
@@ -175,6 +178,7 @@ private:
 };
 
 /*!\brief Computes a (non-optimal) search scheme. Currently the generated search scheme represents trivial backtracking.
+ * \ingroup search
  * \param[in] min_error Minimum number of errors allowed.
  * \param[in] max_error Maximum number of errors allowed.
  *
@@ -199,6 +203,7 @@ inline std::vector<search_dyn> compute_ss(uint8_t const min_error, uint8_t const
 
 /*!\brief Returns for each search the cumulative length of blocks in the order of blocks in each search and the
  *        starting position of the first block in the query sequence.
+ * \ingroup search
  * \tparam search_scheme_t  Is of type `seqan3::detail::search_scheme_type` or `seqan3::detail::search_scheme_dyn_type`.
  * \param[in] search_scheme Search scheme that will be used for searching.
  * \param[in] query_length  Length of the query that will be searched in an index.
@@ -280,8 +285,9 @@ inline bool search_ss(cursor_t cur, query_t & query,
 
 /*!\brief Searches a query sequence in a bidirectional index using a single search of a search scheme.
  *        Sub-function for searching the remaining part of the current block without any errors.
+ * \ingroup search
  * \tparam abort_on_hit     If the flag is set, the search aborts on the first hit.
- * \tparam cursor_t         Must model seqan3::bi_fm_index_cursor_specialisation.
+ * \tparam cursor_t         Must model seqan3::detail::template_specialisation_of a seqan3::bi_fm_index_cursor.
  * \tparam query_t          Must model std::ranges::random_access_range over the index's alphabet.
  * \tparam search_t         Is of type `seqan3::detail::search<>` or `seqan3::detail::search_dyn<>`.
  * \tparam blocks_length_t  Is of type `std::array` or `std::vector` of unsigned integers.
@@ -354,6 +360,7 @@ inline bool search_ss_exact(cursor_t cur, query_t & query,
 
 /*!\brief Searches a query sequence in a bidirectional index using a single search of a search schemes.
  *        Sub-function for deletions at the end of a block.
+ * \ingroup search
  *
  * \copydetails search_ss_exact
  */
@@ -406,6 +413,7 @@ inline bool search_ss_deletion(cursor_t cur, query_t & query,
 
 /*!\brief Searches a query sequence in a bidirectional index using a single search of a search schemes.
  *        Sub-function for approximate search step (iterating over all children in a conceptual suffix tree).
+ * \ingroup search
  *
  * \copydetails search_ss_exact
  *
@@ -502,6 +510,7 @@ inline bool search_ss_children(cursor_t cur, query_t & query,
 }
 
 /*!\brief Searches a query sequence in a bidirectional index using a single search of a search schemes.
+ * \ingroup search
  *
  * \copydetails search_ss_exact
  */
@@ -580,8 +589,10 @@ inline bool search_ss(cursor_t cur, query_t & query,
 }
 
 /*!\brief Searches a query sequence in a bidirectional index using search schemes.
+ * \ingroup search
  * \tparam abort_on_hit     If the flag is set, the search aborts on the first hit.
- * \tparam index_t          Must model seqan3::bi_fm_index_specialisation.
+ * \tparam index_t          index_t::cursor_type must model seqan3::detail::template_specialisation_of
+ *                          a seqan3::bi_fm_index_cursor.
  * \tparam query_t          Must model std::ranges::random_access_range over the index's alphabet.
  * \tparam search_scheme_t  Is of type `seqan3::detail::search_scheme_type` or `seqan3::detail::search_scheme_dyn_type`.
  * \tparam delegate_t       Takes `typename index_t::cursor_type` as argument.
@@ -631,6 +642,7 @@ inline void search_ss(index_t const & index, query_t & query, search_param const
 }
 
 /*!\brief Searches a query sequence in a bidirectional index.
+ * \ingroup search
  * \tparam abort_on_hit    If the flag is set, the search aborts on the first hit.
  * \tparam query_t         Must model std::ranges::random_access_range over the index's alphabet.
  * \tparam delegate_t      Takes `typename index_t::cursor_type` as argument.
@@ -674,6 +686,5 @@ inline void search_scheme_algorithm<configuration_t, index_t, policies_t...>::se
             break;
     }
 }
-//!\}
 
 } // namespace seqan3::detail
