@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2020, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2020, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -12,20 +12,18 @@
 
 #pragma once
 
+#include <seqan3/std/algorithm>
+#include <seqan3/std/bit>
+
 #include <sdsl/bit_vectors.hpp>
 
-#include <seqan3/core/bit_manipulation.hpp>
 #include <seqan3/core/concept/cereal.hpp>
 #include <seqan3/core/detail/strong_type.hpp>
-#include <seqan3/std/algorithm>
 
 namespace seqan3
 {
-
-/*!\addtogroup submodule_dream_index
- * \{
- */
 //!\brief Determines if the Interleaved Bloom Filter is compressed.
+//!\ingroup search_dream_index
 enum data_layout : bool
 {
     uncompressed, //!< The Interleaved Bloom Filter is uncompressed.
@@ -33,30 +31,35 @@ enum data_layout : bool
 };
 
 //!\brief A strong type that represents the number of bins for the seqan3::interleaved_bloom_filter.
+//!\ingroup search_dream_index
 struct bin_count : public detail::strong_type<size_t, bin_count, detail::strong_type_skill::convert>
 {
     using detail::strong_type<size_t, bin_count, detail::strong_type_skill::convert>::strong_type;
 };
 
 //!\brief A strong type that represents the number of bits for each bin in the seqan3::interleaved_bloom_filter.
+//!\ingroup search_dream_index
 struct bin_size : public detail::strong_type<size_t, bin_size, detail::strong_type_skill::convert>
 {
     using detail::strong_type<size_t, bin_size, detail::strong_type_skill::convert>::strong_type;
 };
 
 //!\brief A strong type that represents the number of hash functions for the seqan3::interleaved_bloom_filter.
+//!\ingroup search_dream_index
 struct hash_function_count : public detail::strong_type<size_t, hash_function_count, detail::strong_type_skill::convert>
 {
     using detail::strong_type<size_t, hash_function_count, detail::strong_type_skill::convert>::strong_type;
 };
 
 //!\brief A strong type that represents the bin index for the seqan3::interleaved_bloom_filter.
+//!\ingroup search_dream_index
 struct bin_index : public detail::strong_type<size_t, bin_index, detail::strong_type_skill::convert>
 {
     using detail::strong_type<size_t, bin_index, detail::strong_type_skill::convert>::strong_type;
 };
 
 /*!\brief The IBF binning directory. A data structure that efficiently answers set-membership queries for multiple bins.
+ * \ingroup search_dream_index
  * \tparam data_layout_mode_ Indicates whether the underlying data type is compressed. See seqan3::data_layout.
  * \implements seqan3::cerealisable
  *
@@ -105,6 +108,10 @@ struct bin_index : public detail::strong_type<size_t, bin_index, detail::strong_
  * To query the Interleaved Bloom Filter for a value, call seqan3::interleaved_bloom_filter::membership_agent() and use
  * the returned seqan3::interleaved_bloom_filter::membership_agent.
  *
+ * To count the occurrences of a range of values in the Interleaved Bloom Filter, call
+ * seqan3::interleaved_bloom_filter::counting_agent() and use
+ * the returned seqan3::interleaved_bloom_filter::counting_agent_type.
+ *
  * ### Compression
  *
  * The Interleaved Bloom Filter can be compressed by passing `data_layout::compressed` as template argument.
@@ -129,8 +136,6 @@ private:
     //!\cond
     template <data_layout data_layout_mode>
     friend class interleaved_bloom_filter;
-
-    class membership_agent;
     //!\endcond
 
     //!\brief The underlying datatype to use.
@@ -186,6 +191,10 @@ public:
     //!\brief Indicates whether the Interleaved Bloom Filter is compressed.
     static constexpr data_layout data_layout_mode = data_layout_mode_;
 
+    class membership_agent; // documented upon definition below
+    template <std::integral value_t>
+    class counting_agent_type; // documented upon definition below
+
     /*!\name Constructors, destructor and assignment
      * \{
      */
@@ -227,7 +236,7 @@ public:
         if (bin_size_ == 0)
             throw std::logic_error{"The size of a bin must be > 0."};
 
-        hash_shift = detail::count_leading_zeros(bin_size_);
+        hash_shift = std::countl_zero(bin_size_);
         bin_words = (bins + 63) >> 6; // = ceil(bins/64)
         technical_bins  = bin_words << 6; // = bin_words * 64
         data = sdsl::bit_vector(technical_bins * bin_size_);
@@ -271,7 +280,7 @@ public:
      *
      * \include test/snippet/search/dream_index/interleaved_bloom_filter_emplace.cpp
      */
-    void emplace(size_t const value, bin_index const bin)
+    void emplace(size_t const value, bin_index const bin) noexcept
     //!\cond
         requires (data_layout_mode == data_layout::uncompressed)
     //!\endcond
@@ -286,6 +295,59 @@ public:
         };
     }
 
+    /*!\brief Clears a specific bin.
+     * \param[in] bin The bin index to clear.
+     *
+     * \attention This function is only available for **uncompressed** Interleaved Bloom Filters.
+     *
+     * \details
+     *
+     * ### Example
+     *
+     * \include test/snippet/search/dream_index/interleaved_bloom_filter_clear.cpp
+     */
+    void clear(bin_index const bin) noexcept
+    //!\cond
+        requires (data_layout_mode == data_layout::uncompressed)
+    //!\endcond
+    {
+        assert(bin.get() < bins);
+        for (size_t idx = bin.get(), i = 0; i < bin_size_; idx += technical_bins, ++i)
+            data[idx] = 0;
+    }
+
+    /*!\brief Clears a range of bins.
+     * \tparam rng_t The type of the range. Must model std::ranges::forward_range and the reference type must be
+     *               seqan3::bin_index.
+     * \param[in] bin_range The range of bins to clear.
+     *
+     * \attention This function is only available for **uncompressed** Interleaved Bloom Filters.
+     *
+     * \details
+     *
+     * ### Example
+     *
+     * \include test/snippet/search/dream_index/interleaved_bloom_filter_clear.cpp
+     */
+    template <typename rng_t>
+    //!\cond
+        requires (data_layout_mode == data_layout::uncompressed)
+    //!\endcond
+    void clear(rng_t && bin_range) noexcept
+    {
+        static_assert(std::ranges::forward_range<rng_t>, "The range of bins to clear must model a forward_range.");
+        static_assert(std::same_as<std::remove_cvref_t<std::ranges::range_reference_t<rng_t>>, bin_index>,
+                      "The reference type of the range to clear must be seqan3::bin_index.");
+#ifndef NDEBUG
+        for (auto && bin : bin_range)
+            assert(bin.get() < bins);
+#endif // NDEBUG
+
+        for (size_t offset = 0, i = 0; i < bin_size_; offset += technical_bins, ++i)
+            for (auto && bin : bin_range)
+                data[bin.get() + offset] = 0;
+    }
+
     /*!\brief Increases the number of bins stored in the Interleaved Bloom Filter.
      * \param[in] new_bins_ The new number of bins.
      * \throws std::invalid_argument If passed number of bins is smaller than current number of bins.
@@ -355,9 +417,9 @@ public:
     /*!\name Lookup
      * \{
      */
-    /*!\brief Returns seqan3::interleaved_bloom_filter::membership_agent to be used for lookup.
+    /*!\brief Returns a seqan3::interleaved_bloom_filter::membership_agent to be used for lookup.
      * \attention Calling seqan3::interleaved_bloom_filter::increase_bin_number_to invalidates all
-     * seqan3::interleaved_bloom_filter::membership_agent constructed for this Interleaved Bloom Filter.
+     * `seqan3::interleaved_bloom_filter::membership_agent`s constructed for this Interleaved Bloom Filter.
      *
      * \details
      *
@@ -370,6 +432,23 @@ public:
     {
         return typename interleaved_bloom_filter<data_layout_mode>::membership_agent{*this};
     }
+
+    /*!\brief Returns a seqan3::interleaved_bloom_filter::counting_agent_type to be used for counting.
+     * \attention Calling seqan3::interleaved_bloom_filter::increase_bin_number_to invalidates all
+     * `seqan3::interleaved_bloom_filter::counting_agent_type`s constructed for this Interleaved Bloom Filter.
+     *
+     * \details
+     *
+     * ### Example
+     *
+     * \include test/snippet/search/dream_index/counting_agent_construction.cpp
+     * \sa seqan3::interleaved_bloom_filter::counting_agent_type::bulk_count
+     */
+    template <typename value_t = uint16_t>
+    counting_agent_type<value_t> counting_agent() const
+    {
+        return counting_agent_type<value_t>{*this};
+    }
     //!\}
 
     /*!\name Capacity
@@ -435,6 +514,28 @@ public:
     }
     //!\}
 
+    /*!\name Access
+     * \{
+     */
+    /*!\brief Provides direct, unsafe access to the underlying data structure.
+     * \returns A reference to an SDSL bitvector.
+     *
+     * \details
+     *
+     * \noapi{The exact representation of the data is implementation defined.}
+     */
+    constexpr data_type & raw_data() noexcept
+    {
+        return data;
+    }
+
+    //!\copydoc raw_data()
+    constexpr data_type const & raw_data() const noexcept
+    {
+        return data;
+    }
+    //!\}
+
     /*!\cond DEV
      * \brief Serialisation support function.
      * \tparam archive_t Type of `archive`; must satisfy seqan3::cereal_archive.
@@ -493,10 +594,9 @@ public:
      * \private
      * \param ibf The seqan3::interleaved_bloom_filter.
      */
-    membership_agent(ibf_t const & ibf) : ibf_ptr(std::addressof(ibf))
-    {
-        result_buffer.resize(ibf_ptr->bin_count());
-    };
+    explicit membership_agent(ibf_t const & ibf) :
+        ibf_ptr(std::addressof(ibf)), result_buffer(ibf.bin_count())
+    {}
     //!\}
 
     //!\brief Stores the result of bulk_contains().
@@ -508,7 +608,7 @@ public:
     /*!\brief Determines set membership of a given value.
      * \param[in] value The raw value to process.
      *
-     * \attention The result of this function must always be bound via reference, e.g. `auto &` to prevent copying.
+     * \attention The result of this function must always be bound via reference, e.g. `auto &`, to prevent copying.
      * \attention Sequential calls to this function invalidate the previously returned reference.
      *
      * \details
@@ -519,8 +619,8 @@ public:
      *
      * ### Thread safety
      *
-     * Concurrent invocations of this function are not thread safe, please create a seqan3::membership_agent for each
-     * thread.
+     * Concurrent invocations of this function are not thread safe, please create a
+     * seqan3::interleaved_bloom_filter::membership_agent for each thread.
      */
     [[nodiscard]] binning_bitvector const & bulk_contains(size_t const value) & noexcept
     {
@@ -543,7 +643,7 @@ public:
                bloom_filter_indices[i] += 64;
            }
 
-           result_buffer.set_int(batch << 6, tmp);
+           result_buffer.data.set_int(batch << 6, tmp);
         }
 
         return result_buffer;
@@ -558,57 +658,126 @@ public:
 
 //!\brief A bitvector representing the result of a call to `bulk_contains` of the seqan3::interleaved_bloom_filter.
 template <data_layout data_layout_mode>
-class interleaved_bloom_filter<data_layout_mode>::membership_agent::binning_bitvector : private sdsl::bit_vector
+class interleaved_bloom_filter<data_layout_mode>::membership_agent::binning_bitvector
 {
+private:
+    //!\brief The underlying datatype to use.
+    using data_type = sdsl::bit_vector;
+    //!\brief The bitvector.
+    data_type data{};
+
+    friend class membership_agent;
+
+    template <std::integral value_t>
+    friend class counting_vector;
+
 public:
     /*!\name Constructors, destructor and assignment
-        * \{
-        */
+     * \{
+     */
     binning_bitvector() = default; //!< Defaulted.
     binning_bitvector(binning_bitvector const &) = default; //!< Defaulted.
     binning_bitvector & operator=(binning_bitvector const &) = default; //!< Defaulted.
     binning_bitvector(binning_bitvector &&) = default; //!< Defaulted.
     binning_bitvector & operator=(binning_bitvector &&) = default; //!< Defaulted.
     ~binning_bitvector() = default; //!< Defaulted.
+
+    //!\brief Construct with given size.
+    explicit binning_bitvector(size_t const size) :
+        data(size)
+    {}
     //!\}
 
-    using sdsl::bit_vector::begin;
-    using sdsl::bit_vector::end;
-    using sdsl::bit_vector::operator==;
-    using sdsl::bit_vector::operator[];
-    using sdsl::bit_vector::size;
+    //!\brief Returns the number of elements.
+    size_t size() const noexcept
+    {
+        return data.size();
+    }
 
-#if SEQAN3_DOXYGEN_ONLY(1)0
-    //!\brief The iterator type of the `binning_bitvector`;
-    using iterator_t = IMPLEMENTATION_DEFINED;
-    //!\brief The reference type of the `binning_bitvector`;
-    using reference_t = IMPLEMENTATION_DEFINED;
-    //!\brief The const_reference type of the `binning_bitvector`;
-    using const_reference_t = IMPLEMENTATION_DEFINED;
-    //!\brief Returns an iterator to the begin of the bitvector.
-    iterator_t begin() noexcept;
-    //!\brief Returns an iterator to the end of the bitvector.
-    iterator_t end() noexcept;
-    //!\brief Compares two bitvectors.
-    bool operator==(bit_vector const & other) const noexcept;
-    //!\brief Returns a reference to position `idx` of the bitvector.
-    reference_t operator[](size_t const & idx) noexcept;
-    //!\brief Returns a const_reference to position `idx` of the bitvector.
-    const_reference_t operator[](size_t const & idx) const noexcept;
-    //!\brief Returns the size of the bitvector.
-    size_t size() noexcept;
-#endif
+    /*!\name Iterators
+     * \{
+     */
+    //!\brief Returns an iterator to the first element of the container.
+    auto begin() noexcept
+    {
+        return data.begin();
+    }
 
-private:
-    friend class membership_agent;
-    using sdsl::bit_vector::resize;
-    using sdsl::bit_vector::set_int;
-    template <std::integral value_t>
-    friend class counting_vector;
+    //!\copydoc begin()
+    auto begin() const noexcept
+    {
+        return data.begin();
+    }
+
+    //!\brief Returns an iterator to the element following the last element of the container.
+    auto end() noexcept
+    {
+        return data.end();
+    }
+
+    //!\copydoc end()
+    auto end() const noexcept
+    {
+        return data.end();
+    }
+    //!\}
+
+    /*!\name Comparison operators
+     * \{
+     */
+    //!\brief Test for equality.
+    friend bool operator==(binning_bitvector const & lhs, binning_bitvector const & rhs) noexcept
+    {
+        return lhs.data == rhs.data;
+    }
+
+    //!\brief Test for inequality.
+    friend bool operator!=(binning_bitvector const & lhs, binning_bitvector const & rhs) noexcept
+    {
+        return !(lhs == rhs);
+    }
+    //!\}
+
+    /*!\name Access
+     * \{
+     */
+     //!\brief Return the i-th element.
+    auto operator[](size_t const i) noexcept
+    {
+        assert(i < size());
+        return data[i];
+    }
+
+    //!\copydoc operator[]()
+    auto operator[](size_t const i) const noexcept
+    {
+        assert(i < size());
+        return data[i];
+    }
+
+    /*!\brief Provides direct, unsafe access to the underlying data structure.
+     * \returns A reference to an SDSL bitvector.
+     *
+     * \details
+     *
+     * \noapi{The exact representation of the data is implementation defined.}
+     */
+    constexpr data_type & raw_data() noexcept
+    {
+        return data;
+    }
+
+    //!\copydoc raw_data()
+    constexpr data_type const & raw_data() const noexcept
+    {
+        return data;
+    }
+    //!\}
 };
 
 /*!\brief A data structure that behaves like a std::vector and can be used to consolidate the results of multiple calls
  *        to seqan3::interleaved_bloom_filter::membership_agent::bulk_contains.
+ * \ingroup search_dream_index
  * \tparam value_t The type of the count. Must model std::integral.
  *
  * \details
@@ -663,7 +832,11 @@ public:
      */
     template <typename rhs_t>
     //!\cond
-        requires std::is_base_of<sdsl::bit_vector, rhs_t>::value
+        requires std::same_as<rhs_t,
+                              interleaved_bloom_filter<data_layout::uncompressed>::membership_agent::binning_bitvector>
+                 ||
+                 std::same_as<rhs_t,
+                              interleaved_bloom_filter<data_layout::compressed>::membership_agent::binning_bitvector>
     //!\endcond
     counting_vector & operator+=(rhs_t const & rhs)
     {
@@ -672,13 +845,13 @@ public:
         // Each iteration can handle 64 bits, so we need to iterate `((rhs.size() + 63) >> 6` many times
         for (size_t batch = 0, bin = 0; batch < ((rhs.size() + 63) >> 6); bin = 64 * ++batch)
         {
-            size_t tmp = rhs.get_int(batch * 64); // get 64 bits starting at position `batch * 64`
+            size_t tmp = rhs.data.get_int(batch * 64); // get 64 bits starting at position `batch * 64`
             if (tmp ^ (1ULL<<63)) // This is a special case, because we would shift by 64 (UB) in the while loop.
             {
                 while (tmp > 0)
                 {
                     // Jump to the next 1 and increment the corresponding vector entry.
-                    uint8_t step = detail::count_trailing_zeros(tmp);
+                    uint8_t step = std::countr_zero(tmp);
                     bin += step++;
                     tmp >>= step;
                     ++(*this)[bin++];
@@ -692,8 +865,118 @@ public:
         return *this;
     }
 
+    /*!\brief Bin-wise addition of two `seqan3::counting_vector`s.
+     * \param rhs The other seqan3::counting_vector.
+     * \attention The seqan3::counting_vector must be at least as big as `rhs`.
+     *
+     * \details
+     *
+     * ### Example
+     *
+     * \include test/snippet/search/dream_index/counting_vector.cpp
+     */
+    counting_vector & operator+=(counting_vector const & rhs)
+    {
+        assert(this->size() >= rhs.size()); // The counting vector may be bigger than what we need.
+
+        std::transform(this->begin(), this->end(), rhs.begin(), this->begin(), std::plus<value_t>());
+
+        return *this;
+    }
 };
 
-//!\}
+/*!\brief Manages counting ranges of values for the seqan3::interleaved_bloom_filter.
+ * \attention Calling seqan3::interleaved_bloom_filter::increase_bin_number_to invalidates the counting_agent_type.
+ *
+ * \details
+ *
+ * ### Example
+ *
+ * \include test/snippet/search/dream_index/counting_agent.cpp
+ */
+template <data_layout data_layout_mode>
+template <std::integral value_t>
+class interleaved_bloom_filter<data_layout_mode>::counting_agent_type
+{
+private:
+    //!\brief The type of the augmented seqan3::interleaved_bloom_filter.
+    using ibf_t = interleaved_bloom_filter<data_layout_mode>;
+
+    //!\brief A pointer to the augmented seqan3::interleaved_bloom_filter.
+    ibf_t const * ibf_ptr{nullptr};
+
+    //!\brief Store a seqan3::interleaved_bloom_filter::membership_agent to call `bulk_contains`.
+    typename ibf_t::membership_agent membership_agent;
+
+public:
+    /*!\name Constructors, destructor and assignment
+     * \{
+     */
+    counting_agent_type() = default; //!< Defaulted.
+    counting_agent_type(counting_agent_type const &) = default; //!< Defaulted.
+    counting_agent_type & operator=(counting_agent_type const &) = default; //!< Defaulted.
+    counting_agent_type(counting_agent_type &&) = default; //!< Defaulted.
+    counting_agent_type & operator=(counting_agent_type &&) = default; //!< Defaulted.
+    ~counting_agent_type() = default; //!< Defaulted.
+
+    /*!\brief Construct a counting_agent_type for an existing seqan3::interleaved_bloom_filter.
+     * \private
+     * \param ibf The seqan3::interleaved_bloom_filter.
+     */
+    explicit counting_agent_type(ibf_t const & ibf) :
+        ibf_ptr(std::addressof(ibf)), membership_agent(ibf), result_buffer(ibf.bin_count())
+    {}
+    //!\}
+
+    //!\brief Stores the result of bulk_count().
+    counting_vector<value_t> result_buffer;
+
+    /*!\name Counting
+     * \{
+     */
+    /*!\brief Counts the occurrences in each bin for all values in a range.
+     * \tparam value_range_t The type of the range of values. Must model std::ranges::input_range. The reference type
+     *                       must model std::unsigned_integral.
+     * \param[in] values The range of values to process.
+     *
+     * \attention The result of this function must always be bound via reference, e.g. `auto &`, to prevent copying.
+     * \attention Sequential calls to this function invalidate the previously returned reference.
+     *
+     * \details
+     *
+     * ### Example
+     *
+     * \include test/snippet/search/dream_index/counting_agent.cpp
+     *
+     * ### Thread safety
+     *
+     * Concurrent invocations of this function are not thread safe, please create a
+     * seqan3::interleaved_bloom_filter::counting_agent_type for each thread.
+     */
+    template <std::ranges::range value_range_t>
+    [[nodiscard]] counting_vector<value_t> const & bulk_count(value_range_t && values) & noexcept
+    {
+        assert(ibf_ptr != nullptr);
+        assert(result_buffer.size() == ibf_ptr->bin_count());
+
+        static_assert(std::ranges::input_range<value_range_t>, "The values must model input_range.");
+        static_assert(std::unsigned_integral<std::ranges::range_value_t<value_range_t>>,
+                      "An individual value must be an unsigned integral.");
+
+        std::ranges::fill(result_buffer, 0);
+
+        for (auto && value : values)
+            result_buffer += membership_agent.bulk_contains(value);
+
+        return result_buffer;
+    }
+
+    // `bulk_count` cannot be called on a temporary, since the object the returned reference points to
+    // is immediately destroyed.
+    template <std::ranges::range value_range_t>
+    [[nodiscard]] counting_vector<value_t> const & bulk_count(value_range_t && values) && noexcept = delete;
+    //!\}
+
+};
 
 } // namespace seqan3
