@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2020, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2020, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -20,26 +20,56 @@
 
 #include <seqan3/alphabet/adaptation/char.hpp>
 #include <seqan3/alphabet/concept.hpp>
-#include <seqan3/core/type_traits/range.hpp>
-#include <seqan3/range/views/slice.hpp>
+#include <seqan3/core/range/type_traits.hpp>
+#include <seqan3/search/fm_index/concept.hpp>
 #include <seqan3/search/fm_index/detail/fm_index_cursor.hpp>
-#include <seqan3/search/fm_index/fm_index.hpp>
+#include <seqan3/utility/views/slice.hpp>
 
 namespace seqan3
 {
+//!\brief The underlying suffix array interval.
+//!\ingroup search_fm_index
+struct suffix_array_interval
+{
+    //!\brief The begin position of the interval ("left boundary").
+    size_t begin_position{};
+    //!\brief The exclusive end position of the interval ("right boundary").
+    size_t end_position{};
 
-/*!\addtogroup submodule_fm_index
- * \{
- */
+    /*!\name Comparison operators
+     * \{
+     */
+    /*!\brief Test for equality.
+     * \param[in] lhs A `seqan3::suffix_array_interval`.
+     * \param[in] rhs `seqan3::suffix_array_interval` to compare to.
+     * \returns `true` if equal, `false` otherwise.
+     */
+    friend bool operator==(suffix_array_interval const & lhs, suffix_array_interval const & rhs) noexcept
+    {
+        return lhs.begin_position == rhs.begin_position && lhs.end_position == rhs.end_position;
+    }
+
+    /*!\brief Test for inequality.
+     * \param[in] lhs A `seqan3::suffix_array_interval`.
+     * \param[in] rhs `seqan3::suffix_array_interval` to compare to.
+     * \returns `true` if unequal, `false` otherwise.
+     */
+    friend bool operator!=(suffix_array_interval const & lhs, suffix_array_interval const & rhs) noexcept
+    {
+        return !(lhs == rhs);
+    }
+    //!\}
+};
 
 /*!\brief The SeqAn FM Index Cursor.
- * \implements seqan3::fm_index_cursor_specialisation
- * \tparam index_t The type of the underlying index; must model seqan3::fm_index_specialisation.
+ * \ingroup search_fm_index
+ * \tparam index_t The type of the underlying index. This is normally seqan3::fm_index.
+ * \implements seqan3::cerealisable
  * \details
  *
  * The cursor's interface provides searching a string from left to right in the indexed text.
  * All methods modifying the cursor (e.g. extending by a character with extend_right()) return a `bool` value whether
- * the operation was successful or not. In case of an unsuccessful operation the cursor remains unmodified, i.e. an
+ * the operation was successful or not. In case of an unsuccessful operation the cursor remains unmodified, i.e. a
  * cursor can never be in an invalid state except default constructed cursors that are always invalid.
  *
  * \if DEV
@@ -167,7 +197,9 @@ public:
         index(&_index),
         node({0, _index.index.size() - 1, 0, 0}),
         sigma(_index.index.sigma - index_t::text_layout_mode)
-    {}
+    {
+        assert(_index.index.size() != 0);
+    }
     //\}
 
     /*!\brief Compares two cursors.
@@ -363,7 +395,7 @@ public:
      * \returns `true` if there exists a query in the text where the rightmost character of the query is
      *          lexicographically larger than the current rightmost character of the query.
      *
-     * Example:
+     * ### Example
      *
      * \include test/snippet/search/fm_index_cursor.cpp
      *
@@ -403,7 +435,7 @@ public:
     /*!\brief Outputs the rightmost rank.
      * \returns Rightmost rank.
      *
-     * Example:
+     * ### Example
      *
      * \include test/snippet/search/fm_index_cursor.cpp
      *
@@ -423,12 +455,38 @@ public:
         return index->index.comp2char[node.last_char] - 1; // text is not allowed to contain ranks of 0
     }
 
+    /*!\brief Returns the half-open suffix array interval.
+     * \returns A seqan3::suffix_array_interval contains the half-open interval.
+     *
+     * ### Example
+     *
+     * \include test/snippet/search/fm_index_cursor.cpp
+     *
+     * ### Complexity
+     *
+     * Constant.
+     *
+     * ### Exceptions
+     *
+     * No-throw guarantee.
+     */
+    seqan3::suffix_array_interval suffix_array_interval() const noexcept
+    {
+        assert(index != nullptr);
+
+        return {node.lb, node.rb + 1};
+    }
+
     /*!\brief Returns the length of the searched query.
      *        \if DEV
      *            Returns the depth of the cursor node in the implicit suffix tree.
      *        \endif
      * \returns Length of query.
      *
+     * ### Example
+     *
+     * \include test/snippet/search/fm_index_cursor.cpp
+     *
      * ### Complexity
      *
      * Constant.
@@ -612,17 +670,29 @@ public:
         return std::views::iota(node.lb, node.lb + count())
              | std::views::transform([*this, _offset = offset()] (auto sa_pos)
                {
-                   return _offset - index->index[sa_pos];
-               })
-             | std::views::transform([*this] (auto loc)
-               {
+                   auto loc = _offset - index->index[sa_pos];
                    size_type sequence_rank = index->text_begin_rs.rank(loc + 1);
                    size_type sequence_position = loc - index->text_begin_ss.select(sequence_rank);
                    return locate_result_value_type{sequence_rank - 1, sequence_position};
                });
     }
+
+    /*!\cond DEV
+     * \brief Serialisation support function.
+     * \tparam archive_t Type of `archive`; must satisfy seqan3::cereal_archive.
+     * \param archive The archive being serialised from/to.
+     *
+     * \attention These functions are never called directly, see \ref serialisation for more details.
+     */
+    template <cereal_archive archive_t>
+    void CEREAL_SERIALIZE_FUNCTION_NAME(archive_t & archive)
+    {
+        archive(parent_lb);
+        archive(parent_rb);
+        archive(node);
+        archive(sigma);
+    }
+    //!\endcond
 };
 
-//!\}
-
 } // namespace seqan3
