@@ -6,20 +6,19 @@
 // -----------------------------------------------------------------------------------------------------
 
 /*!\file
- * \brief Provides various type traits.
+ * \brief Meta-header for the \link utility_type_traits Utility / Type Traits submodule \endlink.
  * \author Hannes Hauswedell <hannes.hauswedell AT fu-berlin.de>
  */
 
-/*!\defgroup type_traits Type Traits
+/*!\defgroup utility_type_traits Type Traits
  * \brief Provides various type traits and their shortcuts.
  * \ingroup utility
+ * \see utility
  */
 
 #pragma once
 
 #include <seqan3/utility/type_traits/basic.hpp>
 #include <seqan3/utility/type_traits/concept.hpp>
-#include <seqan3/utility/type_traits/detail/transformation_trait_or.hpp>
 #include <seqan3/utility/type_traits/function_traits.hpp>
 #include <seqan3/utility/type_traits/lazy_conditional.hpp>
-#include <seqan3/utility/type_traits/pre.hpp>
