@@ -14,7 +14,6 @@
 
 #include <benchmark/benchmark.h>
 
-#include <seqan3/range/views/drop.hpp>
 #include <seqan3/utility/views/single_pass_input.hpp>
 
 // ============================================================================
@@ -60,52 +59,26 @@ void sequential_read(benchmark::State & state)
     [[maybe_unused]] volatile uint8_t dummy2 = dummy;
 }
 
-#ifdef SEQAN3_DEPRECATED_310
-//!brief Instance for usage until removed.
-inline constexpr auto seqan3_views_drop = seqan3::detail::drop_fn{};
-#endif // SEQAN3_DEPRECATED_310
-
 BENCHMARK_TEMPLATE(sequential_read, std::string, void);
 BENCHMARK_TEMPLATE(sequential_read, std::string, decltype(std::views::drop));
-#ifdef SEQAN3_DEPRECATED_310
-BENCHMARK_TEMPLATE(sequential_read, std::string, decltype(seqan3_views_drop));
-#endif // SEQAN3_DEPRECATED_310
 
 BENCHMARK_TEMPLATE(sequential_read, std::vector<uint8_t>, void);
 BENCHMARK_TEMPLATE(sequential_read, std::vector<uint8_t>, decltype(std::views::drop));
-#ifdef SEQAN3_DEPRECATED_310
-BENCHMARK_TEMPLATE(sequential_read, std::vector<uint8_t>, decltype(seqan3_views_drop));
-#endif // SEQAN3_DEPRECATED_310
 
 BENCHMARK_TEMPLATE(sequential_read, std::deque<uint8_t>, void);
 BENCHMARK_TEMPLATE(sequential_read, std::deque<uint8_t>, decltype(std::views::drop));
-#ifdef SEQAN3_DEPRECATED_310
-BENCHMARK_TEMPLATE(sequential_read, std::deque<uint8_t>, decltype(seqan3_views_drop));
-#endif // SEQAN3_DEPRECATED_310
 
 BENCHMARK_TEMPLATE(sequential_read, std::list<uint8_t>, void);
 BENCHMARK_TEMPLATE(sequential_read, std::list<uint8_t>, decltype(std::views::drop));
-#ifdef SEQAN3_DEPRECATED_310
-BENCHMARK_TEMPLATE(sequential_read, std::list<uint8_t>, decltype(seqan3_views_drop));
-#endif // SEQAN3_DEPRECATED_310
 
 BENCHMARK_TEMPLATE(sequential_read, std::forward_list<uint8_t>, void);
 BENCHMARK_TEMPLATE(sequential_read, std::forward_list<uint8_t>, decltype(std::views::drop));
-#ifdef SEQAN3_DEPRECATED_310
-BENCHMARK_TEMPLATE(sequential_read, std::forward_list<uint8_t>, decltype(seqan3_views_drop));
-#endif // SEQAN3_DEPRECATED_310
 
 BENCHMARK_TEMPLATE(sequential_read, std::vector<uint8_t>, void, true);
 BENCHMARK_TEMPLATE(sequential_read, std::vector<uint8_t>, decltype(std::views::drop), true);
-#ifdef SEQAN3_DEPRECATED_310
-BENCHMARK_TEMPLATE(sequential_read, std::vector<uint8_t>, decltype(seqan3_views_drop), true);
-#endif // SEQAN3_DEPRECATED_310
 
 BENCHMARK_TEMPLATE(sequential_read, std::forward_list<uint8_t>, void, true);
 BENCHMARK_TEMPLATE(sequential_read, std::forward_list<uint8_t>, decltype(std::views::drop), true);
-#ifdef SEQAN3_DEPRECATED_310
-BENCHMARK_TEMPLATE(sequential_read, std::forward_list<uint8_t>, decltype(seqan3_views_drop), true);
-#endif // SEQAN3_DEPRECATED_310
 
 // ============================================================================
 //  random access
@@ -155,21 +128,12 @@ void random_access(benchmark::State & state)
 
 BENCHMARK_TEMPLATE(random_access, std::string, void);
 BENCHMARK_TEMPLATE(random_access, std::string, decltype(std::views::drop));
-#ifdef SEQAN3_DEPRECATED_310
-BENCHMARK_TEMPLATE(random_access, std::string, decltype(seqan3_views_drop));
-#endif // SEQAN3_DEPRECATED_310
 
 BENCHMARK_TEMPLATE(random_access, std::vector<uint8_t>, void);
 BENCHMARK_TEMPLATE(random_access, std::vector<uint8_t>, decltype(std::views::drop));
-#ifdef SEQAN3_DEPRECATED_310
-BENCHMARK_TEMPLATE(random_access, std::vector<uint8_t>, decltype(seqan3_views_drop));
-#endif // SEQAN3_DEPRECATED_310
 
 BENCHMARK_TEMPLATE(random_access, std::deque<uint8_t>, void);
 BENCHMARK_TEMPLATE(random_access, std::deque<uint8_t>, decltype(std::views::drop));
-#ifdef SEQAN3_DEPRECATED_310
-BENCHMARK_TEMPLATE(random_access, std::deque<uint8_t>, decltype(seqan3_views_drop));
-#endif // SEQAN3_DEPRECATED_310
 
 // ============================================================================
 //  run
