@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2020, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2020, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -8,12 +8,13 @@
 #include <benchmark/benchmark.h>
 
 #include <seqan3/alphabet/nucleotide/dna4.hpp>
-#include <seqan3/range/views/join.hpp>
-#include <seqan3/range/views/to.hpp>
+#include <seqan3/core/detail/persist_view.hpp>
 #include <seqan3/search/fm_index/bi_fm_index.hpp>
 #include <seqan3/search/fm_index/fm_index.hpp>
 #include <seqan3/search/search.hpp>
 #include <seqan3/test/performance/sequence_generator.hpp>
+#include <seqan3/utility/views/join_with.hpp>
+#include <seqan3/utility/views/to.hpp>
 
 struct options
 {
@@ -64,7 +65,14 @@ std::vector<std::vector<alphabet_t>> generate_reads(std::vector<alphabet_t> cons
     std::vector<std::vector<alphabet_t>> reads;
     std::mt19937_64 gen{seed};
 
-    std::normal_distribution<> dis_error_count{static_cast<double>(simulated_errors), stddev};
+    auto error_count_distribution = [simulated_errors, stddev] (auto & generator) -> uint8_t
+    {
+        if (stddev <= 0)
+            return simulated_errors;
+
+        std::normal_distribution<> distribution{static_cast<double>(simulated_errors), stddev};
+        return std::abs(std::rint(distribution(generator)));
+    };
 
     // mutation distributions
     std::uniform_real_distribution<double> mutation_type_prob{0.0, 1.0};
@@ -78,7 +86,7 @@ std::vector<std::vector<alphabet_t>> generate_reads(std::vector<alphabet_t> cons
     for (size_t i = 0; i < number_of_reads; ++i)
     {
         // simulate concrete error number or use normal distribution
-        simulated_errors = (stddev == 0) ? simulated_errors : std::abs(std::round(dis_error_count(gen)));
+        simulated_errors = error_count_distribution(gen);
 
         std::uniform_int_distribution<size_t> random_read_pos{0, std::ranges::size(ref) - read_length - simulated_errors};
         size_t rpos = random_read_pos(gen);
@@ -135,8 +143,8 @@ std::vector<alphabet_t> generate_repeating_sequence(size_t const template_length
     len = (len + simulated_errors  > template_length) ? template_length - simulated_errors : len;
 
     return generate_reads(seq_template, repeats, len, simulated_errors, 0.15, 0.15)
-         | seqan3::views::persist
-         | seqan3::views::join
+         | seqan3::detail::persist
+         | std::views::join
          | seqan3::views::to<std::vector>;
 }
 
@@ -280,86 +288,96 @@ void bidirectional_search_stratified(benchmark::State & state, options && o)
     benchmark::DoNotOptimize(sum);
 }
 
+#ifndef NDEBUG
+inline constexpr size_t small_size = 1'000;
+inline constexpr size_t medium_size = 5'000;
+inline constexpr size_t big_size = 10'000;
+#else
+inline constexpr size_t small_size = 10'000;
+inline constexpr size_t medium_size = 50'000;
+inline constexpr size_t big_size = 100'000;
+#endif // NDEBUG
+
 BENCHMARK_CAPTURE(unidirectional_search_all_collection, highErrorReadsSearch0,
-                  options{10'000, false, 10, 50, 0.18, 0.18, 0, 0, 0, 1.75});
+                  options{small_size, false, 10, 50, 0.18, 0.18, 0, 0, 0, 1.75});
 BENCHMARK_CAPTURE(unidirectional_search_all_collection, highErrorReadsSearch1,
-                  options{10'000, false, 10, 50, 0.18, 0.18, 0, 1, 0, 1.75});
+                  options{small_size, false, 10, 50, 0.18, 0.18, 0, 1, 0, 1.75});
 BENCHMARK_CAPTURE(unidirectional_search_all_collection, highErrorReadsSearch2,
-                  options{10'000, false, 10, 50, 0.18, 0.18, 0, 2, 0, 1.75});
+                  options{small_size, false, 10, 50, 0.18, 0.18, 0, 2, 0, 1.75});
 BENCHMARK_CAPTURE(unidirectional_search_all_collection, highErrorReadsSearch3,
-                  options{10'000, false, 10, 50, 0.18, 0.18, 0, 3, 0, 1.75});
+                  options{small_size, false, 10, 50, 0.18, 0.18, 0, 3, 0, 1.75});
 
 BENCHMARK_CAPTURE(unidirectional_search_all, lowErrorReadsSearch3,
-                  options{100'000, false, 50, 50, 0.18, 0.18, 0, 3, 0, 1});
+                  options{big_size, false, 50, 50, 0.18, 0.18, 0, 3, 0, 1});
 BENCHMARK_CAPTURE(unidirectional_search_all, highErrorReadsSearch0,
-                  options{100'000, false, 50, 50, 0.18, 0.18, 0, 0, 0, 1.75});
+                  options{big_size, false, 50, 50, 0.18, 0.18, 0, 0, 0, 1.75});
 BENCHMARK_CAPTURE(unidirectional_search_all, highErrorReadsSearch1,
-                  options{100'000, false, 50, 50, 0.18, 0.18, 0, 1, 1, 1.75});
+                  options{big_size, false, 50, 50, 0.18, 0.18, 0, 1, 1, 1.75});
 BENCHMARK_CAPTURE(unidirectional_search_all, highErrorReadsSearch2,
-                  options{100'000, false, 50, 50, 0.18, 0.18, 0, 2, 2, 1.75});
+                  options{big_size, false, 50, 50, 0.18, 0.18, 0, 2, 2, 1.75});
 BENCHMARK_CAPTURE(unidirectional_search_all, highErrorReadsSearch3,
-                  options{100'000, false, 50, 50, 0.18, 0.18, 0, 3, 3, 1.75});
+                  options{big_size, false, 50, 50, 0.18, 0.18, 0, 3, 3, 1.75});
 BENCHMARK_CAPTURE(unidirectional_search_all, highErrorReadsSearch0Rep,
-                  options{100'000, true, 50, 50, 0.18, 0.18, 0, 0, 0, 1.75});
+                  options{big_size, true, 50, 50, 0.18, 0.18, 0, 0, 0, 1.75});
 BENCHMARK_CAPTURE(unidirectional_search_all, highErrorReadsSearch1Rep,
-                  options{100'000, true, 50, 50, 0.18, 0.18, 0, 1, 1, 1.75});
+                  options{big_size, true, 50, 50, 0.18, 0.18, 0, 1, 1, 1.75});
 BENCHMARK_CAPTURE(unidirectional_search_all, highErrorReadsSearch2Rep,
-                  options{100'000, true, 50, 50, 0.18, 0.18, 0, 2, 2, 1.75});
+                  options{big_size, true, 50, 50, 0.18, 0.18, 0, 2, 2, 1.75});
 BENCHMARK_CAPTURE(unidirectional_search_all, highErrorReadsSearch3Rep,
-                  options{100'000, true, 50, 50, 0.18, 0.18, 0, 3, 3, 1.75});
+                  options{big_size, true, 50, 50, 0.18, 0.18, 0, 3, 3, 1.75});
 BENCHMARK_CAPTURE(unidirectional_search_all, highErrorReadsSearch3Rep,
-                  options{100'000, true, 50, 50, 0.30, 0.30, 0, 3, 3, 1.75});
+                  options{big_size, true, 50, 50, 0.30, 0.30, 0, 3, 3, 1.75});
 
 BENCHMARK_CAPTURE(bidirectional_search_all, lowErrorReadsSearch3,
-                  options{100'000, false, 50, 50, 0.18, 0.18, 0, 3, 0, 1});
+                  options{big_size, false, 50, 50, 0.18, 0.18, 0, 3, 0, 1});
 BENCHMARK_CAPTURE(bidirectional_search_all, highErrorReadsSearch0,
-                  options{100'000, false, 50, 50, 0.18, 0.18, 0, 0, 0, 1.75});
+                  options{big_size, false, 50, 50, 0.18, 0.18, 0, 0, 0, 1.75});
 BENCHMARK_CAPTURE(bidirectional_search_all, highErrorReadsSearch1,
-                  options{100'000, false, 50, 50, 0.18, 0.18, 0, 1, 1, 1.75});
+                  options{big_size, false, 50, 50, 0.18, 0.18, 0, 1, 1, 1.75});
 BENCHMARK_CAPTURE(bidirectional_search_all, highErrorReadsSearch2,
-                  options{100'000, false, 50, 50, 0.18, 0.18, 0, 2, 2, 1.75});
+                  options{big_size, false, 50, 50, 0.18, 0.18, 0, 2, 2, 1.75});
 BENCHMARK_CAPTURE(bidirectional_search_all, highErrorReadsSearch3,
-                  options{100'000, false, 50, 50, 0.18, 0.18, 0, 3, 3, 1.75});
+                  options{big_size, false, 50, 50, 0.18, 0.18, 0, 3, 3, 1.75});
 BENCHMARK_CAPTURE(bidirectional_search_all, highErrorReadsSearch0Rep,
-                  options{100'000, true, 50, 50, 0.18, 0.18, 0, 0, 0, 1.75});
+                  options{big_size, true, 50, 50, 0.18, 0.18, 0, 0, 0, 1.75});
 BENCHMARK_CAPTURE(bidirectional_search_all, highErrorReadsSearch1Rep,
-                  options{100'000, true, 50, 50, 0.18, 0.18, 0, 1, 1, 1.75});
+                  options{big_size, true, 50, 50, 0.18, 0.18, 0, 1, 1, 1.75});
 BENCHMARK_CAPTURE(bidirectional_search_all, highErrorReadsSearch2Rep,
-                  options{100'000, true, 50, 50, 0.18, 0.18, 0, 2, 2, 1.75});
+                  options{big_size, true, 50, 50, 0.18, 0.18, 0, 2, 2, 1.75});
 BENCHMARK_CAPTURE(bidirectional_search_all, highErrorReadsSearch3Rep,
-                  options{100'000, true, 50, 50, 0.18, 0.18, 0, 3, 3, 1.75});
+                  options{big_size, true, 50, 50, 0.18, 0.18, 0, 3, 3, 1.75});
 BENCHMARK_CAPTURE(bidirectional_search_all, highErrorReadsSearch3Rep,
-                  options{100'000, true, 50, 50, 0.30, 0.30, 0, 3, 3, 1.75});
+                  options{big_size, true, 50, 50, 0.30, 0.30, 0, 3, 3, 1.75});
 
 BENCHMARK_CAPTURE(unidirectional_search_stratified, lowErrorReadsSearch3Strata0Rep,
-                  options{50'000, true, 50, 50, 0.18, 0.18, 0, 3, 0, 1});
+                  options{medium_size, true, 50, 50, 0.18, 0.18, 0, 3, 0, 1});
 BENCHMARK_CAPTURE(unidirectional_search_stratified, lowErrorReadsSearch3Strata1Rep,
-                  options{50'000, true, 50, 50, 0.18, 0.18, 0, 3, 1, 1});
+                  options{medium_size, true, 50, 50, 0.18, 0.18, 0, 3, 1, 1});
 BENCHMARK_CAPTURE(unidirectional_search_stratified, lowErrorReadsSearch3Strata2Rep,
-                  options{50'000, true, 50, 50, 0.18, 0.18, 0, 3, 2, 1});
+                  options{medium_size, true, 50, 50, 0.18, 0.18, 0, 3, 2, 1});
 BENCHMARK_CAPTURE(unidirectional_search_stratified, highErrorReadsSearch3Strata0Rep,
-                  options{50'000, true, 50, 50, 0.30, 0.30, 0, 3, 0, 1.75});
+                  options{medium_size, true, 50, 50, 0.30, 0.30, 0, 3, 0, 1.75});
 BENCHMARK_CAPTURE(unidirectional_search_stratified, highErrorReadsSearch3Strata1Rep,
-                  options{50'000, true, 50, 50, 0.30, 0.30, 0, 3, 1, 1.75});
+                  options{medium_size, true, 50, 50, 0.30, 0.30, 0, 3, 1, 1.75});
 BENCHMARK_CAPTURE(unidirectional_search_stratified, highErrorReadsSearch3Strata2Rep,
-                  options{50'000, true, 50, 50, 0.30, 0.30, 0, 3, 2, 1.75});
+                  options{medium_size, true, 50, 50, 0.30, 0.30, 0, 3, 2, 1.75});
 BENCHMARK_CAPTURE(unidirectional_search_stratified, highErrorReadsSearch3Strata2RepLong,
-                  options{100'000, true, 50, 50, 0.30, 0.30, 0, 3, 2, 1.75});
+                  options{big_size, true, 50, 50, 0.30, 0.30, 0, 3, 2, 1.75});
 
 BENCHMARK_CAPTURE(bidirectional_search_stratified, lowErrorReadsSearch3Strata0Rep,
-                  options{50'000, true, 50, 50, 0.18, 0.18, 0, 3, 0, 1});
+                  options{medium_size, true, 50, 50, 0.18, 0.18, 0, 3, 0, 1});
 BENCHMARK_CAPTURE(bidirectional_search_stratified, lowErrorReadsSearch3Strata1Rep,
-                  options{50'000, true, 50, 50, 0.18, 0.18, 0, 3, 1, 1});
+                  options{medium_size, true, 50, 50, 0.18, 0.18, 0, 3, 1, 1});
 BENCHMARK_CAPTURE(bidirectional_search_stratified, lowErrorReadsSearch3Strata2Rep,
-                  options{50'000, true, 50, 50, 0.18, 0.18, 0, 3, 2, 1});
+                  options{medium_size, true, 50, 50, 0.18, 0.18, 0, 3, 2, 1});
 BENCHMARK_CAPTURE(bidirectional_search_stratified, highErrorReadsSearch3Strata0Rep,
-                  options{50'000, true, 50, 50, 0.30, 0.30, 0, 3, 0, 1.75});
+                  options{medium_size, true, 50, 50, 0.30, 0.30, 0, 3, 0, 1.75});
 BENCHMARK_CAPTURE(bidirectional_search_stratified, highErrorReadsSearch3Strata1Rep,
-                  options{50'000, true, 50, 50, 0.30, 0.30, 0, 3, 1, 1.75});
+                  options{medium_size, true, 50, 50, 0.30, 0.30, 0, 3, 1, 1.75});
 BENCHMARK_CAPTURE(bidirectional_search_stratified, highErrorReadsSearch3Strata2Rep,
-                  options{50'000, true, 50, 50, 0.30, 0.30, 0, 3, 2, 1.75});
+                  options{medium_size, true, 50, 50, 0.30, 0.30, 0, 3, 2, 1.75});
 BENCHMARK_CAPTURE(bidirectional_search_stratified, highErrorReadsSearch3Strata2RepLong,
-                  options{100'000, true, 50, 50, 0.30, 0.30, 0, 3, 2, 1.75});
+                  options{big_size, true, 50, 50, 0.30, 0.30, 0, 3, 2, 1.75});
 
 // ============================================================================
 //  instantiate tests
