@@ -3,7 +3,7 @@
 
 int main()
 {
-    using seqan3::operator""_dna5;
+    using namespace seqan3::literals;
 
     seqan3::alphabet_variant<seqan3::dna4, seqan3::dna5> var;
     var.assign_char('A');             // will be in the "dna4-state"
