@@ -1,6 +1,4 @@
 #include <seqan3/argument_parser/all.hpp>
-#include <seqan3/range/views/all.hpp>
-#include <seqan3/range/views/get.hpp>
 
 namespace foo
 {
@@ -15,7 +13,7 @@ enum class bar
 // Specialise a mapping from an identifying string to the respective value of your type bar.
 auto enumeration_names(bar)
 {
-    return std::unordered_map<std::string_view, bar>{{"one", bar::one}, {"two", bar::two}, {"three", bar::three}};;
+    return std::unordered_map<std::string_view, bar>{{"one", bar::one}, {"two", bar::two}, {"three", bar::three}};
 }
 
 } // namespace foo
@@ -28,8 +26,8 @@ int main(int argc, char const * argv[])
 
     // Because of the enumeration_names function
     // you can now add an option that takes a value of type bar:
-    parser.add_option(value, 'f', "foo", "Give me a foo value.", seqan3::option_spec::DEFAULT,
-                      seqan3::value_list_validator{(seqan3::enumeration_names<foo::bar> | seqan3::views::get<1>)});
+    parser.add_option(value, 'f', "foo", "Give me a foo value.", seqan3::option_spec::standard,
+                      seqan3::value_list_validator{(seqan3::enumeration_names<foo::bar> | std::views::values)});
 
     try
     {
