@@ -1,12 +1,12 @@
 #include <iostream>
 
 #include <seqan3/alphabet/nucleotide/dna5.hpp>
+#include <seqan3/alphabet/views/to_rank.hpp>
 #include <seqan3/core/debug_stream.hpp>
-#include <seqan3/range/views/to_rank.hpp>
 
 int main()
 {
-    using seqan3::operator""_dna5;
+    using namespace seqan3::literals;
 
     // The alphabet normally needs to be converted to char explicitly:
     std::cout << seqan3::to_char('C'_dna5);                // prints 'C'
