@@ -1,8 +1,8 @@
+#include <seqan3/std/ranges>
 #include <vector>
 
 #include <seqan3/alphabet/nucleotide/dna4.hpp>
 #include <seqan3/core/detail/strong_type.hpp>
-#include <seqan3/std/ranges>
 
 struct error : seqan3::detail::strong_type<unsigned, error>
 {
@@ -14,26 +14,29 @@ struct window_size : seqan3::detail::strong_type<unsigned, window_size>
     using seqan3::detail::strong_type<unsigned, window_size>::strong_type;
 };
 
-namespace seqan3::detail
+namespace detail
 {
-template <std::ranges::forward_range fwd_rng_type>
-    bool do_find(fwd_rng_type &, int const, int const) { return true; }
-}  // namespace seqan3::detail
 
 template <std::ranges::forward_range fwd_rng_type>
-    bool search(fwd_rng_type & rng, window_size const w, error const e)
+bool do_find(fwd_rng_type const &, uint8_t const, uint8_t const)
 {
-    // do something
-    return seqan3::detail::do_find(rng, w.get(), e.get());
+    return true;
+}
+
+}  // namespace detail
+
+template <std::ranges::forward_range fwd_rng_type>
+bool search(fwd_rng_type const & rng, window_size const window_size, error const error)
+{
+    return detail::do_find(rng, window_size.get(), error.get());
 }
 
 int main()
 {
-    using seqan3::operator""_dna4;
+    using namespace seqan3::literals;
+
+    std::vector<seqan3::dna4> range = "ACGTT"_dna4;
+    search(range, window_size{4u}, error{2u});
 
-    std::vector<seqan3::dna4> my_range = "ACGTT"_dna4;
-    // do something
-    search(my_range, window_size{4}, error{2});
-    // do something
     return 0;
 }
