@@ -1,7 +1,6 @@
 #include <sstream>
 
-#include <seqan3/io/stream/iterator.hpp>
-#include <seqan3/range/detail/misc.hpp>
+#include <seqan3/io/stream/detail/fast_ostreambuf_iterator.hpp>
 
 int main()
 {
@@ -25,7 +24,7 @@ int main()
     auto it = std::ranges::begin(sequence);
     while (it != std::ranges::end(sequence))
     {
-        /* Note that you need cannot use stream_it.write_range(rng | seqan3::views::take(10) here
+        /* Note that you need cannot use stream_it.write_range(rng | std::views::take(10)) here
          * because the returned iterator is not of the correct type.
          */
         auto current_end = it;
