@@ -1,7 +1,7 @@
 #include <sstream>
 
-#include <seqan3/core/type_list/type_list.hpp>
 #include <seqan3/io/sequence_file/input.hpp>
+#include <seqan3/utility/type_list/type_list.hpp>
 
 // ... input had amino acid sequences
 auto input = R"(> TEST1
