@@ -2,12 +2,12 @@
 #include <string>
 
 #include <seqan3/alphabet/nucleotide/dna5.hpp>
-#include <seqan3/core/type_list/type_list.hpp>
 #include <seqan3/io/sequence_file/output.hpp>
+#include <seqan3/utility/type_list/type_list.hpp>
 
 int main()
 {
-    using seqan3::operator""_dna5;
+    using namespace seqan3::literals;
 
     seqan3::sequence_file_output fout{std::ostringstream{}, seqan3::format_fasta{}};
     for(int i = 0; i < 5; ++i) // some criteria
