@@ -2,14 +2,13 @@
 #include <string>
 #include <vector>
 
+#include <seqan3/alphabet/container/concatenated_sequences.hpp>
 #include <seqan3/alphabet/nucleotide/rna5.hpp>
 #include <seqan3/alphabet/structure/wuss.hpp>
 #include <seqan3/io/structure_file/output.hpp>
-#include <seqan3/range/container/concatenated_sequences.hpp>
-#include <seqan3/range/views/zip.hpp>
+#include <seqan3/utility/views/zip.hpp>
 
-using seqan3::operator""_rna5;
-using seqan3::operator""_wuss51;
+using namespace seqan3::literals;
 
 struct data_storage_t
 {
