@@ -1,10 +1,12 @@
-#include <seqan3/alphabet/nucleotide/dna4.hpp>
-#include <seqan3/range/views/complement.hpp>
 #include <seqan3/std/ranges>
 
+#include <seqan3/alphabet/nucleotide/dna4.hpp>
+#include <seqan3/alphabet/views/complement.hpp>
+#include <seqan3/core/debug_stream.hpp>
+
 int main()
 {
-    using seqan3::operator""_dna4;
+    using namespace seqan3::literals;
 
     seqan3::dna4_vector vec{"ACGGTC"_dna4};
     // views can be composed iteratively
@@ -15,4 +17,6 @@ int main()
     auto vec_view5 = vec | seqan3::views::complement | std::views::reverse;
 
     // vec_view4 and vec_view5 are the reverse complement of "ACGGTC": "GACCGT"
+    seqan3::debug_stream << vec_view4 << '\n'; // GACCGT
+    seqan3::debug_stream << vec_view5 << '\n'; // GACCGT
 }
