@@ -7,7 +7,7 @@
 
 int main()
 {
-    using seqan3::operator""_dna4;
+    using namespace seqan3::literals;
     std::vector<seqan3::dna4_vector> genomes{"CGCTGTCTGAAGGATGAGTGTCAGCCAGTGTA"_dna4,
                                              "ACCCGATGAGCTACCCAGTAGTCGAACTG"_dna4,
                                              "GGCCAGACAACCCGGCGCTAATGCACTCA"_dna4};
