@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2020, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2020, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -50,8 +50,10 @@ static auto dna4_01 = []()
         11,
         "GTTTA",
         "GTCTA",
-        seqan3::alignment_coordinate{column_index_type{5u}, row_index_type{2u}},
-        seqan3::alignment_coordinate{column_index_type{10u}, row_index_type{7u}},
+        /*.sequence1_begin_position = */ 5u,
+        /*.sequence2_begin_position = */ 2u,
+        /*.sequence1_end_position = */ 10u,
+        /*.sequence2_end_position = */ 7u,
         std::vector
         {
         //     e, A, A, C, C, G, G, T, T, T, A, A, C, C, G, G, T, T
@@ -102,8 +104,10 @@ static auto dna4_02 = []()
         11,
         "GTCTA",
         "GTTTA",
-        seqan3::alignment_coordinate{column_index_type{2u}, row_index_type{5u}},
-        seqan3::alignment_coordinate{column_index_type{7u}, row_index_type{10u}},
+        /*.sequence1_begin_position = */ 2u,
+        /*.sequence2_begin_position = */ 5u,
+        /*.sequence1_end_position = */ 7u,
+        /*.sequence2_end_position = */ 10u,
         std::vector
         {
         //     e, A, C, G, T, C, T, A, C, G, T, A
@@ -169,8 +173,10 @@ static auto dna4_03 = []()
         9,
         "ATAAGCGT",
         "AT-AGAGT",
-        seqan3::alignment_coordinate{column_index_type{0u}, row_index_type{2u}},
-        seqan3::alignment_coordinate{column_index_type{8u}, row_index_type{9u}},
+        /*.sequence1_begin_position = */ 0u,
+        /*.sequence2_begin_position = */ 2u,
+        /*.sequence1_end_position = */ 8u,
+        /*.sequence2_end_position = */ 9u,
         std::vector
         {
         //    e,A,T,A,A,G,C,G,T,C,T,C,G
@@ -223,8 +229,10 @@ static auto dna4_04 = []()
         0,
         "",
         "",
-        seqan3::alignment_coordinate{column_index_type{0u}, row_index_type{0u}},
-        seqan3::alignment_coordinate{column_index_type{0u}, row_index_type{0u}},
+        /*.sequence1_begin_position = */ 0u,
+        /*.sequence2_begin_position = */ 0u,
+        /*.sequence1_end_position = */ 0u,
+        /*.sequence2_end_position = */ 0u,
         std::vector
         {
         //    e,A,A,A,A,A,A
@@ -265,8 +273,10 @@ static auto dna4_05 = []()
         24,
         "AAAAAA",
         "AAAAAA",
-        seqan3::alignment_coordinate{column_index_type{0u}, row_index_type{7u}},
-        seqan3::alignment_coordinate{column_index_type{6u}, row_index_type{13u}},
+        /*.sequence1_begin_position = */ 0u,
+        /*.sequence2_begin_position = */ 7u,
+        /*.sequence1_end_position = */ 6u,
+        /*.sequence2_end_position = */ 13u,
         std::vector
         {
         //     e, A, A, A, A, A, A, T, C, C, C, C, C, C
@@ -321,8 +331,10 @@ static auto rna5_01 = []()
         28,
         "AAAAAAUUUUNNUUUUCCCCCC",
         "AAAAAA----------CCCCCC",
-        seqan3::alignment_coordinate{column_index_type{0u}, row_index_type{0u}},
-        seqan3::alignment_coordinate{column_index_type{22u}, row_index_type{12u}},
+        /*.sequence1_begin_position = */ 0u,
+        /*.sequence2_begin_position = */ 0u,
+        /*.sequence1_end_position = */ 22u,
+        /*.sequence2_end_position = */ 12u,
         std::vector
         {
         //     e, A, A, A, A, A, A, U, U, U, U, N, N, U, U, U, U, C, C, C, C, C, C
@@ -360,7 +372,7 @@ static auto rna5_01 = []()
     };
 }();
 
-// Local alignment for proteins (amino acid sequence) with BLOSUM62 score.
+// Local alignment for proteins (amino acid sequence) with blosum62 score.
 static auto aa27_01 = []()
 {
     using seqan3::detail::column_index_type;
@@ -371,12 +383,14 @@ static auto aa27_01 = []()
         "ALIGATOR"_aa27,
         "GALORA"_aa27,
         align_config
-        | seqan3::align_cfg::scoring_scheme{aminoacid_scoring_scheme{aminoacid_similarity_matrix::BLOSUM62}},
+        | seqan3::align_cfg::scoring_scheme{aminoacid_scoring_scheme{aminoacid_similarity_matrix::blosum62}},
         13,
         "GATOR",
         "GALOR",
-        seqan3::alignment_coordinate{column_index_type{3u}, row_index_type{0u}},
-        seqan3::alignment_coordinate{column_index_type{8u}, row_index_type{5u}},
+        /*.sequence1_begin_position = */ 3u,
+        /*.sequence2_begin_position = */ 0u,
+        /*.sequence1_end_position = */ 8u,
+        /*.sequence2_end_position = */ 5u,
         std::vector
         {
         //     e, A, L, I, G, A, T, O, R
@@ -413,12 +427,14 @@ static auto aa27_02 = []()
         "ALIGATOR"_aa27,
         ""_aa27,
         align_config
-        | seqan3::align_cfg::scoring_scheme{aminoacid_scoring_scheme{aminoacid_similarity_matrix::BLOSUM62}},
+        | seqan3::align_cfg::scoring_scheme{aminoacid_scoring_scheme{aminoacid_similarity_matrix::blosum62}},
         0,
         "",
         "",
-        seqan3::alignment_coordinate{column_index_type{0u}, row_index_type{0u}},
-        seqan3::alignment_coordinate{column_index_type{0u}, row_index_type{0u}},
+        /*.sequence1_begin_position = */ 0u,
+        /*.sequence2_begin_position = */ 0u,
+        /*.sequence1_end_position = */ 0u,
+        /*.sequence2_end_position = */ 0u,
         std::vector
         {
         //e,A,L,I,G,A,T,O,R
