@@ -1,17 +1,17 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2020, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2020, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
 
 #include <fstream>
+#include <seqan3/std/ranges>
 
 #include <gtest/gtest.h>
 
 #include <seqan3/argument_parser/argument_parser.hpp>
 #include <seqan3/argument_parser/detail/format_help.hpp>
-#include <seqan3/std/ranges>
 
 // reused global variables
 std::string std_cout;
@@ -19,10 +19,10 @@ std::string expected;
 int option_value{5};
 bool flag_value{};
 std::vector<std::string> pos_opt_value{};
-const char * argv0[] = {"./help_add_test --version-check 0"};
-const char * argv1[] = {"./help_add_test --version-check 0", "-h"};
-const char * argv2[] = {"./help_add_test --version-check 0", "-hh"};
-const char * argv3[] = {"./help_add_test --version-check 0", "--version"};
+const char * argv0[] = {"./help_add_test --version-check false"};
+const char * argv1[] = {"./help_add_test --version-check false", "-h"};
+const char * argv2[] = {"./help_add_test --version-check false", "-hh"};
+const char * argv3[] = {"./help_add_test --version-check false", "--version"};
 
 std::string const basic_options_str = "OPTIONS\n"
                                       "\n"
@@ -38,14 +38,12 @@ std::string const basic_options_str = "OPTIONS\n"
                                       "    --export-help (std::string)\n"
                                       "          Export the help page information. Value must be one of [html, man].\n"
                                       "    --version-check (bool)\n"
-                                      "          Whether to to check for the newest app version. Default: 1.\n"
-                                      "\n"
-                                      "  \n";
+                                      "          Whether to check for the newest app version. Default: true.\n";
 
 std::string const basic_version_str = "VERSION\n"
-                                      "    Last update: \n"
-                                      "    test_parser version: \n"
-                                      "    SeqAn version: " + seqan3::seqan3_version + "\n";
+                                      "    Last update:\n"
+                                      "    test_parser version:\n"
+                                      "    SeqAn version: " + std::string{seqan3::seqan3_version_cstring} + "\n";
 
 std::string license_text()
 {
@@ -116,6 +114,7 @@ TEST(help_page_printing, with_short_copyright)
 {
     // Again, but with short copyright, long copyright, and citation.
     seqan3::argument_parser short_copy("test_parser", 2, argv1);
+    test_accessor::set_terminal_width(short_copy, 80);
     short_copy.info.short_copyright = "short";
     testing::internal::CaptureStdout();
     EXPECT_EXIT(short_copy.parse(), ::testing::ExitedWithCode(EXIT_SUCCESS), "");
@@ -129,13 +128,15 @@ TEST(help_page_printing, with_short_copyright)
                "\n" +
                "LEGAL\n"
                "    test_parser Copyright: short\n"
-               "    SeqAn Copyright: 2006-2015 Knut Reinert, FU-Berlin; released under the 3-clause BSDL.\n";
+               "    SeqAn Copyright: 2006-2021 Knut Reinert, FU-Berlin; released under the\n"
+               "    3-clause BSDL.\n";
     EXPECT_EQ(std_cout, expected);
 }
 
 TEST(help_page_printing, with_long_copyright)
 {
     seqan3::argument_parser long_copy("test_parser", 2, argv1);
+    test_accessor::set_terminal_width(long_copy, 80);
     long_copy.info.long_copyright = "long";
     testing::internal::CaptureStdout();
     EXPECT_EXIT(long_copy.parse(), ::testing::ExitedWithCode(EXIT_SUCCESS), "");
@@ -148,7 +149,8 @@ TEST(help_page_printing, with_long_copyright)
                basic_version_str +
                "\n" +
                "LEGAL\n"
-               "    SeqAn Copyright: 2006-2015 Knut Reinert, FU-Berlin; released under the 3-clause BSDL.\n"
+               "    SeqAn Copyright: 2006-2021 Knut Reinert, FU-Berlin; released under the\n"
+               "    3-clause BSDL.\n"
                "    For full copyright and/or warranty information see --copyright.\n";
     EXPECT_EQ(std_cout, expected);
 }
@@ -156,6 +158,7 @@ TEST(help_page_printing, with_long_copyright)
 TEST(help_page_printing, with_citation)
 {
     seqan3::argument_parser citation("test_parser", 2, argv1);
+    test_accessor::set_terminal_width(citation, 80);
     citation.info.citation = "citation";
     testing::internal::CaptureStdout();
     EXPECT_EXIT(citation.parse(), ::testing::ExitedWithCode(EXIT_SUCCESS), "");
@@ -168,11 +171,56 @@ TEST(help_page_printing, with_citation)
                basic_version_str +
                "\n" +
                "LEGAL\n"
-               "    SeqAn Copyright: 2006-2015 Knut Reinert, FU-Berlin; released under the 3-clause BSDL.\n"
+               "    SeqAn Copyright: 2006-2021 Knut Reinert, FU-Berlin; released under the\n"
+               "    3-clause BSDL.\n"
                "    In your academic works please cite: citation\n";
     EXPECT_EQ(std_cout, expected);
 }
 
+TEST(help_page_printing, with_author)
+{
+    seqan3::argument_parser author("test_parser", 2, argv1);
+    test_accessor::set_terminal_width(author, 80);
+    author.info.author = "author";
+    testing::internal::CaptureStdout();
+    EXPECT_EXIT(author.parse(), ::testing::ExitedWithCode(EXIT_SUCCESS), "");
+    std_cout = testing::internal::GetCapturedStdout();
+    expected = "test_parser\n"
+               "===========\n"
+               "\n" +
+               basic_options_str +
+               "\n" +
+               basic_version_str +
+               "\n" +
+               "LEGAL\n"
+               "    Author: author\n"
+               "    SeqAn Copyright: 2006-2021 Knut Reinert, FU-Berlin; released under the\n"
+               "    3-clause BSDL.\n";
+    EXPECT_EQ(std_cout, expected);
+}
+
+TEST(help_page_printing, with_email)
+{
+    seqan3::argument_parser email("test_parser", 2, argv1);
+    test_accessor::set_terminal_width(email, 80);
+    email.info.email = "email";
+    testing::internal::CaptureStdout();
+    EXPECT_EXIT(email.parse(), ::testing::ExitedWithCode(EXIT_SUCCESS), "");
+    std_cout = testing::internal::GetCapturedStdout();
+    expected = "test_parser\n"
+               "===========\n"
+               "\n" +
+               basic_options_str +
+               "\n" +
+               basic_version_str +
+               "\n" +
+               "LEGAL\n"
+               "    Contact: email\n"
+               "    SeqAn Copyright: 2006-2021 Knut Reinert, FU-Berlin; released under the\n"
+               "    3-clause BSDL.\n";
+    EXPECT_EQ(std_cout, expected);
+}
+
 TEST(help_page_printing, empty_advanced_help)
 {
     // Empty help call with -hh
@@ -210,7 +258,7 @@ TEST(help_page_printing, version_call)
     // Version call with url and options.
     seqan3::argument_parser parser4{"test_parser", 2, argv3};
     test_accessor::set_terminal_width(parser4, 80);
-    parser4.info.url = "www.seqan.de";
+    parser4.info.url = "https://seqan.de";
     parser4.add_option(option_value, 'i', "int", "this is a int option.");
     parser4.add_flag(flag_value, 'f', "flag", "this is a flag.");
     parser4.add_positional_option(pos_opt_value, "this is a positional option.");
@@ -221,9 +269,9 @@ TEST(help_page_printing, version_call)
                "===========\n"
                "\n" +
                basic_version_str +
+               "\n" +
                "URL\n"
-               "    www.seqan.de\n"
-               "\n";
+               "    https://seqan.de\n";
     EXPECT_EQ(std_cout, expected);
 }
 
@@ -232,8 +280,8 @@ TEST(help_page_printing, do_not_print_hidden_options)
     // Add an option and request help.
     seqan3::argument_parser parser5{"test_parser", 2, argv1};
     test_accessor::set_terminal_width(parser5, 80);
-    parser5.add_option(option_value, 'i', "int", "this is a int option.", seqan3::option_spec::HIDDEN);
-    parser5.add_flag(flag_value, 'f', "flag", "this is a flag.", seqan3::option_spec::HIDDEN);
+    parser5.add_option(option_value, 'i', "int", "this is a int option.", seqan3::option_spec::hidden);
+    parser5.add_flag(flag_value, 'f', "flag", "this is a flag.", seqan3::option_spec::hidden);
     testing::internal::CaptureStdout();
     EXPECT_EXIT(parser5.parse(), ::testing::ExitedWithCode(EXIT_SUCCESS), "");
     std_cout = testing::internal::GetCapturedStdout();
@@ -254,32 +302,33 @@ TEST(help_page_printing, advanced_options)
     auto set_up = [&option_value, &flag_value] (seqan3::argument_parser & parser)
     {
         // default or required information are always displayed
-        parser.add_section("default section", seqan3::option_spec::REQUIRED);
-        parser.add_subsection("default subsection", seqan3::option_spec::REQUIRED); // same as DEFAULT
-        parser.add_option(option_value, 'i', "int", "this is a int option.", seqan3::option_spec::REQUIRED);
-        parser.add_flag(flag_value, 'g', "goo", "this is a flag.", seqan3::option_spec::REQUIRED); // same as DEFAULT
-        parser.add_list_item("-s, --some", "list item.", seqan3::option_spec::REQUIRED); // same as DEFAULT
-        parser.add_line("some line.", true, seqan3::option_spec::REQUIRED); // same as DEFAULT
+        parser.add_section("default section", seqan3::option_spec::required);
+        parser.add_subsection("default subsection", seqan3::option_spec::required); // same as DEFAULT
+        parser.add_option(option_value, 'i', "int", "this is a int option.", seqan3::option_spec::required);
+        parser.add_flag(flag_value, 'g', "goo", "this is a flag.", seqan3::option_spec::required); // same as DEFAULT
+        parser.add_list_item("-s, --some", "list item.", seqan3::option_spec::required); // same as DEFAULT
+        parser.add_line("some line.", true, seqan3::option_spec::required); // same as DEFAULT
 
         // advanced information
-        parser.add_section("advanced section", seqan3::option_spec::ADVANCED);
-        parser.add_subsection("advanced subsection", seqan3::option_spec::ADVANCED);
-        parser.add_option(option_value, 'j', "jnt", "this is a int option.", seqan3::option_spec::ADVANCED);
-        parser.add_flag(flag_value, 'f', "flag", "this is a flag.", seqan3::option_spec::ADVANCED);
-        parser.add_list_item("-s, --some", "list item.", seqan3::option_spec::ADVANCED);
-        parser.add_line("some line.", true, seqan3::option_spec::ADVANCED);
+        parser.add_section("advanced section", seqan3::option_spec::advanced);
+        parser.add_subsection("advanced subsection", seqan3::option_spec::advanced);
+        parser.add_option(option_value, 'j', "jnt", "this is a int option.", seqan3::option_spec::advanced);
+        parser.add_flag(flag_value, 'f', "flag", "this is a flag.", seqan3::option_spec::advanced);
+        parser.add_list_item("-s, --some", "list item.", seqan3::option_spec::advanced);
+        parser.add_line("some line.", true, seqan3::option_spec::advanced);
 
         // hidden information (never displayed, normally used for options not section information)
-        parser.add_section("hidden section", seqan3::option_spec::HIDDEN);
-        parser.add_subsection("hidden subsection", seqan3::option_spec::HIDDEN);
-        parser.add_option(option_value, 'd', "dnt", "hidden option.", seqan3::option_spec::HIDDEN);
-        parser.add_flag(flag_value, 'l', "lflag", "hidden a flag.", seqan3::option_spec::HIDDEN);
-        parser.add_list_item("-s, --some", "hidden list item.", seqan3::option_spec::HIDDEN);
-        parser.add_line("hidden line.", true, seqan3::option_spec::HIDDEN);
+        parser.add_section("hidden section", seqan3::option_spec::hidden);
+        parser.add_subsection("hidden subsection", seqan3::option_spec::hidden);
+        parser.add_option(option_value, 'd', "dnt", "hidden option.", seqan3::option_spec::hidden);
+        parser.add_flag(flag_value, 'l', "lflag", "hidden a flag.", seqan3::option_spec::hidden);
+        parser.add_list_item("-s, --some", "hidden list item.", seqan3::option_spec::hidden);
+        parser.add_line("hidden line.", true, seqan3::option_spec::hidden);
     };
 
     // without -hh, only the non/advanced information are shown
     seqan3::argument_parser parser_normal_help{"test_parser", 2, argv1};
+    test_accessor::set_terminal_width(parser_normal_help, 80);
     set_up(parser_normal_help);
     testing::internal::CaptureStdout();
     EXPECT_EXIT(parser_normal_help.parse(), ::testing::ExitedWithCode(EXIT_SUCCESS), "");
@@ -305,6 +354,7 @@ TEST(help_page_printing, advanced_options)
 
     // with -hh everything is shown
     seqan3::argument_parser parser_advanced_help{"test_parser", 2, argv2};
+    test_accessor::set_terminal_width(parser_advanced_help, 80);
     set_up(parser_advanced_help);
     testing::internal::CaptureStdout();
     EXPECT_EXIT(parser_advanced_help.parse(), ::testing::ExitedWithCode(EXIT_SUCCESS), "");
@@ -367,10 +417,10 @@ TEST(help_page_printing, full_information)
     parser6.info.description.push_back("description2");
     parser6.info.short_description = "so short";
     parser6.add_option(option_value, 'i', "int", "this is a int option.");
-    parser6.add_option(enum_option_value, 'e', "enum", "this is an enum option.", seqan3::option_spec::DEFAULT,
+    parser6.add_option(enum_option_value, 'e', "enum", "this is an enum option.", seqan3::option_spec::standard,
                        seqan3::value_list_validator{seqan3::enumeration_names<foo> | std::views::values});
     parser6.add_option(required_option, 'r', "required-int", "this is another int option.",
-                       seqan3::option_spec::REQUIRED);
+                       seqan3::option_spec::required);
     parser6.add_section("Flags");
     parser6.add_subsection("SubFlags");
     parser6.add_line("here come all the flags");
@@ -397,7 +447,7 @@ TEST(help_page_printing, full_information)
                "POSITIONAL ARGUMENTS\n"
                "    ARGUMENT-1 (signed 8 bit integer)\n"
                "          this is not a list.\n"
-               "    ARGUMENT-2 (List of std::string's)\n"
+               "    ARGUMENT-2 (List of std::string)\n"
                "          this is a positional option. Default: [].\n"
                "\n" +
                basic_options_str +
@@ -499,7 +549,11 @@ TEST(parse_test, subcommand_argument_parser)
     std::string option_value2{};
 
     const char * argv[]{"./test_parser", "-h"};
-    seqan3::argument_parser top_level_parser{"test_parser", 2, argv, true, {"sub1", "sub2"}};
+    seqan3::argument_parser top_level_parser{"test_parser",
+                                             2,
+                                             argv,
+                                             seqan3::update_notifications::on,
+                                             {"sub1", "sub2"}};
     test_accessor::set_terminal_width(top_level_parser, 80);
     top_level_parser.info.description.push_back("description");
     top_level_parser.add_option(option_value, 'f', "foo", "foo bar.");
