@@ -152,9 +152,6 @@ TEST_F(sam_file_input_f, default_template_args_and_deduction_guides)
     using comp1 = seqan3::fields<seqan3::field::seq,
                                  seqan3::field::id,
                                  seqan3::field::offset,
-#ifdef SEQAN3_DEPRECATED_310
-                                 seqan3::field::ref_seq,
-#endif // SEQAN3_DEPRECATED_310
                                  seqan3::field::ref_id,
                                  seqan3::field::ref_offset,
                                  seqan3::field::alignment,
@@ -164,10 +161,6 @@ TEST_F(sam_file_input_f, default_template_args_and_deduction_guides)
                                  seqan3::field::flag,
                                  seqan3::field::mate,
                                  seqan3::field::tags,
-#ifdef SEQAN3_DEPRECATED_310
-                                 seqan3::field::evalue,
-                                 seqan3::field::bit_score,
-#endif // SEQAN3_DEPRECATED_310
                                  seqan3::field::header_ptr>;
     using comp2 = seqan3::type_list<seqan3::format_sam, seqan3::format_bam>;
     using comp3 = char;
@@ -264,15 +257,6 @@ TEST_F(sam_file_input_f, record_reading)
     size_t counter = 0;
     for (auto & rec : fin)
     {
-#ifdef SEQAN3_DEPRECATED_310
-#pragma GCC diagnostic push
-#pragma GCC diagnostic ignored "-Wdeprecated-declarations"
-        EXPECT_RANGE_EQ(seqan3::get<seqan3::field::seq>(rec), seq_comp[counter]);
-        EXPECT_RANGE_EQ(seqan3::get<seqan3::field::id>(rec), id_comp[counter]);
-        EXPECT_RANGE_EQ(seqan3::get<seqan3::field::qual>(rec), qual_comp[counter]);
-#pragma GCC diagnostic pop
-#endif // SEQAN3_DEPRECATED_310
-
         EXPECT_RANGE_EQ(rec.sequence(), seq_comp[counter]);
         EXPECT_RANGE_EQ(rec.id(), id_comp[counter]);
         EXPECT_RANGE_EQ(rec.base_qualities(), qual_comp[counter]);
@@ -314,15 +298,6 @@ TEST_F(sam_file_input_f, file_view)
     size_t counter = 1; // the first record will be filtered out
     for (auto & rec : fin | minimum_length_filter)
     {
-#ifdef SEQAN3_DEPRECATED_310
-#pragma GCC diagnostic push
-#pragma GCC diagnostic ignored "-Wdeprecated-declarations"
-        EXPECT_RANGE_EQ(seqan3::get<seqan3::field::seq>(rec), seq_comp[counter]);
-        EXPECT_RANGE_EQ(seqan3::get<seqan3::field::id>(rec), id_comp[counter]);
-        EXPECT_RANGE_EQ(seqan3::get<seqan3::field::qual>(rec), qual_comp[counter]);
-#pragma GCC diagnostic pop
-#endif // SEQAN3_DEPRECATED_310
-
         EXPECT_RANGE_EQ(rec.sequence(), seq_comp[counter]);
         EXPECT_RANGE_EQ(rec.id(), id_comp[counter]);
         EXPECT_RANGE_EQ(rec.base_qualities(), qual_comp[counter]);
@@ -343,15 +318,6 @@ void decompression_impl(fixture_t & fix, input_file_t & fin)
     size_t counter = 0;
     for (auto & rec : fin)
     {
-#ifdef SEQAN3_DEPRECATED_310
-#pragma GCC diagnostic push
-#pragma GCC diagnostic ignored "-Wdeprecated-declarations"
-        EXPECT_RANGE_EQ(seqan3::get<seqan3::field::seq>(rec), fix.seq_comp[counter]);
-        EXPECT_RANGE_EQ(seqan3::get<seqan3::field::id>(rec), fix.id_comp[counter]);
-        EXPECT_RANGE_EQ(seqan3::get<seqan3::field::qual>(rec), fix.qual_comp[counter]);
-#pragma GCC diagnostic pop
-#endif // SEQAN3_DEPRECATED_310
-
         EXPECT_RANGE_EQ(rec.sequence(), fix.seq_comp[counter]);
         EXPECT_RANGE_EQ(rec.id(), fix.id_comp[counter]);
         EXPECT_RANGE_EQ(rec.base_qualities(), fix.qual_comp[counter]);
@@ -362,7 +328,7 @@ void decompression_impl(fixture_t & fix, input_file_t & fin)
     EXPECT_EQ(counter, 3u);
 }
 
-#ifdef SEQAN3_HAS_ZLIB
+#if defined(SEQAN3_HAS_ZLIB)
 
 std::string input_gz
 {
@@ -475,7 +441,7 @@ TEST_F(sam_file_input_f, read_empty_bgzf_file)
 
 #endif
 
-#ifdef SEQAN3_HAS_BZIP2
+#if defined(SEQAN3_HAS_BZIP2)
 std::string input_bz2
 {
     '\x42','\x5A','\x68','\x39','\x31','\x41','\x59','\x26','\x53','\x59','\x7B','\xE2','\xE1','\x92','\x00','\x00',
@@ -651,7 +617,7 @@ struct sam_file_input_bam_format_f : public sam_file_input_sam_format_f
     };
 };
 
-#if SEQAN3_HAS_ZLIB
+#if defined(SEQAN3_HAS_ZLIB)
 TEST_F(sam_file_input_bam_format_f, construct_by_filename)
 {
     seqan3::test::tmp_filename filename{"sam_file_input_constructor.bam"};
@@ -715,4 +681,4 @@ TEST_F(sam_file_input_bam_format_f, construct_by_stream)
 
     EXPECT_EQ(counter, 3u);
 }
-#endif // SEQAN3_HAS_ZLIB
+#endif // defined(SEQAN3_HAS_ZLIB)
