@@ -1,21 +1,22 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2020, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2020, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
 
-#include <sstream>
-
 #include <gtest/gtest.h>
 
-#include <seqan3/io/sequence_file/input.hpp>
-#include <seqan3/range/views/convert.hpp>
 #include <seqan3/std/algorithm>
 #include <seqan3/std/iterator>
 #include <seqan3/std/ranges>
+#include <sstream>
+
+#include <seqan3/alphabet/detail/debug_stream_alphabet.hpp>
+#include <seqan3/io/sequence_file/input.hpp>
 #include <seqan3/test/expect_range_eq.hpp>
 #include <seqan3/test/tmp_filename.hpp>
+#include <seqan3/utility/views/convert.hpp>
 
 using seqan3::operator""_dna5;
 
@@ -231,9 +232,9 @@ TEST_F(sequence_file_input_f, record_reading)
     size_t counter = 0;
     for (auto & rec : fin)
     {
-        EXPECT_RANGE_EQ(seqan3::get<seqan3::field::seq>(rec), seq_comp[counter]);
-        EXPECT_RANGE_EQ(seqan3::get<seqan3::field::id>(rec),  id_comp[counter]);
-        EXPECT_TRUE(empty(seqan3::get<seqan3::field::qual>(rec)));
+        EXPECT_RANGE_EQ(rec.id(),  id_comp[counter]);
+        EXPECT_RANGE_EQ(rec.sequence(), seq_comp[counter]);
+        EXPECT_TRUE(empty(rec.base_qualities()));
 
         counter++;
     }
@@ -259,25 +260,6 @@ TEST_F(sequence_file_input_f, record_reading_struct_bind)
     EXPECT_EQ(counter, 3u);
 }
 
-TEST_F(sequence_file_input_f, record_reading_custom_fields)
-{
-    /* record based reading */
-    seqan3::sequence_file_input fin{std::istringstream{input},
-                                    seqan3::format_fasta{},
-                                    seqan3::fields<seqan3::field::id, seqan3::field::seq_qual>{}};
-
-    size_t counter = 0;
-    for (auto & [ id, seq_qual ] : fin)
-    {
-        EXPECT_RANGE_EQ(seq_qual | seqan3::views::convert<seqan3::dna5>, seq_comp[counter]);
-        EXPECT_RANGE_EQ(id,  id_comp[counter]);
-
-        counter++;
-    }
-
-    EXPECT_EQ(counter, 3u);
-}
-
 TEST_F(sequence_file_input_f, record_reading_custom_options)
 {
     std::istringstream istream{std::string
@@ -295,37 +277,28 @@ TEST_F(sequence_file_input_f, record_reading_custom_options)
     fin.options.truncate_ids = true;
 
     auto it = fin.begin();
-    EXPECT_EQ(seqan3::get<seqan3::field::id>(*it), "ID1");
+    EXPECT_EQ((*it).id(), "ID1");
     ++it;
-    EXPECT_EQ(seqan3::get<seqan3::field::id>(*it), "ID2");
+    EXPECT_EQ((*it).id(), "ID2");
     ++it;
-    EXPECT_EQ(seqan3::get<seqan3::field::id>(*it), "ID3");
+    EXPECT_EQ((*it).id(), "ID3");
 }
 
 TEST_F(sequence_file_input_f, file_view)
 {
     seqan3::sequence_file_input fin{std::istringstream{input}, seqan3::format_fasta{}};
 
-#if !SEQAN3_WORKAROUND_GCC_93983
     auto minimum_length_filter = std::views::filter([] (auto const & rec)
     {
-        return size(seqan3::get<seqan3::field::seq>(rec)) >= 5;
+        return size(rec.sequence()) >= 5;
     });
-#endif
 
     size_t counter = 1; // the first record will be filtered out
-#if SEQAN3_WORKAROUND_GCC_93983
-    for (auto & rec : fin /*| minimum_length_filter*/)
-    {
-        if (!(size(seqan3::get<seqan3::field::seq>(rec)) >= 5))
-            continue;
-#else // ^^^ workaround / no workaround vvv
     for (auto & rec : fin | minimum_length_filter)
     {
-#endif // SEQAN3_WORKAROUND_GCC_93983
-        EXPECT_RANGE_EQ(seqan3::get<seqan3::field::seq>(rec), seq_comp[counter]);
-        EXPECT_RANGE_EQ(seqan3::get<seqan3::field::id>(rec),  id_comp[counter]);
-        EXPECT_TRUE(empty(seqan3::get<seqan3::field::qual>(rec)));
+        EXPECT_RANGE_EQ(rec.id(),  id_comp[counter]);
+        EXPECT_RANGE_EQ(rec.sequence(), seq_comp[counter]);
+        EXPECT_TRUE(empty(rec.base_qualities()));
 
         counter++;
     }
@@ -343,9 +316,9 @@ void decompression_impl(fixture_t & fix, input_file_t & fin)
     size_t counter = 0;
     for (auto & rec : fin)
     {
-        EXPECT_RANGE_EQ(seqan3::get<seqan3::field::seq>(rec), fix.seq_comp[counter]);
-        EXPECT_RANGE_EQ(seqan3::get<seqan3::field::id>(rec),  fix.id_comp[counter]);
-        EXPECT_TRUE(empty(seqan3::get<seqan3::field::qual>(rec)));
+        EXPECT_RANGE_EQ(rec.sequence(), fix.seq_comp[counter]);
+        EXPECT_RANGE_EQ(rec.id(),  fix.id_comp[counter]);
+        EXPECT_TRUE(empty(rec.base_qualities()));
 
         counter++;
     }
@@ -353,7 +326,7 @@ void decompression_impl(fixture_t & fix, input_file_t & fin)
     EXPECT_EQ(counter, 3u);
 }
 
-#ifdef SEQAN3_HAS_ZLIB
+#if defined(SEQAN3_HAS_ZLIB)
 std::string input_gz
 {
     '\x1F','\x8B','\x08','\x00','\x33','\xBF','\x13','\x5C','\x00','\x03','\xB3','\x53','\x08','\x71','\x0D','\x0E',
@@ -459,7 +432,7 @@ TEST_F(sequence_file_input_f, read_empty_bgzf_file)
 }
 #endif
 
-#ifdef SEQAN3_HAS_BZIP2
+#if defined(SEQAN3_HAS_BZIP2)
 std::string input_bz2
 {
     '\x42','\x5A','\x68','\x39','\x31','\x41','\x59','\x26','\x53','\x59','\x8D','\xD7','\xE7','\xD6','\x00','\x00',
