@@ -1,21 +1,19 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2020, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2020, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
 
+#include <seqan3/std/iterator>
 #include <sstream>
 
 #include <gtest/gtest.h>
 
-#include <range/v3/view/zip.hpp>
-#include <range/v3/view/filter.hpp>
-
 #include <seqan3/alphabet/quality/phred42.hpp>
 #include <seqan3/io/sequence_file/output.hpp>
 #include <seqan3/test/tmp_filename.hpp>
-#include <seqan3/std/iterator>
+#include <seqan3/utility/views/zip.hpp>
 
 using seqan3::operator""_dna5;
 using seqan3::operator""_phred42;
@@ -356,26 +354,6 @@ TEST(row, different_fields_in_record_and_file)
     EXPECT_EQ(reinterpret_cast<std::ostringstream&>(fout.get_stream()).str(), expected_out);
 }
 
-TEST(row, writing_seq_qual)
-{
-    seqan3::sequence_file_output fout{std::ostringstream{},
-                                      seqan3::format_fasta{},
-                                      seqan3::fields<seqan3::field::id, seqan3::field::seq_qual>()};
-    fout.options.fasta_letters_per_line = 0;
-
-    for (size_t i = 0; i < 3; ++i)
-    {
-        std::vector<seqan3::qualified<seqan3::dna5, seqan3::phred42>> seq_qual;
-        seq_qual.resize(quals[i].size());
-        std::copy(seqs[i].begin(), seqs[i].end(), seq_qual.begin());
-        std::copy(quals[i].begin(), quals[i].end(), seq_qual.begin());
-
-        fout.emplace_back(ids[i], seq_qual);
-    }
-
-    EXPECT_EQ(reinterpret_cast<std::ostringstream&>(fout.get_stream()).str(), output_comp);
-}
-
 // ----------------------------------------------------------------------------
 // rows
 // ----------------------------------------------------------------------------
@@ -434,27 +412,6 @@ TEST(columns, writing_id_seq_qual)
     EXPECT_EQ(reinterpret_cast<std::ostringstream&>(fout.get_stream()).str(), output_comp);
 }
 
-TEST(columns, writing_seq_qual)
-{
-    seqan3::sequence_file_output fout{std::ostringstream{},
-                                      seqan3::format_fasta{},
-                                      seqan3::fields<seqan3::field::id, seqan3::field::seq_qual>()};
-    fout.options.fasta_letters_per_line = 0;
-
-    std::vector<std::vector<seqan3::qualified<seqan3::dna5, seqan3::phred42>>> seq_quals{3};
-    for (size_t i = 0; i < 3; ++i)
-    {
-        seq_quals[i].resize(quals[i].size());
-        std::copy(seqs[i].begin(), seqs[i].end(), seq_quals[i].begin());
-        std::copy(quals[i].begin(), quals[i].end(), seq_quals[i].begin());
-    }
-
-    fout = seqan3::views::zip(ids, seq_quals);
-
-    fout.get_stream().flush();
-    EXPECT_EQ(reinterpret_cast<std::ostringstream&>(fout.get_stream()).str(), output_comp);
-}
-
 // ----------------------------------------------------------------------------
 // compression
 // ----------------------------------------------------------------------------
@@ -500,7 +457,7 @@ void compression_by_stream_impl(comp_stream_t & stream)
     }
 }
 
-#ifdef SEQAN3_HAS_ZLIB
+#if defined(SEQAN3_HAS_ZLIB)
 std::string expected_gz
 {
     '\x1F','\x8B','\x08','\x00','\x00','\x00','\x00','\x00','\x00','\x00','\xB3','\x53','\x08','\x71','\x0D','\x0E',
@@ -528,7 +485,7 @@ TEST(compression, by_filename_gz)
 
     std::string buffer = compression_by_filename_impl(filename);
     buffer[9] = '\x00'; // zero out OS byte
-    EXPECT_EQ(buffer, expected_bgzf);
+    EXPECT_EQ(buffer, expected_gz);
 }
 
 TEST(compression, by_stream_gz)
@@ -570,7 +527,7 @@ TEST(compression, by_stream_bgzf)
 
 #endif
 
-#ifdef SEQAN3_HAS_BZIP2
+#if defined(SEQAN3_HAS_BZIP2)
 std::string expected_bz2
 {
     '\x42','\x5A','\x68','\x39','\x31','\x41','\x59','\x26','\x53','\x59','\xB4','\x68','\xEA','\xE3','\x00','\x00',
