@@ -1,26 +1,29 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2020, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2020, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
 
+#include <gtest/gtest.h>
+
+#include <seqan3/std/algorithm>
+#include <seqan3/std/iterator>
 #include <set>
 #include <sstream>
 #include <tuple>
 #include <vector>
 
-#include <gtest/gtest.h>
-
+#include <seqan3/alphabet/detail/debug_stream_alphabet.hpp>
 #include <seqan3/alphabet/nucleotide/rna15.hpp>
 #include <seqan3/alphabet/nucleotide/rna5.hpp>
-#include <seqan3/alphabet/structure/wuss.hpp>
 #include <seqan3/alphabet/structure/structured_rna.hpp>
-#include <seqan3/io/structure_file/all.hpp>
-#include <seqan3/range/views/convert.hpp>
-#include <seqan3/std/algorithm>
-#include <seqan3/std/iterator>
+#include <seqan3/alphabet/structure/wuss.hpp>
+#include <seqan3/io/structure_file/format_vienna.hpp>
+#include <seqan3/io/structure_file/input.hpp>
+#include <seqan3/io/structure_file/output.hpp>
 #include <seqan3/test/expect_range_eq.hpp>
+#include <seqan3/utility/views/convert.hpp>
 
 using seqan3::operator""_rna5;
 using seqan3::operator""_wuss51;
@@ -120,26 +123,26 @@ struct read : public ::testing::Test
         auto it = fin.begin();
         for (size_t idx = 0ul; idx < expected_seq.size(); ++idx, ++it)
         {
-            EXPECT_EQ(check_energy, seqan3::get<seqan3::field::energy>(*it).has_value());
+            EXPECT_EQ(check_energy, (*it).energy().has_value());
             if (check_seq)
             {
-                EXPECT_RANGE_EQ(seqan3::get<seqan3::field::seq>(*it), expected_seq[idx]);
+                EXPECT_RANGE_EQ((*it).sequence(), expected_seq[idx]);
             }
             if (check_id)
             {
-                EXPECT_RANGE_EQ(seqan3::get<seqan3::field::id>(*it), expected_id[idx]);
+                EXPECT_RANGE_EQ((*it).id(), expected_id[idx]);
             }
             if (check_structure)
             {
-                bpp_test(seqan3::get<seqan3::field::bpp>(*it), expected_interactions[idx]);
+                bpp_test((*it).base_pair_probability_matrix(), expected_interactions[idx]);
             }
             if (check_energy)
             {
-                EXPECT_DOUBLE_EQ(*seqan3::get<seqan3::field::energy>(*it), expected_energy[idx]);
+                EXPECT_DOUBLE_EQ(*(*it).energy(), expected_energy[idx]);
             }
             if (check_structure)
             {
-                EXPECT_RANGE_EQ(seqan3::get<seqan3::field::structure>(*it), expected_structure[idx]);
+                EXPECT_RANGE_EQ((*it).sequence_structure(), expected_structure[idx]);
             }
         }
     }
@@ -247,7 +250,7 @@ TEST_F(read_fields, only_seq)
     auto it = fin.begin();
     for (size_t idx = 0ul; idx < expected_seq.size(); ++idx, ++it)
     {
-        EXPECT_RANGE_EQ(seqan3::get<seqan3::field::seq>(*it), expected_seq[idx]);
+        EXPECT_RANGE_EQ((*it).sequence(), expected_seq[idx]);
     }
 }
 
@@ -258,7 +261,7 @@ TEST_F(read_fields, only_id)
     auto it = fin.begin();
     for (size_t idx = 0ul; idx < expected_seq.size(); ++idx, ++it)
     {
-        EXPECT_RANGE_EQ(seqan3::get<seqan3::field::id>(*it), expected_id[idx]);
+        EXPECT_RANGE_EQ((*it).id(), expected_id[idx]);
     }
 }
 
@@ -269,7 +272,7 @@ TEST_F(read_fields, only_structure)
     auto it = fin.begin();
     for (size_t idx = 0ul; idx < expected_seq.size(); ++idx, ++it)
     {
-        EXPECT_RANGE_EQ(seqan3::get<seqan3::field::structure>(*it), expected_structure[idx]);
+        EXPECT_RANGE_EQ((*it).sequence_structure(), expected_structure[idx]);
     }
 }
 
@@ -280,22 +283,8 @@ TEST_F(read_fields, only_energy)
     auto it = fin.begin();
     for (size_t idx = 0ul; idx < expected_seq.size(); ++idx, ++it)
     {
-        EXPECT_TRUE(seqan3::get<seqan3::field::energy>(*it));
-        EXPECT_DOUBLE_EQ(*seqan3::get<seqan3::field::energy>(*it), expected_energy[idx]);
-    }
-}
-
-TEST_F(read_fields, structured_seq)
-{
-    std::stringstream istream{input};
-    seqan3::structure_file_input fin{istream, seqan3::format_vienna{}, seqan3::fields<seqan3::field::structured_seq>{}};
-    auto it = fin.begin();
-    for (size_t idx = 0ul; idx < expected_seq.size(); ++idx, ++it)
-    {
-        EXPECT_RANGE_EQ(seqan3::get<seqan3::field::structured_seq>(*it) | seqan3::views::convert<seqan3::rna5>,
-                        expected_seq[idx]);
-        EXPECT_RANGE_EQ(seqan3::get<seqan3::field::structured_seq>(*it) | seqan3::views::convert<seqan3::wuss<51>>,
-                        expected_structure[idx]);
+        EXPECT_TRUE((*it).energy());
+        EXPECT_DOUBLE_EQ(*(*it).energy(), expected_energy[idx]);
     }
 }
 
@@ -306,7 +295,7 @@ TEST_F(read_fields, only_bpp)
     auto it = fin.begin();
     for (size_t idx = 0ul; idx < expected_seq.size(); ++idx, ++it)
     {
-        bpp_test(seqan3::get<seqan3::field::bpp>(*it), expected_interactions[idx]);
+        bpp_test((*it).base_pair_probability_matrix(), expected_interactions[idx]);
     }
 }
 
