@@ -266,16 +266,6 @@ struct structure_file_input_read : public ::testing::Test
         counter = 0ul;
         for (auto & rec : fin)
         {
-
-#ifdef SEQAN3_DEPRECATED_310
-#pragma GCC diagnostic push
-#pragma GCC diagnostic ignored "-Wdeprecated-declarations"
-            EXPECT_RANGE_EQ(seqan3::get<seqan3::field::seq>(rec), seq_comp[counter]);
-            EXPECT_RANGE_EQ(seqan3::get<seqan3::field::id>(rec), id_comp[counter]);
-            EXPECT_RANGE_EQ(seqan3::get<seqan3::field::structure>(rec), structure_comp[counter]);
-#pragma GCC diagnostic pop
-#endif // SEQAN3_DEPRECATED_310
-
             EXPECT_RANGE_EQ(rec.sequence(), seq_comp[counter]);
             EXPECT_RANGE_EQ(rec.id(), id_comp[counter]);
             EXPECT_RANGE_EQ(rec.sequence_structure(), structure_comp[counter]);
@@ -313,16 +303,6 @@ TEST_F(structure_file_input_read, record_general)
     size_t counter = 0ul;
     for (auto & rec : fin)
     {
-
-#ifdef SEQAN3_DEPRECATED_310
-#pragma GCC diagnostic push
-#pragma GCC diagnostic ignored "-Wdeprecated-declarations"
-        EXPECT_RANGE_EQ(seqan3::get<seqan3::field::seq>(rec), seq_comp[counter]);
-        EXPECT_RANGE_EQ(seqan3::get<seqan3::field::id>(rec), id_comp[counter]);
-        EXPECT_RANGE_EQ(seqan3::get<seqan3::field::structure>(rec), structure_comp[counter]);
-#pragma GCC diagnostic pop
-#endif // SEQAN3_DEPRECATED_310
-
         EXPECT_RANGE_EQ(rec.sequence(), seq_comp[counter]);
         EXPECT_RANGE_EQ(rec.id(), id_comp[counter]);
         EXPECT_RANGE_EQ(rec.sequence_structure(), structure_comp[counter]);
@@ -392,18 +372,6 @@ TEST_F(structure_file_input_read, record_file_view)
     size_t counter = 0ul; // the first record will be filtered out
     for (auto & rec : fin | minimum_length_filter)
     {
-
-#ifdef SEQAN3_DEPRECATED_310
-#pragma GCC diagnostic push
-#pragma GCC diagnostic ignored "-Wdeprecated-declarations"
-        EXPECT_RANGE_EQ(seqan3::get<seqan3::field::seq>(rec), seq_comp[counter]);
-        EXPECT_RANGE_EQ(seqan3::get<seqan3::field::id>(rec),  id_comp[counter]);
-        bpp_test(seqan3::get<seqan3::field::bpp>(rec), interaction_comp[counter]);
-        EXPECT_RANGE_EQ(seqan3::get<seqan3::field::structure>(rec), structure_comp[counter]);
-        EXPECT_DOUBLE_EQ(seqan3::get<seqan3::field::energy>(rec).value(), energy_comp[counter]);
-#pragma GCC diagnostic pop
-#endif // SEQAN3_DEPRECATED_310
-
         EXPECT_RANGE_EQ(rec.sequence(), seq_comp[counter]);
         EXPECT_RANGE_EQ(rec.id(), id_comp[counter]);
         bpp_test(rec.base_pair_probability_matrix(), interaction_comp[counter]);
@@ -419,7 +387,7 @@ TEST_F(structure_file_input_read, record_file_view)
 // decompression
 // ----------------------------------------------------------------------------
 
-#ifdef SEQAN3_HAS_ZLIB
+#if defined(SEQAN3_HAS_ZLIB)
 std::string input_gz
 {
     '\x1F','\x8B','\x08','\x00','\x00','\x00','\x00','\x00','\x00','\x03','\x55','\x8E','\xC1','\x0A','\xC2','\x40',
@@ -527,7 +495,7 @@ TEST_F(structure_file_input_read, read_empty_bgzf_file)
 
 #endif
 
-#ifdef SEQAN3_HAS_BZIP2
+#if defined(SEQAN3_HAS_BZIP2)
 std::string input_bz2
 {
     '\x42','\x5A','\x68','\x39','\x31','\x41','\x59','\x26','\x53','\x59','\xC7','\x0B','\xB5','\x7F','\x00','\x00',
