@@ -1,26 +1,20 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2020, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2020, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
 
-#include <iterator>
+#include <seqan3/std/iterator>
 #include <fstream>
+#include <seqan3/std/ranges>
 #include <sstream>
 #include <vector>
 
 #include <gtest/gtest.h>
 
-#include <range/v3/view/zip.hpp>
-#include <range/v3/view/filter.hpp>
-#include <range/v3/algorithm/for_each.hpp>
-#include <range/v3/view/map.hpp>
-
 #include <seqan3/io/structure_file/output.hpp>
 #include <seqan3/io/structure_file/input.hpp>
-#include <seqan3/std/iterator>
-#include <seqan3/std/ranges>
 #include <seqan3/test/tmp_filename.hpp>
 
 using seqan3::operator""_rna5;
@@ -441,7 +435,7 @@ struct structure_file_output_compression : public structure_file_output_write
 };
 #endif
 
-#ifdef SEQAN3_HAS_ZLIB
+#if defined(SEQAN3_HAS_ZLIB)
 std::string expected_gz
 {
     '\x1F','\x8B','\x08','\x00','\x00','\x00','\x00','\x00','\x00','\x00','\x55','\x8E','\xC1','\x0A','\xC2','\x40',
@@ -481,7 +475,7 @@ TEST_F(structure_file_output_compression, by_filename_gz)
     seqan3::test::tmp_filename filename{"structure_file_output_test.dbn.gz"};
     std::string buffer = compression_by_filename_impl(filename);
     buffer[9] = '\x00'; // zero out OS byte
-    EXPECT_EQ(buffer, expected_bgzf);
+    EXPECT_EQ(buffer, expected_gz);
 }
 
 TEST_F(structure_file_output_compression, by_stream_gz)
@@ -517,7 +511,7 @@ TEST_F(structure_file_output_compression, by_stream_bgzf)
 }
 #endif
 
-#ifdef SEQAN3_HAS_BZIP2
+#if defined(SEQAN3_HAS_BZIP2)
 std::string expected_bz2
 {
     '\x42','\x5A','\x68','\x39','\x31','\x41','\x59','\x26','\x53','\x59','\xC7','\x0B','\xB5','\x7F','\x00','\x00',
