@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2020, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2020, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -10,7 +10,10 @@
 #include <algorithm>
 #include <type_traits>
 
-#include <seqan3/range/views/persist.hpp>
+#include <seqan3/alphabet/nucleotide/dna4.hpp>
+#include <seqan3/alphabet/quality/phred42.hpp>
+#include <seqan3/alphabet/quality/qualified.hpp>
+#include <seqan3/core/detail/persist_view.hpp>
 #include <seqan3/search/configuration/hit.hpp>
 #include <seqan3/search/configuration/max_error.hpp>
 #include <seqan3/search/configuration/on_result.hpp>
@@ -25,9 +28,9 @@ using seqan3::operator""_phred42;
 
 using namespace std::string_literals;
 
-auto position = seqan3::views::persist |
+auto position = seqan3::detail::persist |
                 std::views::transform([] (auto && res) { return res.reference_begin_position(); });
-auto query_id = seqan3::views::persist | std::views::transform([] (auto && res) { return res.query_id(); });
+auto query_id = seqan3::detail::persist | std::views::transform([] (auto && res) { return res.query_id(); });
 
 template <typename index_t>
 class search_test : public ::testing::Test
@@ -274,6 +277,11 @@ TYPED_TEST(search_test, error_levenshtein)
         EXPECT_RANGE_EQ(search("CCGT"_dna4, this->index, cfg) | position,
                         (std::vector{0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10}));
     }
+    {
+        seqan3::configuration const cfg = seqan3::search_cfg::max_error_total{seqan3::search_cfg::error_count{4}};
+        EXPECT_RANGE_EQ(search("CCGT"_dna4, this->index, cfg) | position,
+                        (std::vector{0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12}));
+    }
 }
 
 TYPED_TEST(search_test, error_indel_no_substitution)
@@ -405,6 +413,16 @@ TYPED_TEST(search_test, search_strategy_best)
         ASSERT_EQ(result.size(), 1u);
         EXPECT_TRUE(std::find(possible_hits2d.begin(), possible_hits2d.end(), result[0]) != possible_hits2d.end());
     }
+
+    {  // Find best match with at most 2 of every error type.
+        seqan3::configuration const cfg = seqan3::search_cfg::max_error_deletion{seqan3::search_cfg::error_count{2}} |
+                                          seqan3::search_cfg::max_error_insertion{seqan3::search_cfg::error_count{2}} |
+                                          seqan3::search_cfg::max_error_substitution{
+                                              seqan3::search_cfg::error_count{2}} |
+                                          seqan3::search_cfg::hit_single_best{};
+
+        EXPECT_RANGE_EQ(search("TATTA"_dna4, this->index, cfg) | position, (std::vector{3}));
+    }
 }
 
 TYPED_TEST(search_test, search_strategy_all_best)
@@ -480,6 +498,38 @@ TYPED_TEST(search_test, parallel_without_parameter)
     EXPECT_THROW(search("AAAA"_dna4, this->index, cfg), std::runtime_error);
 }
 
+TYPED_TEST(search_test, debug_streaming)
+{
+    std::ostringstream oss;
+    seqan3::debug_stream_type stream{oss};
+    stream << search("TAC"_dna4, this->index);
+    EXPECT_EQ(oss.str(), "[<query_id:0, reference_id:0, reference_pos:3>"
+                         ",<query_id:0, reference_id:0, reference_pos:7>]");
+}
+
+// https://github.com/seqan/seqan3/issues/2115
+TYPED_TEST(search_test, issue_2115)
+{
+    std::vector<seqan3::dna4> const genome{"ACAG"_dna4};
+    TypeParam const index{genome};
+
+    // One substitution error, report all best hits
+    seqan3::configuration const cfg = seqan3::search_cfg::max_error_total{seqan3::search_cfg::error_count{1}} |
+                                      seqan3::search_cfg::max_error_substitution{seqan3::search_cfg::error_count{1}} |
+                                      seqan3::search_cfg::max_error_insertion{seqan3::search_cfg::error_count{0}} |
+                                      seqan3::search_cfg::max_error_deletion{seqan3::search_cfg::error_count{0}} |
+                                      seqan3::search_cfg::hit_all_best{};
+
+    std::vector<seqan3::dna4> const dna4_query{"ACGG"_dna4};
+    std::vector<seqan3::qualified<seqan3::dna4, seqan3::phred42>> const dna4q_query{{'A'_dna4, '!'_phred42},
+                                                                                    {'C'_dna4, '0'_phred42},
+                                                                                    {'G'_dna4, '?'_phred42},
+                                                                                    {'G'_dna4, 'J'_phred42}};
+
+    // Quality should not alter search results.
+    EXPECT_RANGE_EQ(seqan3::search(dna4q_query, index, cfg), seqan3::search(dna4_query, index, cfg));
+}
+
 TYPED_TEST(search_string_test, error_free_string)
 {
     // successful and unsuccesful exact search without cfg
