@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2020, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2020, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -14,7 +14,6 @@
 
 #include <seqan3/core/platform.hpp>
 
-#if !SEQAN3_WORKAROUND_GCC_95578
 // https://gcc.gnu.org/bugzilla/show_bug.cgi?id=95578
 TEST(algorithm_test, gcc95578)
 {
@@ -24,4 +23,3 @@ TEST(algorithm_test, gcc95578)
     std::vector<int> rng_copy{};
     std::ranges::copy(rng, std::cpp20::back_inserter(rng_copy));
 }
-#endif // !SEQAN3_WORKAROUND_GCC_95578
